@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: autocompletion.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: autocompletion.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,16 +39,15 @@ if (!strstr($_POST['itemtype'],"Plugin")) {
 }
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkLoginUser();
+Session::checkLoginUser();
 
 // Security
-if (!isset($_POST['itemtype']) || !class_exists($_POST['itemtype'])) {
+if (!isset($_POST['itemtype']) || !($item = getItemForItemtype($_POST['itemtype']))) {
    exit();
 }
 
-$item = new $_POST['itemtype']();
 $item->getEmpty();
 $table = $item->getTable();
 // Security
@@ -57,28 +56,24 @@ if (!isset($item->fields[$_POST['field']]) || !$item->canView()) {
 }
 
 // Security : blacklist fields
-if (in_array($table.'.'.$_POST['field'],array('glpi_users.name',
-                                              'glpi_users.password',
-                                              'glpi_authldaps.rootdn_passwd',
-                                              'glpi_authldaps.rootdn',
-                                              'glpi_configs.proxy_passwd',
-                                              'glpi_mailcollectors.login',
-                                              'glpi_mailcollectors.passwd',
-                                              'glpi_ocsservers.ocs_db_user',
-                                              'glpi_ocsservers.ocs_db_passwd'))) {
+if (in_array($table.'.'.$_POST['field'],
+             array('glpi_authldaps.rootdn', 'glpi_authldaps.rootdn_passwd',
+                   'glpi_configs.proxy_passwd', 'glpi_mailcollectors.login',
+                   'glpi_mailcollectors.passwd', 'glpi_ocsservers.ocs_db_passwd',
+                   'glpi_ocsservers.ocs_db_user', 'glpi_users.name', 'glpi_users.password'))) {
    exit();
 }
 
 
-$entity="";
+$entity = "";
 if (isset($_POST['entity_restrict']) && $_POST['entity_restrict']>=0) {
    if ($item->isEntityAssign()) {
-      $entity=" AND `entities_id` = '".$_POST['entity_restrict']."' ";
+      $entity = " AND `entities_id` = '".$_POST['entity_restrict']."' ";
    }
 }
 
 if (isset($_POST['user_restrict']) && $_POST['user_restrict']>0) {
-   $entity=" AND `users_id` = '".$_POST['user_restrict']."' ";
+   $entity = " AND `users_id` = '".$_POST['user_restrict']."' ";
 }
 
 $query = "SELECT COUNT(`".$_POST['field']."`)
@@ -100,10 +95,10 @@ $query = "SELECT DISTINCT `".$_POST['field']."` AS VAL
 if ($result=$DB->query($query)) {
    echo '{"totalCount":'.$totnum.',"items":[';
    if ($DB->numrows($result)>0) {
-      $first=true;
+      $first = true;
       while ($data=$DB->fetch_array($result)) {
          if ($first) {
-            $first=false;
+            $first = false;
          } else {
             echo ',';
          }
