@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownAllItems.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownAllItems.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,9 +36,9 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 // Make a select box
 if ($_POST["idtable"] && class_exists($_POST["idtable"])) {
@@ -76,9 +76,9 @@ if ($_POST["idtable"] && class_exists($_POST["idtable"])) {
       $paramsallitems['condition'] = stripslashes($_POST['condition']);
    }
 
-   $default = "<select name='".$_POST["myname"]."'><option value='0'>".DROPDOWN_EMPTY_VALUE.
+   $default = "<select name='".$_POST["myname"]."'><option value='0'>".Dropdown::EMPTY_VALUE.
               "</option></select>";
-   ajaxDropdown($use_ajax, "/ajax/$link", $paramsallitems, $default, $rand);
+   Ajax::dropdown($use_ajax, "/ajax/$link", $paramsallitems, $default, $rand);
 
 }
 
