@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownConnectPort.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownConnectPort.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,9 +38,9 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkRight("networking","w");
+Session::checkRight("networking", "w");
 
 // Make a select box
 if (class_exists($_POST["itemtype"]) && isset($_POST["item"])) {
@@ -71,7 +71,7 @@ if (class_exists($_POST["itemtype"]) && isset($_POST["item"])) {
 
    echo "<br>";
    echo "<select name='".$_POST['myname']."[".$_POST["current"]."]' size='1'>";
-   echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>";
+   echo "<option value='0'>".Dropdown::EMPTY_VALUE."</option>";
 
    if ($DB->numrows($result)) {
       while ($data = $DB->fetch_array($result)) {
@@ -94,8 +94,8 @@ if (class_exists($_POST["itemtype"]) && isset($_POST["item"])) {
             $output      .= " ($ID)";
             $output_long .= " ($ID)";
          }
-         $output = utf8_substr($output, 0, $_SESSION["glpidropdown_chars_limit"]);
-         echo "<option value='$ID' title=\"".cleanInputText($output_long)."\">".$output;
+         $output = Toolbox::substr($output, 0, $_SESSION["glpidropdown_chars_limit"]);
+         echo "<option value='$ID' title=\"".Html::cleanInputText($output_long)."\">".$output;
          echo "</option>";
       }
    }
