@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownConnectPortDeviceType.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownConnectPortDeviceType.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,9 +36,9 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkRight("networking", "w");
+Session::checkRight("networking", "w");
 
 // Make a select box
 if (class_exists($_POST["itemtype"])) {
@@ -60,8 +60,8 @@ if (class_exists($_POST["itemtype"])) {
                                                       'itemtype' => $_POST['itemtype'],
                                                       'myname'   => $_POST['myname'])));
 
-   $default = "<select name='item$rand'><option value='0'>".DROPDOWN_EMPTY_VALUE."</option></select>\n";
-   ajaxDropdown($use_ajax, "/ajax/dropdownValue.php", $paramsconnectpdt, $default, $rand);
+   $default = "<select name='item$rand'><option value='0'>".Dropdown::EMPTY_VALUE."</option></select>\n";
+   Ajax::dropdown($use_ajax, "/ajax/dropdownValue.php", $paramsconnectpdt, $default, $rand);
 
    echo "<span id='results_item_$rand'>";
    echo "</span>\n";
