@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownFieldsBlacklist.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownFieldsBlacklist.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,10 +36,10 @@ if (strpos($_SERVER['PHP_SELF'],"dropdownFieldsBlacklist.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
-checkRight("config", "w");
+Session::checkRight("config", "w");
 
 $field = new Fieldblacklist();
 if ($_POST['id'] > 0) {
