@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownFindNum.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownFindNum.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,9 +36,9 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT . "/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkRight("create_ticket", "1");
+Session::checkRight("create_ticket", "1");
 
 // Security
 if (!TableExists($_POST['table'])) {
@@ -46,10 +46,10 @@ if (!TableExists($_POST['table'])) {
 }
 
 $itemtypeisplugin = isPluginItemType($_POST['itemtype']);
-$item             = new $_POST['itemtype'];
+$item             = new $_POST['itemtype']();
 
 if ($item->isEntityAssign()) {
-   if (isset ($_POST["entity_restrict"]) && $_POST["entity_restrict"] >= 0) {
+   if (isset($_POST["entity_restrict"]) && $_POST["entity_restrict"] >= 0) {
       $entity = $_POST["entity_restrict"];
    } else {
       $entity = '';
@@ -66,12 +66,13 @@ if ($item->isEntityAssign()) {
 if ($item->maybeDeleted()) {
    $where .= " AND `is_deleted` = '0' ";
 }
+
 if ($item->maybeTemplate()) {
    $where .= " AND `is_template` = '0' ";
 }
 
 if (strlen($_POST['searchText'])>0 && $_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]) {
-   $search = makeTextSearch($_POST['searchText']);
+   $search = Search::makeTextSearch($_POST['searchText']);
 
    $where .= " AND (`name` ".$search."
                     OR `id` = '".$_POST['searchText']."'";
@@ -103,13 +104,13 @@ $query = "SELECT *
           $LIMIT";
 $result = $DB->query($query);
 
-echo "<select name='".$_POST['myname']."' size='1'>";
+echo "<select id='dropdown_find_num' name='".$_POST['myname']."' size='1'>";
 
 if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"] && $DB->numrows($result)==$NBMAX) {
    echo "<option value='0'>--".$LANG['common'][11]."--</option>";
 }
 
-echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>";
+echo "<option value='0'>".Dropdown::EMPTY_VALUE."</option>";
 
 if ($DB->numrows($result)) {
    while ($data = $DB->fetch_array($result)) {
@@ -130,11 +131,19 @@ if ($DB->numrows($result)) {
       if (empty($output) || $_SESSION['glpiis_ids_visible']) {
          $output .= " (".$data['id'].")";
       }
-      echo "<option value='".$data['id']."' title=\"".cleanInputText($output)."\">".
-            utf8_substr($output, 0, $_SESSION["glpidropdown_chars_limit"])."</option>";
+      echo "<option value='".$data['id']."' title=\"".Html::cleanInputText($output)."\">".
+            Toolbox::substr($output, 0, $_SESSION["glpidropdown_chars_limit"])."</option>";
    }
 }
 
 echo "</select>";
 
-?>
+
+// Auto update summary of active or just solved tickets
+$params = array('items_id' => '__VALUE__',
+                'itemtype' => $_POST['itemtype']);
+
+Ajax::updateItemOnSelectEvent("dropdown_find_num","item_ticket_selection_information",
+                              $CFG_GLPI["root_doc"]."/ajax/ticketiteminformation.php",
+                              $params);
+?>
\ No newline at end of file
