@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownMassiveAction.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: dropdownMassiveAction.php 18190 2012-04-06 09:12:48Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -199,7 +199,7 @@ if (isset($_POST["action"]) && isset($_POST["itemtype"]) && !empty($_POST["itemt
       case "connect_to_computer" :
          Dropdown::showAllItems("connect_item", 0, 0, $_SESSION["glpiactive_entity"],
                                 array('Monitor', 'Peripheral', 'Phone',  'Printer'),
-                                true);
+                                true, true);
          echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                       $LANG['buttons'][2]."'>";
          break;
