@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownMassiveActionField.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownMassiveActionField.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,29 +36,27 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-if (!isset($_POST["itemtype"]) || !class_exists($_POST["itemtype"])) {
+if (!isset($_POST["itemtype"]) || !($item = getItemForItemtype($_POST['itemtype']))) {
    exit();
 }
 
-$item = new $_POST["itemtype"]();
-
 if (in_array($_POST["itemtype"],$CFG_GLPI["infocom_types"])) {
-   checkSeveralRightsOr(array($_POST["itemtype"] => "w",
-                              "infocom"          => "w"));
+   Session::checkSeveralRightsOr(array($_POST["itemtype"] => "w",
+                                       "infocom"          => "w"));
 } else {
    $item->checkGlobal("w");
 }
 
-
 if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]) {
    $search = Search::getOptions($_POST["itemtype"]);
-   $search = $search[$_POST["id_field"]];
-
+   if (!isset($search[$_POST["id_field"]])) {
+      exit();
+   }
+   $search            = $search[$_POST["id_field"]];
    $FIELDNAME_PRINTED = false;
-
-   echo '&nbsp;';
+   $USE_TABLE         = false;
 
    if ($search["table"]==getTableForItemType($_POST["itemtype"])) { // field type
       switch ($search["table"].".".$search["linkfield"]) {
@@ -69,7 +67,7 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
 
          case "glpi_contracts.duration" :
          case "glpi_contracts.notice" :
-            Dropdown::showInteger($search["field"], 0, 0, 120);
+            Dropdown::showInteger($search["linkfield"], 0, 0, 120);
             echo " ".$LANG['financial'][57];
             break;
 
@@ -86,6 +84,12 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
             Ticket::dropdownStatus($search["linkfield"]);
             break;
 
+         case "glpi_tickets.items_id" :
+            if (isset($_POST['itemtype_used']) && !empty($_POST['itemtype_used'])) {
+               Dropdown::show($_POST['itemtype_used'], array('name' => $search["linkfield"]));
+            }
+            break;
+
          case "glpi_tickets.type" :
             Ticket::dropdownType($search["linkfield"]);
             break;
@@ -107,36 +111,82 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
             break;
 
          case "glpi_users.language" :
-            Dropdown::showLanguages("language", array('display_none' => true, 
+            Dropdown::showLanguages("language", array('display_none' => true,
                                                       'emptylabel'   => $LANG['setup'][46]));
             break;
-
+            
+         case "glpi_crontasks.mode" :
+            $options = array();
+            $options[CronTask::MODE_INTERNAL] = CronTask::getModeName(CronTask::MODE_INTERNAL);
+            $options[CronTask::MODE_EXTERNAL] = CronTask::getModeName(CronTask::MODE_EXTERNAL);
+            Dropdown::showFromArray('mode', $options);
+            break;
+         
+         case "glpi_crontasks.state" :
+            CronTask::dropdownState('state');
+            break;
+            
          default :
             // Specific plugin Type case
             $plugdisplay = false;
             if ($plug=isPluginItemType($_POST["itemtype"])) {
-               $plugdisplay = doOneHook($plug['plugin'], 'MassiveActionsFieldsDisplay',
-                                        array('itemtype' => $_POST["itemtype"],
-                                              'options'  => $search));
+               $plugdisplay = Plugin::doOneHook($plug['plugin'], 'MassiveActionsFieldsDisplay',
+                                                array('itemtype' => $_POST["itemtype"],
+                                                      'options'  => $search));
             }
             $already_display = false;
 
             if (isset($search['datatype'])) {
                switch ($search['datatype']) {
                   case "date" :
-                     showDateFormItem($search["field"]);
+                     echo "<table><tr><td>";
+                     Html::showDateFormItem($search["linkfield"]);
+                     echo "</td>";
+                     $USE_TABLE       = true;
                      $already_display = true;
                      break;
 
                   case "datetime" :
-                     showDateTimeFormItem($search["field"]);
-                     $already_display = true;
+                     if (!isset($_POST['relative_dates']) || !$_POST['relative_dates']) {
+                        echo "<table><tr><td>";
+                        Html::showDateTimeFormItem($search["linkfield"]);
+                        echo "</td>";
+                        $already_display = true;
+                        $USE_TABLE       = true;
+                     } else { // For ticket template
+                        Html::showGenericDateTimeSearch($search["linkfield"], '',
+                                                        array('with_time'          => true,
+                                                              'with_future'
+                                                                  => (isset($search['maybefuture'])
+                                                                      && $search['maybefuture']),
+                                                              'with_days'          => false,
+                                                              'with_specific_date' => false));
+
+                        $already_display = true;
+                     }
+                     break;
+
+                  case "itemtypename" :
+                     if (isset($search['itemtype_list'])) {
+                        Dropdown::dropdownTypes($search["linkfield"],'',$CFG_GLPI[$search['itemtype_list']]);
+                        $already_display = true;
+                     }
                      break;
 
                   case "bool" :
                      Dropdown::showYesNo($search["linkfield"]);
                      $already_display = true;
                      break;
+
+                  case "timestamp" :
+                     Dropdown::showTimeStamp($search["linkfield"]);
+                     $already_display = true;
+                     break;
+
+                  case "text" :
+                     echo "<textarea cols='45' rows='5' name='".$search["linkfield"]."' ></textarea>";
+                     $already_display = true;
+                     break;
                }
             }
 
@@ -145,9 +195,9 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
                if ($newtype != $_POST["itemtype"]) {
                   $item = new $newtype();
                }
-               autocompletionTextField($item, $search["field"],
-                                       array('name'   => $search["linkfield"],
-                                             'entity' => $_SESSION["glpiactive_entity"]));
+               Html::autocompletionTextField($item, $search["linkfield"],
+                                             array('name'   => $search["linkfield"],
+                                                   'entity' => $_SESSION["glpiactive_entity"]));
             }
       }
 
@@ -168,8 +218,10 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
                case "order_date" :
                case "inventory_date" :
                case "warranty_date" :
-                  showDateFormItem($search["field"]);
-                  echo "&nbsp;&nbsp;";
+                  echo "<table><tr><td>";
+                  Html::showDateFormItem($search["field"]);
+                  echo "</td>";
+                  $USE_TABLE = true;
                   break;
 
                case "sink_type" :
@@ -191,8 +243,8 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
                   if ($newtype != $_POST["itemtype"]) {
                      $item = new $newtype();
                   }
-                  autocompletionTextField($item, $search["field"],
-                                          array('entity' => $_SESSION["glpiactive_entity"]));
+                  Html::autocompletionTextField($item, $search["field"],
+                                                array('entity' => $_SESSION["glpiactive_entity"]));
             }
             break;
 
@@ -247,39 +299,56 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
             if (($plug=isPluginItemType($_POST["itemtype"]))
                 // Specific for plugin which add link to core object
                 || ($plug=isPluginItemType(getItemTypeForTable($search['table'])))) {
-               $plugdisplay = doOneHook($plug['plugin'], 'MassiveActionsFieldsDisplay',
-                                        array('itemtype' => $_POST["itemtype"],
-                                              'options'  => $search));
+               $plugdisplay = Plugin::doOneHook($plug['plugin'], 'MassiveActionsFieldsDisplay',
+                                                array('itemtype' => $_POST["itemtype"],
+                                                      'options'  => $search));
             }
             $already_display = false;
 
             if (isset($search['datatype'])) {
                switch ($search['datatype']) {
                   case "date" :
-                     showDateFormItem($search["field"]);
+                     echo "<table><tr><td>";
+                     Html::showDateFormItem($search["linkfield"]);
+                     echo "</td>";
+                     $USE_TABLE       = true;
                      $already_display = true;
                      break;
 
                   case "datetime" :
-                     showDateTimeFormItem($search["field"]);
+                     echo "<table><tr><td>";
+                     Html::showDateTimeFormItem($search["linkfield"]);
+                     echo "</td>";
                      $already_display = true;
+                     $USE_TABLE = true;
                      break;
 
                   case "bool" :
                      Dropdown::showYesNo($search["linkfield"]);
                      $already_display = true;
                      break;
+
+                  case "text" :
+                     echo "<textarea cols='45' rows='5' name='".$search["linkfield"]."' ></textarea>";
+                     $already_display = true;
+                     break;
                }
             }
 
             if (!$plugdisplay && !$already_display) {
+               $cond = (isset($search['condition']) ? $search['condition'] : '');
                Dropdown::show(getItemTypeForTable($search["table"]),
-                              array('name'   => $search["linkfield"],
-                                    'entity' => $_SESSION['glpiactiveentities']));
+                              array('name'      => $search["linkfield"],
+                                    'entity'    => $_SESSION['glpiactiveentities'],
+                                    'condition' => $cond));
             }
       }
    }
 
+   if ($USE_TABLE) {
+      echo "<td>";
+   }
+
    if (!$FIELDNAME_PRINTED) {
       if (empty($search["linkfield"])) {
          echo "<input type='hidden' name='field' value='".$search["field"]."'>";
@@ -290,6 +359,9 @@ if (isset($_POST["itemtype"]) && isset($_POST["id_field"]) && $_POST["id_field"]
 
    echo "&nbsp;<input type='submit' name='massiveaction' class='submit' value='".
                 $LANG['buttons'][2]."'>";
-}
+   if ($USE_TABLE) {
+      echo "</td></tr></table>";
+   }
 
+}
 ?>
