@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownMassiveActionPorts.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: dropdownMassiveActionPorts.php 18718 2012-06-26 06:51:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -62,7 +62,7 @@ if (isset($_POST["action"])) {
          break;
 
       case "move" :
-         Dropdown::show($_POST['itemtype'], array('name' => 'device'));
+         Dropdown::show('NetworkEquipment', array('name' => 'items_id'));
          echo "&nbsp;<input type='submit' name='move' class='submit' value=\"".
                       $LANG['buttons'][2]."\">";
          break;
