@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownRubDocument.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownRubDocument.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,10 +37,10 @@ if (strpos($_SERVER['PHP_SELF'],"dropdownRubDocument.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 // Make a select box
 if (isset($_POST["rubdoc"])) {
