@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownSelectSoftware.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownSelectSoftware.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,17 +37,17 @@ if (strpos($_SERVER['PHP_SELF'],"dropdownSelectSoftware.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
-checkRight("software","w");
+Session::checkRight("software", "w");
 
 // Make a select box
 $rand  = mt_rand();
 $where = "";
 
 if (strlen($_POST['searchText'])>0 && $_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]) {
-   $where .=" AND `name` ".makeTextSearch($_POST['searchText'])." ";
+   $where .=" AND `name` ".Search::makeTextSearch($_POST['searchText'])." ";
 }
 
 $where .= getEntitiesRestrictRequest(' AND', 'glpi_softwares','entities_id',
@@ -63,14 +63,14 @@ $query = "SELECT DISTINCT `glpi_softwares`.`id`,
 $result = $DB->query($query);
 
 echo "<select name='softwares_id' id='item_type$rand'>\n";
-echo "<option value='0'>".DROPDOWN_EMPTY_VALUE."</option>\n";
+echo "<option value='0'>".Dropdown::EMPTY_VALUE."</option>\n";
 
 if ($DB->numrows($result)) {
    while ($data=$DB->fetch_array($result)) {
       $softwares_id = $data["id"];
       $output       = $data["name"];
-      echo "<option value='$softwares_id' title=\"".cleanInputText($output)."\">".
-             utf8_substr($output, 0, $_SESSION["glpidropdown_chars_limit"])."</option>";
+      echo "<option value='$softwares_id' title=\"".Html::cleanInputText($output)."\">".
+             Toolbox::substr($output, 0, $_SESSION["glpidropdown_chars_limit"])."</option>";
    }
 }
 echo "</select>\n";
@@ -78,9 +78,9 @@ echo "</select>\n";
 $paramsselsoft = array('softwares_id' => '__VALUE__',
                        'myname'       => $_POST["myname"]);
 
-ajaxUpdateItemOnSelectEvent("item_type$rand", "show_".$_POST["myname"].$rand,
-                            $CFG_GLPI["root_doc"]."/ajax/dropdownInstallVersion.php",
-                            $paramsselsoft, false);
+Ajax::updateItemOnSelectEvent("item_type$rand", "show_".$_POST["myname"].$rand,
+                              $CFG_GLPI["root_doc"]."/ajax/dropdownInstallVersion.php",
+                              $paramsselsoft);
 
 echo "<span id='show_".$_POST["myname"]."$rand'>&nbsp;</span>\n";
 
