@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownUnicityFields.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownUnicityFields.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,12 +36,12 @@ if (strpos($_SERVER['PHP_SELF'],"dropdownUnicityFields.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
-checkRight("config", "w");
+Session::checkRight("config", "w");
 
-$field = new FieldUnicity;
+$field = new FieldUnicity();
 if ($_POST['id'] > 0) {
    $field->getFromDB($_POST['id']);
 } else {
