@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdownValue.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdownValue.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,20 +37,20 @@ if (strpos($_SERVER['PHP_SELF'],"dropdownValue.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
    die("Can not acces directly to this file");
 }
 
-checkLoginUser();
+Session::checkLoginUser();
 
 // Security
-if (!class_exists($_POST['itemtype']) ) {
+if (!($item = getItemForItemtype($_POST['itemtype']))) {
    exit();
 }
-$item  = new $_POST['itemtype']();
+
 $table = $item->getTable();
 
 $displaywith = false;
@@ -77,7 +77,11 @@ if (isset($_POST['condition']) && !empty($_POST['condition'])) {
 }
 
 if (!isset($_POST['emptylabel']) || $_POST['emptylabel'] == '') {
-   $_POST['emptylabel'] = DROPDOWN_EMPTY_VALUE;
+   $_POST['emptylabel'] = Dropdown::EMPTY_VALUE;
+}
+
+if (!isset($_POST['display_rootentity'])) {
+   $_POST['display_rootentity'] = false;
 }
 
 if (isset($_POST["entity_restrict"])
@@ -123,6 +127,15 @@ if (isset($_POST['used'])) {
    }
 }
 
+if (isset($_POST['toadd'])) {
+   if (is_array($_POST['toadd'])) {
+      $toadd = $_POST['toadd'];
+   } else {
+      $toadd = unserialize(stripslashes($_POST['toadd']));
+   }
+} else {
+   $toadd = array();
+}
 
 $where .= ") ";
 
@@ -133,7 +146,7 @@ if (isset($_POST['condition']) && $_POST['condition'] != '') {
 if ($item instanceof CommonTreeDropdown) {
 
    if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]) {
-      $where .= " AND `completename` ".makeTextSearch($_POST['searchText']);
+      $where .= " AND `completename` ".Search::makeTextSearch($_POST['searchText']);
    }
    $multi = false;
 
@@ -190,8 +203,8 @@ if ($item instanceof CommonTreeDropdown) {
       echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name='".$_POST['myname']."'
              size='1'";
 
-      if (isset($_POST["auto_submit"]) && $_POST["auto_submit"]==1) {
-         echo " onChange='submit()'";
+      if (isset($_POST["on_change"]) && !empty($_POST["on_change"])) {
+         echo " onChange='".$_POST["on_change"]."'";
       }
       echo ">";
 
@@ -199,6 +212,14 @@ if ($item instanceof CommonTreeDropdown) {
          echo "<option class='tree' value='0'>--".$LANG['common'][11]."--</option>";
       }
 
+      if (count($toadd)) {
+         foreach ($toadd as $key => $val) {
+            echo "<option class='tree' ".($_POST['value']==$key?'selected':'').
+                 " value='$key' title=\"".Html::cleanInputText($val)."\">".
+                  Toolbox::substr($val, 0, $_POST["limit"])."</option>";
+         }
+      }
+
       $display_selected = true;
 
       switch ($table) {
@@ -206,12 +227,13 @@ if ($item instanceof CommonTreeDropdown) {
             // If entity=0 allowed
             if (isset($_POST["entity_restrict"])
                 && (($_POST["entity_restrict"]<=0 && in_array(0, $_SESSION['glpiactiveentities']))
-                    || (is_array($_POST["entity_restrict"]) && in_array(0, $_POST["entity_restrict"])))) {
+                    || (is_array($_POST["entity_restrict"])
+                        && in_array(0, $_POST["entity_restrict"])))) {
 
                echo "<option class='tree' value='0'>".$LANG['entity'][2]."</option>";
 
                // Entity=0 already add above
-               if ($_POST['value']==0) {
+               if ($_POST['value']==0 && !$_POST['display_rootentity']) {
                   $display_selected = false;
                }
             }
@@ -226,13 +248,13 @@ if ($item instanceof CommonTreeDropdown) {
       if ($display_selected) {
          $outputval = Dropdown::getDropdownName($table, $_POST['value']);
 
-         if (strlen($outputval)!=0 && $outputval!="&nbsp;") {
+         if (Toolbox::strlen($outputval)!=0 && $outputval!="&nbsp;") {
 
-            if (utf8_strlen($outputval)>$_POST["limit"]) {
+            if (Toolbox::strlen($outputval)>$_POST["limit"]) {
                // Completename for tree dropdown : keep right
-               $outputval = "&hellip;".utf8_substr($outputval, -$_POST["limit"]);
+               $outputval = "&hellip;".Toolbox::substr($outputval, -$_POST["limit"]);
             }
-            if ($_SESSION["glpiis_ids_visible"] || strlen($outputval)==0) {
+            if ($_SESSION["glpiis_ids_visible"] || Toolbox::strlen($outputval)==0) {
                $outputval .= " (".$_POST['value'].")";
             }
             echo "<option class='tree' selected value='".$_POST['value']."'>".$outputval."</option>";
@@ -302,8 +324,8 @@ if ($item instanceof CommonTreeDropdown) {
                               $addcomment = " - ".$item->fields["comment"];
                            }
                            $output2 = $item->getName();
-                           if (utf8_strlen($output2)>$_POST["limit"]) {
-                              $output2 = utf8_substr($output2, 0 ,$_POST["limit"])."&hellip;";
+                           if (Toolbox::strlen($output2)>$_POST["limit"]) {
+                              $output2 = Toolbox::substr($output2, 0 ,$_POST["limit"])."&hellip;";
                            }
 
                            $class2 = " class='tree' ";
@@ -315,7 +337,7 @@ if ($item instanceof CommonTreeDropdown) {
                            }
 
                            $to_display = "<option disabled value='$work_parentID' $class2
-                                           title=\"".cleanInputText($item->fields['completename'].
+                                           title=\"".Html::cleanInputText($item->fields['completename'].
                                              $addcomment)."\">".
                                          str_repeat("&nbsp;&nbsp;&nbsp;", $work_level).
                                          $raquo2.$output2."</option>".$to_display;
@@ -338,16 +360,16 @@ if ($item instanceof CommonTreeDropdown) {
                $last_level_displayed[$level] = $data['id'];
             }
 
-            if (utf8_strlen($output)>$_POST["limit"]) {
+            if (Toolbox::strlen($output)>$_POST["limit"]) {
 
                if ($_SESSION['glpiuse_flat_dropdowntree']) {
-                  $output = "&hellip;".utf8_substr($output, -$_POST["limit"]);
+                  $output = "&hellip;".Toolbox::substr($output, -$_POST["limit"]);
                } else {
-                  $output = utf8_substr($output, 0, $_POST["limit"])."&hellip;";
+                  $output = Toolbox::substr($output, 0, $_POST["limit"])."&hellip;";
                }
             }
 
-            if ($_SESSION["glpiis_ids_visible"] || strlen($output)==0) {
+            if ($_SESSION["glpiis_ids_visible"] || Toolbox::strlen($output)==0) {
                $output .= " ($ID)";
             }
             $addcomment = "";
@@ -355,7 +377,7 @@ if ($item instanceof CommonTreeDropdown) {
             if (isset($data["comment"])) {
                $addcomment = " - ".$data["comment"];
             }
-            echo "<option value='$ID' $class title=\"".cleanInputText($data['completename'].
+            echo "<option value='$ID' $class title=\"".Html::cleanInputText($data['completename'].
                    $addcomment)."\">".str_repeat("&nbsp;&nbsp;&nbsp;", $level).$raquo.$output.
                  "</option>";
          }
@@ -395,7 +417,7 @@ if ($item instanceof CommonTreeDropdown) {
    }
 
    if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"]) {
-      $search = makeTextSearch($_POST['searchText']);
+      $search = Search::makeTextSearch($_POST['searchText']);
       $where .=" AND  (`$table`.`$field` ".$search;
 
       if ($_POST['itemtype']=="SoftwareLicense") {
@@ -441,9 +463,10 @@ if ($item instanceof CommonTreeDropdown) {
       echo "<select id='dropdown_".$_POST["myname"].$_POST["rand"]."' name='".$_POST['myname']."'
              size='1'";
 
-      if (isset($_POST["auto_submit"]) && $_POST["auto_submit"]==1) {
-         echo " onChange='submit()'";
+      if (isset($_POST["on_change"]) && !empty($_POST["on_change"])) {
+         echo " onChange='".$_POST["on_change"]."'";
       }
+
       echo ">";
 
       if ($_POST['searchText']!=$CFG_GLPI["ajax_wildcard"] && $DB->numrows($result)==$NBMAX) {
@@ -453,6 +476,14 @@ if ($item instanceof CommonTreeDropdown) {
          echo "<option value='0'>".$_POST["emptylabel"]."</option>";
       }
 
+      if (count($toadd)) {
+         foreach ($toadd as $key => $val) {
+            echo "<option title=\"".Html::cleanInputText($val)."\" value='$key' ".
+                  ($_POST['value']==$key?'selected':'').">".
+                  Toolbox::substr($val, 0, $_POST["limit"])."</option>";
+         }
+      }
+
       $output = Dropdown::getDropdownName($table,$_POST['value']);
 
       if (strlen($output)!=0 && $output!="&nbsp;") {
@@ -493,8 +524,8 @@ if ($item instanceof CommonTreeDropdown) {
                echo "<optgroup label=\"". Dropdown::getDropdownName("glpi_entities", $prev) ."\">";
             }
 
-            echo "<option value='$ID' title=\"".cleanInputText($output.$addcomment)."\">".
-                  utf8_substr($output, 0, $_POST["limit"])."</option>";
+            echo "<option value='$ID' title=\"".Html::cleanInputText($output.$addcomment)."\">".
+                  Toolbox::substr($output, 0, $_POST["limit"])."</option>";
          }
 
          if ($multi) {
@@ -509,10 +540,10 @@ if (isset($_POST["comment"]) && $_POST["comment"]) {
    $paramscomment = array('value' => '__VALUE__',
                           'table' => $table);
 
-   ajaxUpdateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],
-                               "comment_".$_POST["myname"].$_POST["rand"],
-                               $CFG_GLPI["root_doc"]."/ajax/comments.php", $paramscomment, false);
+   Ajax::updateItemOnSelectEvent("dropdown_".$_POST["myname"].$_POST["rand"],
+                                 "comment_".$_POST["myname"].$_POST["rand"],
+                                 $CFG_GLPI["root_doc"]."/ajax/comments.php", $paramscomment);
 }
 
-commonDropdownUpdateItem($_POST);
+Ajax::commonDropdownUpdateItem($_POST);
 ?>
