@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entitytree.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: entitytree.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,9 +37,9 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (!isset($_GET['target'])) {
    $_GET['target'] = $CFG_GLPI['root_doc']."/front/central.php";
@@ -47,6 +47,5 @@ if (!isset($_GET['target'])) {
 
 Entity::showSelector($_GET['target'], "activeentity");
 
-ajaxFooter();
-
-?>
+Html::ajaxFooter();
+?>
\ No newline at end of file
