@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: genericdate.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: genericdate.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,20 +38,19 @@ include (GLPI_ROOT."/inc/includes.php");
 
 // Send UTF8 Headers
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_POST['value']) && strcmp($_POST['value'],'0')==0) {
 
    if ($_POST['withtime']) {
-      showDateTimeFormItem($_POST['name'], $_POST['specificvalue']);
+      Html::showDateTimeFormItem($_POST['name'], $_POST['specificvalue']);
    } else {
-      showDateFormItem($_POST['name'], $_POST['specificvalue']);
+      Html::showDateFormItem($_POST['name'], $_POST['specificvalue']);
    }
 
 } else {
    echo "<input type='hidden' name='".$_POST['name']."' value='".$_POST['value']."'>";
 }
-
 ?>
\ No newline at end of file
