@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: inputtext.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: inputtext.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,14 +38,15 @@ define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_POST['name'])) {
    echo "<input type='text' ".(isset($_POST["size"])?" size='".$_POST["size"]."' ":"")." ".
          (isset($_POST["maxlength"])?"maxlength='".$_POST["maxlength"]."' ":"")." name='".
-         $_POST['name']."' value=\"".cleanInputText(rawurldecode(stripslashes($_POST["data"])))."\">";
+         $_POST['name']."' value=\"".
+         Html::cleanInputText(rawurldecode(stripslashes($_POST["data"])))."\">";
 }
 
 ?>
