@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleaction.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ruleaction.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,14 +37,14 @@ if (strpos($_SERVER['PHP_SELF'],"ruleaction.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
    die("Can not acces directly to this file");
 }
 
-checkLoginUser();
+Session::checkLoginUser();
 
 // Non define case
 if (isset($_POST["sub_type"]) && class_exists($_POST["sub_type"])) {
@@ -62,12 +62,11 @@ if (isset($_POST["sub_type"]) && class_exists($_POST["sub_type"])) {
                          'field'       => $_POST["field"],
                          'sub_type'    => $_POST["sub_type"]);
 
-   ajaxUpdateItemOnSelectEvent("dropdown_action_type$randaction", "action_type_span$randaction",
-                               $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php", $paramsaction,
-                               false);
+   Ajax::updateItemOnSelectEvent("dropdown_action_type$randaction", "action_type_span$randaction",
+                                 $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php", $paramsaction);
 
-   ajaxUpdateItem("action_type_span$randaction", $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",
-                  $paramsaction, false, "dropdown_action_type$randaction");
+   Ajax::updateItem("action_type_span$randaction", $CFG_GLPI["root_doc"]."/ajax/ruleactionvalue.php",
+                    $paramsaction, "dropdown_action_type$randaction");
 }
 
 ?>
