@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteria.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rulecriteria.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,17 +37,17 @@ if (strpos($_SERVER['PHP_SELF'],"rulecriteria.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
    die("Can not acces directly to this file");
 }
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_POST["sub_type"])) {
-   $rule      = new $_POST["sub_type"];
+   $rule      = new $_POST["sub_type"]();
    $criterias = $rule->getCriterias();
 
    if (count($criterias)) {
@@ -55,17 +55,13 @@ if (isset($_POST["sub_type"])) {
       if (!isset($_POST["criteria"])) {
          $_POST["criteria"] = key($criterias);
       }
-      $type = "";
-
-      if (isset($criterias[$_POST["criteria"]]['type'])) {
-         $type = $criterias[$_POST["criteria"]]['type'];
-      }
 
       if (isset($criterias[$_POST["criteria"]]['allow_condition'])) {
          $allow_condition = $criterias[$_POST["criteria"]]['allow_condition'];
       } else {
          $allow_condition = array();
       }
+
       $randcrit = RuleCriteria::dropdownConditions($_POST["sub_type"],
                                                    array('criterion'        => $_POST["criteria"],
                                                          'allow_conditions' => $allow_condition));
@@ -78,12 +74,13 @@ if (isset($_POST["sub_type"])) {
                               'criteria'  => $_POST["criteria"],
                               'sub_type'  => $_POST["sub_type"]);
 
-      ajaxUpdateItemOnSelectEvent("dropdown_condition$randcrit", "condition_span$randcrit",
-                                  $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
-                                  $paramscriteria, false);
+      Ajax::updateItemOnSelectEvent("dropdown_condition$randcrit", "condition_span$randcrit",
+                                    $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
+                                    $paramscriteria);
 
-      ajaxUpdateItem("condition_span$randcrit", $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php",
-                     $paramscriteria, false, "dropdown_condition$randcrit");
+      Ajax::updateItem("condition_span$randcrit",
+                       $CFG_GLPI["root_doc"]."/ajax/rulecriteriavalue.php", $paramscriteria,
+                       "dropdown_condition$randcrit");
    }
 }
 
