@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: searchoptionvalue.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: searchoptionvalue.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,17 +37,23 @@ if (strpos($_SERVER['PHP_SELF'],"searchoptionvalue.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
 if (!defined('GLPI_ROOT')) {
    die("Can not acces directly to this file");
 }
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_REQUEST['searchtype'])) {
    $searchopt         = unserialize(stripslashes($_REQUEST['searchopt']));
+   
+   /// TODO clean it : used for glpi_complete_entites
+   if (isset($searchopt['realtable']) && !empty($searchopt['realtable'])) {
+      $searchopt['table'] = $searchopt['realtable'];
+   }
+   
    $_REQUEST['value'] = rawurldecode(stripslashes($_REQUEST['value']));
 
    $addmeta = "";
@@ -63,6 +69,7 @@ if (isset($_REQUEST['searchtype'])) {
       case "notequals" :
       case "morethan" :
       case "lessthan" :
+      case "under" :
         // Specific cases with linkfield
 //         if (!$display && isset($searchopt['linkfield'])) {
 //             // Specific cases
@@ -108,13 +115,59 @@ if (isset($_REQUEST['searchtype'])) {
         if (!$display && isset($searchopt['field'])) {
             // Specific cases
             switch ($searchopt['table'].".".$searchopt['field']) {
+               case "glpi_reminders.state" :
+                  Planning::dropdownState($inputname, $_REQUEST['value']);
+                  $display = true;
+                  break;
+
+
+               case "glpi_changes.status" :
+                  Change::dropdownStatus($inputname, $_REQUEST['value'], 1);
+                  $display = true;
+                  break;
+
+               case "glpi_changes.priority" :
+                  Change::dropdownPriority($inputname, $_REQUEST['value'], true, true);
+                  $display = true;
+                  break;
+
+               case "glpi_changes.impact" :
+                  Change::dropdownImpact($inputname, $_REQUEST['value'], true);
+                  $display = true;
+                  break;
+
+               case "glpi_changes.urgency" :
+                  Change::dropdownUrgency($inputname, $_REQUEST['value'], true);
+                  $display = true;
+                  break;
+
+               case "glpi_problems.status" :
+                  Problem::dropdownStatus($inputname, $_REQUEST['value'], 1);
+                  $display = true;
+                  break;
+
+               case "glpi_problems.priority" :
+                  Problem::dropdownPriority($inputname, $_REQUEST['value'], true, true);
+                  $display = true;
+                  break;
+
+               case "glpi_problems.impact" :
+                  Problem::dropdownImpact($inputname, $_REQUEST['value'], true);
+                  $display = true;
+                  break;
+
+               case "glpi_problems.urgency" :
+                  Problem::dropdownUrgency($inputname, $_REQUEST['value'], true);
+                  $display = true;
+                  break;
+
                case "glpi_tickets.status" :
                   Ticket::dropdownStatus($inputname, $_REQUEST['value'], 1);
                   $display = true;
                   break;
 
                case "glpi_tickets.type" :
-                  Ticket::dropdownType($inputname, $_REQUEST['value']);
+                  Ticket::dropdownType($inputname, array('value' => $_REQUEST['value']));
                   $display = true;
                   break;
 
@@ -193,16 +246,20 @@ if (isset($_REQUEST['searchtype'])) {
 
                   case "date" :
                   case "date_delay" :
-                     showGenericDateTimeSearch($inputname, $_REQUEST['value'], false,
-                                               (isset($searchopt['maybefuture'])
-                                                && $searchopt['maybefuture']));
+                     Html::showGenericDateTimeSearch($inputname, $_REQUEST['value'],
+                                                     array('with_time'   => false,
+                                                           'with_future'
+                                                               => (isset($searchopt['maybefuture'])
+                                                                   && $searchopt['maybefuture'])));
                      $display = true;
                      break;
 
                   case "datetime" :
-                     showGenericDateTimeSearch($inputname, $_REQUEST['value'], true,
-                                               (isset($searchopt['maybefuture'])
-                                                      && $searchopt['maybefuture']));
+                     Html::showGenericDateTimeSearch($inputname, $_REQUEST['value'],
+                                                     array('with_time'   => true,
+                                                           'with_future'
+                                                               => (isset($searchopt['maybefuture'])
+                                                                   && $searchopt['maybefuture'])));
                      $display = true;
                      break;
                }
@@ -225,10 +282,12 @@ if (isset($_REQUEST['searchtype'])) {
                switch ($searchopt['field']) {
                   case "name" :
                   case "completename" :
+                     $cond = (isset($searchopt['condition']) ? $searchopt['condition'] : '');
                      Dropdown::show(getItemTypeForTable($searchopt['table']),
-                                    array('value'    => $_REQUEST['value'],
-                                          'name'     => $inputname,
-                                          'comments' => 0));
+                                    array('value'     => $_REQUEST['value'],
+                                          'name'      => $inputname,
+                                          'comments'  => 0,
+                                          'condition' => $cond));
                      $display = true;
                      break;
                }
@@ -240,7 +299,7 @@ if (isset($_REQUEST['searchtype'])) {
    // Default case : text field
    if (!$display) {
         echo "<input type='text' size='13' name='$inputname' value=\"".
-               cleanInputText($_REQUEST['value'])."\">";
+               Html::cleanInputText($_REQUEST['value'])."\">";
    }
 }
 
