@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: textarea.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: textarea.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,15 +37,14 @@ $AJAX_INCLUDE=1;
 define('GLPI_ROOT','..');
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_POST['name'])) {
    echo "<textarea ".(isset($_POST['rows'])?" rows='".$_POST['rows']."' ":"")." ".
          (isset($_POST['cols'])?" cols='".$_POST['cols']."' ":"")."  name='".$_POST['name']."'>";
-   echo cleanPostForTextArea(rawurldecode($_POST["data"]));
+   echo Html::cleanPostForTextArea(rawurldecode($_POST["data"]));
    echo "</textarea>";
 }
-
 ?>
\ No newline at end of file
