@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: uemailUpdate.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: uemailUpdate.php 17500 2012-02-14 13:04:43Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,18 +37,25 @@ if (strpos($_SERVER['PHP_SELF'],"uemailUpdate.php")) {
    define('GLPI_ROOT','..');
    include (GLPI_ROOT."/inc/includes.php");
    header("Content-Type: text/html; charset=UTF-8");
-   header_nocache();
+   Html::header_nocache();
 }
 
-checkLoginUser();
-// print_r($_REQUEST);
+Session::checkLoginUser();
+
 if ((isset($_REQUEST['field']) && $_REQUEST["value"]>0)
     || (isset($_REQUEST['allow_email']) && $_REQUEST['allow_email'])) {
-   $user = new User;
-   $email = "";
+   $user          = new User();
+   $default_email = "";
+   $emails        = array();
    if ($user->getFromDB($_REQUEST["value"])) {
-      $email = $user->getField('email');
+      $default_email = $user->getDefaultEmail();
+      $emails        = $user->getAllEmails();
    }
+   
+   if (isset($_REQUEST['alternative_email']) && !empty($_REQUEST['alternative_email'])
+      && empty($default_email)) {
+      $default_email = $_REQUEST['alternative_email'];
+   }   
 
    echo $LANG['job'][19].'&nbsp;:&nbsp;';
 
@@ -60,14 +67,30 @@ if ((isset($_REQUEST['field']) && $_REQUEST["value"]>0)
    $rand = Dropdown::showYesNo($_REQUEST['field'].'[use_notification]', $default_notif);
 
    echo '<br>'.$LANG['mailing'][118]."&nbsp;:&nbsp;";
-   if (!empty($email) && NotificationMail::isUserAddressValid($email)) {
-      echo $email;
+   // Only one email
+   if (count($emails) ==  1
+       && !empty($default_email)
+       && NotificationMail::isUserAddressValid($default_email)) {
+      echo $default_email;
+      // Clean alternative email
+      echo "<input type='hidden' size='25' name='".$_REQUEST['field']."[alternative_email]'
+            value=''>";
+
+   } else if (count($emails) > 1) {
+      // Several emails : select in the list
+      echo "<select name='".$_REQUEST['field']."[alternative_email]' value=''>";
+      echo "<option value='' selected>$default_email</option>";
+      foreach ($emails as $new_email) {
+         if ($new_email != $default_email) {
+            echo "<option value='$new_email'>$new_email</option>";
+         }
+      }
+      echo "</select>";
    } else {
       echo "<input type='text' size='25' name='".$_REQUEST['field']."[alternative_email]'
-            value='$email'>";
+            value='$default_email'>";
    }
-
 }
-commonDropdownUpdateItem($_POST);
 
+Ajax::commonDropdownUpdateItem($_POST);
 ?>
\ No newline at end of file
