@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: updateMetaSearch.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: updateMetaSearch.php 18536 2012-05-25 11:19:35Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -53,6 +53,7 @@ echo "<select id='Search2".$_POST["itemtype"].$_POST["num"]."' name='field2[".$_
 foreach ($searchopt as $key => $val) {
 
    // print groups
+   $str_limit   = 28; // not use $_SESSION['glpidropdown_chars_limit'] because it came to too short
    if (!is_array($val)) {
       if (!empty($newgroup) && $items_in_group>0) {
          echo $newgroup;
@@ -63,6 +64,7 @@ foreach ($searchopt as $key => $val) {
       if (!$first_group) {
          $newgroup .= "</optgroup>";
       }
+      $val       = Toolbox::substr($val, 0, $str_limit);
       $newgroup .= "<optgroup label=\"$val\">";
 
    } else {
@@ -73,8 +75,7 @@ foreach ($searchopt as $key => $val) {
          if ($key == $_POST["field"]) {
             $newgroup .= "selected";
          }
-         $newgroup .= ">". Toolbox::substr($val["name"], 0,
-                                           $_SESSION['glpidropdown_chars_limit']) ."</option>\n";
+         $newgroup .= ">". Toolbox::substr($val["name"], 0, $str_limit) ."</option>\n";
          $items_in_group++;
       }
    }
