@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: updateTrackingDeviceType.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: updateTrackingDeviceType.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,11 +37,10 @@ define('GLPI_ROOT','..');
 
 include (GLPI_ROOT."/inc/includes.php");
 header("Content-Type: text/html; charset=UTF-8");
-header_nocache();
+Html::header_nocache();
 
-checkRight("update_ticket", "1");
+Session::checkRight("update_ticket", "1");
 Ticket::dropdownMyDevices($_POST["userID"], $_POST["entity_restrict"]);
 
-ajaxFooter();
-
-?>
+Html::ajaxFooter();
+?>
\ No newline at end of file
