@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: based_config.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: based_config.php 18773 2012-06-29 09:31:34Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -141,4 +141,12 @@ if (!defined("GLPI_FONT_FREESANS")) {
    # if FreeSans.ttf available in system, use (in config_path.php)
    # define("GLPI_FONT_FREESANS", '/usr/share/fonts/gnu-free/FreeSans.ttf');
 }
+
+// Default patch to htmLawed
+if (!defined('GLPI_HTMLAWED')) {
+   define('GLPI_HTMLAWED', GLPI_ROOT.'/lib/htmlawed/htmLawed.php');
+
+   # if htmLawed available in system, use (in config_path.php)
+   # define('GLPI_HTMLAWED', '/usr/share/htmlawed/htmLawed.php');
+}
 ?>
