@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: config.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -123,8 +123,10 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
 
    if ($config_ok) {
       $CFG_GLPI = array_merge($CFG_GLPI,$config_object->fields);
-      $CFG_GLPI['priority_matrix'] = importArrayFromDB($config_object->fields['priority_matrix'],
-                                                       true);
+      if (isset($config_object->fields['priority_matrix'])) {
+         $CFG_GLPI['priority_matrix'] = importArrayFromDB($config_object->fields['priority_matrix'],
+                                                          true);
+      }
       // Path for icon of document type
       $CFG_GLPI["typedoc_icon_dir"] = $CFG_GLPI["root_doc"]."/pics/icones";
 
@@ -133,6 +135,15 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
       exit();
    }
 
+   if (isCommandLine() && isset($_SERVER['argv'])) {
+      $key = array_search('--debug', $_SERVER['argv']);
+      if ($key) {
+         $_SESSION['glpi_use_mode'] = Session::DEBUG_MODE;
+         unset($_SERVER['argv'][$key]);
+         $_SERVER['argv']= array_values($_SERVER['argv']);
+         $_SERVER['argc']--;
+      }
+   }
    // If debug mode activated : display some informations
    if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE) {
       // display_errors only need for for E_ERROR, E_PARSE, ... which cannot be catched
@@ -144,7 +155,11 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
    } else {
       // Recommended production settings
       ini_set('display_errors','Off');
-      error_reporting(E_ALL);
+      if (defined('E_DEPRECATED')) {
+         error_reporting(E_ALL & ~E_DEPRECATED & ~E_STRICT);
+      } else {
+         error_reporting(E_ALL & ~E_STRICT);
+      }
       set_error_handler(array('Toolbox', 'userErrorHandlerNormal'));
    }
 
@@ -174,23 +189,24 @@ if (!file_exists(GLPI_CONFIG_DIR . "/config_db.php")) {
          $error = Toolbox::commonCheckForUseGLPI();
          echo "</table><br>";
 
-         if (!$error) {
+         if ($error) {
+            echo "<form action='".$CFG_GLPI["root_doc"]."/index.php' method='post'>";
+            echo "<input type='submit' name='submit' class='submit' value=\"".
+                   $LANG['install'][27]."\">";
+            Html::closeForm();
+         }
+         if ($error < 2) {
             if (!isset($CFG_GLPI["version"]) || trim($CFG_GLPI["version"])<GLPI_VERSION) {
                echo "<form method='post' action='".$CFG_GLPI["root_doc"]."/install/update.php'>";
                echo "<p class='red'>".$LANG['update'][88]."</p>";
                echo "<input type='submit' name='from_update' value=\"".$LANG['install'][4].
                       "\" class='submit'>";
-               echo "</form>";
+               Html::closeForm();
 
             } else if (trim($CFG_GLPI["version"])>GLPI_VERSION) {
                echo "<p class='red'>".$LANG['update'][89]."</p>";
             }
 
-         } else {
-            echo "<form action='".$CFG_GLPI["root_doc"]."/index.php' method='post'>";
-            echo "<input type='submit' name='submit' class='submit' value=\"".
-                   $LANG['install'][27]."\">";
-            echo "</form>";
          }
 
          echo "</div>";
