@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: define.php 17288 2012-01-31 10:35:07Z moyo $
+ * @version $Id: define.php 18892 2012-07-12 09:15:18Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -28,9 +28,12 @@
 */
 
 // Current version of GLPI
-define("GLPI_VERSION","0.83");
+define("GLPI_VERSION","0.83.31");
 define("GLPI_DEMO_MODE","0");
 
+define("GLPI_USE_CSRF_CHECK", "1");
+define("GLPI_CSRF_EXPIRES","7200");
+define("GLPI_CSRF_MAX_TOKENS","100");
 
 // dictionnaries
 // 0 Name - 1 lang file - 2 extjs - 3 tiny_mce - 4 english lang name
@@ -97,7 +100,7 @@ define("MONTH_TIMESTAMP",2592000);
 // ITEMS TYPE
 /// Temporary definition for test
 // TODO clean it.
-if (!strstr($_SERVER['PHP_SELF'],"/install/")) {
+if (!strstr($_SERVER['PHP_SELF'], "/install/") && !strstr($_SERVER['PHP_SELF'], '/cliupdate')) {
    define("GENERAL_TYPE",'');
    define("COMPUTER_TYPE",'Computer');
    define("NETWORKING_TYPE",'NetworkEquipment');
@@ -296,6 +299,7 @@ $CFG_GLPI["debug_sql"] = $CFG_GLPI["debug_vars"] = $CFG_GLPI["debug_lang"] = 1;
 
 // User Prefs fields which override $CFG_GLPI config
 $CFG_GLPI['user_pref_field'] = array('csv_delimiter', 'date_format', 'default_requesttypes_id',
+                                     'display_count_on_home',
                                      'dropdown_chars_limit', 'followup_private',
                                      'is_categorized_soft_expanded', 'is_ids_visible',
                                      'is_not_categorized_soft_expanded', 'language', 'list_limit',
