@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: auth.others.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: auth.others.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,24 +36,23 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("config", "w");
+Session::checkRight("config", "w");
 
 $config = new Config();
 
 //Update CAS configuration
-if (isset ($_POST["update"])) {
+if (isset($_POST["update"])) {
    $config->update($_POST);
-   glpi_header($CFG_GLPI["root_doc"] . "/front/auth.others.php");
+   Html::redirect($CFG_GLPI["root_doc"] . "/front/auth.others.php");
 }
 
 if (!isset($_GET["id"])) {
    $_GET["id"]="";
 }
 
-commonHeader($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others");
+Html::header($LANG['title'][14], $_SERVER['PHP_SELF'],"config","extauth","others");
 
-showOtherAuthList($_SERVER['PHP_SELF']);
+Auth::showOtherAuthList();
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
