@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridgeitem.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: cartridgeitem.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,11 +36,11 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("cartridge", "r");
+Session::checkRight("cartridge", "r");
 
-commonHeader($LANG['Menu'][21],$_SERVER['PHP_SELF'],"inventory","cartridge");
+Html::header($LANG['Menu'][21],$_SERVER['PHP_SELF'],"inventory","cartridge");
 
 Search::show('CartridgeItem');
 
-commonFooter();
-?>
+Html::footer();
+?>
\ No newline at end of file
