@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: central.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: central.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,18 +36,22 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT."/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 // Change profile system
-if (isset ($_POST['newprofile'])) {
-   if (isset ($_SESSION["glpiprofiles"][$_POST['newprofile']])) {
-      changeProfile($_POST['newprofile']);
+if (isset($_POST['newprofile'])) {
+   if (isset($_SESSION["glpiprofiles"][$_POST['newprofile']])) {
+      Session::changeProfile($_POST['newprofile']);
       if ($_SESSION["glpiactiveprofile"]["interface"] == "helpdesk") {
-         glpi_header($CFG_GLPI['root_doc']."/front/helpdesk.public.php");
+         if ($_SESSION['glpiactiveprofile']['create_ticket_on_login']) {
+            Html::redirect($CFG_GLPI['root_doc'] . "/front/helpdesk.public.php?create_ticket=1");
+         } else {
+            Html::redirect($CFG_GLPI['root_doc']."/front/helpdesk.public.php");
+         }
       }
-      glpi_header($_SERVER['PHP_SELF']);
+      Html::redirect($_SERVER['PHP_SELF']);
    }
-   glpi_header(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
+   Html::redirect(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
 }
 
 // Manage entity change
@@ -55,24 +59,23 @@ if (isset($_GET["active_entity"])) {
    if (!isset($_GET["is_recursive"])) {
       $_GET["is_recursive"] = 0;
    }
-   if (changeActiveEntities($_GET["active_entity"],$_GET["is_recursive"])) {
+   if (Session::changeActiveEntities($_GET["active_entity"],$_GET["is_recursive"])) {
       if (($_GET["active_entity"] == $_SESSION["glpiactive_entity"])
           && isset($_SERVER['HTTP_REFERER'])) {
-         glpi_header(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
+         Html::redirect(preg_replace("/entities_id.*/","",$_SERVER['HTTP_REFERER']));
       }
    }
 }
 
-commonHeader($LANG['common'][56],$_SERVER['PHP_SELF']);
+Html::header($LANG['common'][56],$_SERVER['PHP_SELF']);
 
 // Redirect management
 if (isset($_GET["redirect"])) {
-   manageRedirect($_GET["redirect"]);
+   Toolbox::manageRedirect($_GET["redirect"]);
 }
 
 $central = new Central();
 $central->show();
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
