@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: contract.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,12 +36,11 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("contract","r");
+Session::checkRight("contract", "r");
 
-commonHeader($LANG['Menu'][25],$_SERVER['PHP_SELF'],"financial","contract");
+Html::header($LANG['Menu'][25],$_SERVER['PHP_SELF'],"financial","contract");
 
 Search::show('Contract');
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
