@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: control.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: control.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,5 +35,5 @@
 
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
-glpi_header (GLPI_ROOT . "/front/fieldunicity.php");
+Html::redirect (GLPI_ROOT . "/front/fieldunicity.php");
 ?>
