@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cron.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: cron.php 18765 2012-06-29 05:40:19Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,6 +36,7 @@
 chdir(dirname($_SERVER["SCRIPT_FILENAME"]));
 
 
+define('DO_NOT_CHECK_HTTP_REFERER', 1);
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
@@ -64,13 +65,17 @@ if (!isCommandLine()) {
 } else if (isset($_SERVER['argc']) && $_SERVER['argc']>1) {
    // TODO Warning : command line is cron.php 1 2 3 4 : will produce cron.php 10 !
    // Parse command line options
+
+   $mode = CronTask::MODE_EXTERNAL; // when taskname given, will allow --force
    for ($i=1 ; $i<$_SERVER['argc'] ; $i++) {
-      if (is_numeric($_SERVER['argv'][$i])) {
+      if ($_SERVER['argv'][$i] == '--force') {
+         $mode = -CronTask::MODE_EXTERNAL;
+      } else if (is_numeric($_SERVER['argv'][$i])) {
          // Number of tasks
          CronTask::launch(CronTask::MODE_EXTERNAL, intval($_SERVER['argv'][$i]));
       } else {
          // Task name
-         CronTask::launch(CronTask::MODE_EXTERNAL, $CFG_GLPI['cron_limit'], $_SERVER['argv'][$i]);
+         CronTask::launch($mode, $CFG_GLPI['cron_limit'], $_SERVER['argv'][$i]);
       }
    }
 
