@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: crontask.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: crontask.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,36 +35,35 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("config", "w");
+Session::checkRight("config", "w");
 
 $crontask = new CronTask();
 
 if (isset($_POST["update"])) {
-   checkRight('config','w');
+   Session::checkRight('config', 'w');
    $crontask->update($_POST);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_GET['resetdate']) && isset($_GET["id"])) {
-   checkRight('config','w');
+   Session::checkRight('config', 'w');
    if ($crontask->getFromDB($_GET["id"])) {
        $crontask->resetDate();
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_GET['resetstate']) && isset($_GET["id"])) {
-   checkRight('config','w');
+   Session::checkRight('config', 'w');
    if ($crontask->getFromDB($_GET["id"])) {
        $crontask->resetState();
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 }else {
    if (!isset($_GET["id"]) || empty($_GET["id"])) {
       exit();
    }
-   commonHeader($LANG['crontask'][0],$_SERVER['PHP_SELF'],"config","crontask");
+   Html::header($LANG['crontask'][0],$_SERVER['PHP_SELF'],"config","crontask");
    $crontask->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
