@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dictionnary.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dictionnary.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,25 +35,25 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkSeveralRightsOr(array('rule_dictionnary_dropdown' => 'r',
-                           'rule_dictionnary_software' => 'r'));
+Session::checkSeveralRightsOr(array('rule_dictionnary_dropdown' => 'r',
+                                    'rule_dictionnary_software' => 'r'));
 
-commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"admin","dictionnary",-1);
+Html::header($LANG['common'][12],$_SERVER['PHP_SELF'],"admin","dictionnary",-1);
 
 echo "<div class='center'><table class='tab_cadre'>";
 echo "<tr><th colspan='4'>" . $LANG['rulesengine'][77] . "</th></tr>";
 echo "<tr class='tab_bg_1'><td class='top'><table class='tab_cadre'>";
 echo "<tr><th>".$LANG['rulesengine'][80]."</th></tr>";
 
-if (haveRight("rule_dictionnary_software","r")) {
+if (Session::haveRight("rule_dictionnary_software","r")) {
    echo "<tr class='tab_bg_1'><td class='center b'>";
    echo "<a href=\"ruledictionnarysoftware.php\">" . $LANG['rulesengine'][35] ."</a></td></tr>";
 }
-if (haveRight("rule_dictionnary_dropdown","r")) {
+if (Session::haveRight("rule_dictionnary_dropdown","r")) {
    echo "<tr class='tab_bg_1'><td class='center b'>";
    echo "<a href=\"ruledictionnarymanufacturer.php\">" . $LANG['rulesengine'][36] ."</a></td></tr>";
 }
-if (haveRight("rule_dictionnary_printer","r")) {
+if (Session::haveRight("rule_dictionnary_printer","r")) {
    echo "<tr class='tab_bg_1'><td class='center b'>";
    echo "<a href=\"ruledictionnaryprinter.php\">" . $LANG['rulesengine'][39] ."</a></td></tr>";
 }
@@ -61,7 +61,7 @@ if (haveRight("rule_dictionnary_printer","r")) {
 echo "</table></td>";
 
 echo "<td class='top'><table class='tab_cadre'>";
-if (haveRight("rule_dictionnary_dropdown","r")) {
+if (Session::haveRight("rule_dictionnary_dropdown","r")) {
    echo "<tr><th>".$LANG['rulesengine'][56]."</th></tr>";
    echo "<tr class='tab_bg_1'><td class='center b'>".
          "<a href='ruledictionnarycomputermodel.php'>" . $LANG['rulesengine'][50] . "</a></td>";
@@ -79,7 +79,7 @@ if (haveRight("rule_dictionnary_dropdown","r")) {
 echo "</table></td>";
 
 echo "<td class='top'><table class='tab_cadre'>";
-if (haveRight("rule_dictionnary_dropdown","r")) {
+if (Session::haveRight("rule_dictionnary_dropdown","r")) {
    echo "<tr><th>".$LANG['rulesengine'][66]."</th></tr>";
    echo "<tr class='tab_bg_1'><td class='center b'>".
          "<a href='ruledictionnarycomputertype.php'>" . $LANG['rulesengine'][60] . "</a></td>";
@@ -97,7 +97,7 @@ if (haveRight("rule_dictionnary_dropdown","r")) {
 echo "</table></td>";
 
 echo "<td class='top'><table class='tab_cadre'>";
-if (haveRight("rule_dictionnary_dropdown","r")) {
+if (Session::haveRight("rule_dictionnary_dropdown","r")) {
    echo "<tr><th>".$LANG['computers'][9]."</th></tr>";
    echo "<tr class='tab_bg_1'><td class='center b'>".
          "<a href='ruledictionnaryoperatingsystem.php'>" . $LANG['rulesengine'][67] . "</a></td></tr>";
@@ -109,6 +109,5 @@ if (haveRight("rule_dictionnary_dropdown","r")) {
 echo "</table></td></tr>";
 
 echo "</table></div>";
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
