@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: documenttype.list.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: documenttype.list.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -31,13 +31,12 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkLoginUser();
+Session::checkLoginUser();
 
-popHeader($LANG['common'][12],$_SERVER['PHP_SELF']);
+Html::popHeader($LANG['common'][12],$_SERVER['PHP_SELF']);
 
 Search::manageGetValues('DocumentType');
 Search::showList('DocumentType',$_GET);
 
-popFooter();
-
-?>
+Html::popFooter();
+?>
\ No newline at end of file
