@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.common.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdown.common.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -34,15 +34,15 @@
 
 
 if (!($dropdown instanceof CommonDropdown)) {
-   displayErrorAndDie('');
+   Html::displayErrorAndDie('');
 }
 if (!$dropdown->canView()) {
-   // Gestion timeout session
-   if (!getLoginUserID()) {
-      glpi_header($CFG_GLPI["root_doc"] . "/index.php");
-      exit ();
+      // Gestion timeout session
+   if (!Session::getLoginUserID()) {
+      Html::redirect($CFG_GLPI["root_doc"] . "/index.php");
+      exit();
    }
-   displayRightError();
+   Html::displayRightError();
 }
 
 
@@ -66,15 +66,15 @@ if (isset($_POST["add"])) {
                     $_SESSION["glpiname"]." added ".$_POST["name"].".");
       }
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $dropdown->check($_POST["id"],'w');
    if ($dropdown->isUsed() && empty($_POST["forcedelete"])) {
-      commonHeader($dropdown->getTypeName(), $_SERVER['PHP_SELF'], "config",
+      Html::header($dropdown->getTypeName(), $_SERVER['PHP_SELF'], "config",
                    $dropdown->second_level_menu, str_replace('glpi_','',$dropdown->getTable()));
       $dropdown->showDeleteConfirmForm($_SERVER['PHP_SELF']);
-      commonFooter();
+      Html::footer();
    } else {
       $dropdown->delete($_POST, 1);
       $dropdown->refreshParentInfos();
@@ -100,33 +100,34 @@ if (isset($_POST["add"])) {
 
    Event::log($_POST["id"], get_class($dropdown), 4, "setup",
               $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
-} else if (isset($_POST["execute"])) {
-   if (method_exists($dropdown, $_POST["_method"])) {
-      call_user_func(array(&$dropdown, $_POST["_method"]), $_POST);
-      glpi_header($_SERVER['HTTP_REFERER']);
+} else if (isset($_POST['execute']) && isset($_POST['_method'])) {
+   $method = 'execute'.$_POST['_method'];
+   if (method_exists($dropdown, $method)) {
+      call_user_func(array(&$dropdown, $method), $_POST);
+      Html::back();
    } else {
-      displayErrorAndDie($LANG['common'][24]);
+      Html::displayErrorAndDie($LANG['common'][24]);
    }
 
 } else if (isset($_GET['popup'])) {
-   popHeader($dropdown->getTypeName(),$_SERVER['PHP_SELF']);
+   Html::popHeader($dropdown->getTypeName(),$_SERVER['PHP_SELF']);
    if (isset($_GET["rand"])) {
       $_SESSION["glpipopup"]["rand"]=$_GET["rand"];
    }
    $dropdown->showForm($_GET["id"]);
    echo "<div class='center'><br><a href='javascript:window.close()'>".$LANG['buttons'][13]."</a>";
    echo "</div>";
-   popFooter();
+   Html::popFooter();
 
 } else {
    $dropdown->displayHeader();
+
    if (!isset($options)) {
       $options = array();
    }
    $dropdown->showForm($_GET["id"],$options);
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
