@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dropdown.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -32,12 +32,13 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
+
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkLoginUser();
+Session ::checkLoginUser();
 
-commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","dropdowns");
+Html::header($LANG['common'][12],$_SERVER['PHP_SELF'],"config","dropdowns");
 
 echo "<div align='center'>";
 
@@ -46,5 +47,5 @@ Dropdown::showItemTypeMenu($LANG['setup'][0], $optgroup);
 Dropdown::showItemTypeList($optgroup);
 
 echo "</div>";
-commonFooter();
-?>
+Html::footer();
+?>
\ No newline at end of file
