@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entitynotification.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: entitynotification.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -30,9 +30,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
-$data = new EntityNotification;
+$data = new EntityNotification();
 
 if (isset($_POST["add"])) {
    $data->check(-1,'w',$_POST);
@@ -40,7 +40,7 @@ if (isset($_POST["add"])) {
    if ($data->add($_POST)) {
       Event::log($_POST["entities_id"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["update"])) {
    $data->check($_POST["entities_id"],'w');
@@ -48,9 +48,8 @@ if (isset($_POST["add"])) {
    if ($data->update($_POST)) {
       Event::log($_POST["entities_id"], "entity", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 }
-displayErrorAndDie("lost");
-
-?>
+Html::displayErrorAndDie("lost");
+?>
\ No newline at end of file
