@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: fieldunicity.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: fieldunicity.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,9 +36,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight('config','r');
-commonHeader($LANG['setup'][811], $_SERVER['PHP_SELF'], "config", "control", "FieldUnicity");
+Session::checkRight('config', 'r');
+Html::header($LANG['setup'][811], $_SERVER['PHP_SELF'], "config", "control", "FieldUnicity");
 
 Search::show('FieldUnicity');
-commonFooter();
-?>
+Html::footer();
+?>
\ No newline at end of file
