@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.form.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: group.form.php 18680 2012-06-22 07:31:54Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -50,6 +50,7 @@ if (isset($_POST["add"])) {
       Event::log($newID, "groups", 4, "setup",
                  $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
    }
+   Ajax::refreshDropdownPopupInMainWindow();
    Html::back();
 
 } else if (isset($_POST["delete"])) {
@@ -147,6 +148,16 @@ if (isset($_POST["add"])) {
    }
    Html::back();
 
+} else if (isset($_GET['popup'])) {
+   Html::popHeader($LANG['Menu'][36],$_SERVER['PHP_SELF']);
+   if (isset($_GET["rand"])) {
+      $_SESSION["glpipopup"]["rand"] = $_GET["rand"];
+   }
+   $group->showForm($_GET["id"]);
+   echo "<div class='center'><br><a href='javascript:window.close()'>".$LANG['buttons'][13]."</a>";
+   echo "</div>";
+   Html::popFooter();
+
 } else {
    Html::header($LANG['Menu'][36],$_SERVER['PHP_SELF'],"admin","group");
    $group->showForm($_GET["id"]);
