@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: helpdesk.faq.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: helpdesk.faq.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,7 +38,7 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 // Redirect management
 if (isset($_GET["redirect"])) {
-   manageRedirect($_GET["redirect"]);
+   Toolbox::manageRedirect($_GET["redirect"]);
 }
 
 //*******************
@@ -46,13 +46,15 @@ if (isset($_GET["redirect"])) {
 //******************
 
 $name = "";
-checkFaqAccess();
-if (getLoginUserID()) {
-   helpHeader($LANG['Menu'][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
+Session:: checkFaqAccess();
+
+if (Session::getLoginUserID()) {
+   Html::helpHeader($LANG['Menu'][20],$_SERVER['PHP_SELF'],$_SESSION["glpiname"]);
 } else {
    $_SESSION["glpilanguage"] = $CFG_GLPI['language'];
    // Anonymous FAQ
-   simpleHeader($LANG['Menu'][20],array($LANG['Menu'][20] => $_SERVER['PHP_SELF']));
+   Html::simpleHeader($LANG['Menu'][20],array($LANG['login'][10] => $CFG_GLPI["root_doc"],
+                                              $LANG['Menu'][20]  => $_SERVER['PHP_SELF']));
 }
 
 if (!isset($_GET["contains"])) {
@@ -63,7 +65,7 @@ if (!isset($_GET["knowbaseitemcategories_id"])) {
 }
 
 if (isset($_GET["id"])) {
-   $kb = new KnowbaseItem;
+   $kb = new KnowbaseItem();
    if ($kb->getFromDB($_GET["id"])) {
       $kb->showFull(false);
    }
@@ -77,6 +79,5 @@ if (isset($_GET["id"])) {
    }
 }
 
-helpFooter();
-
-?>
+Html::helpFooter();
+?>
\ No newline at end of file
