@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: infocom.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -42,35 +42,34 @@ if (isset($_GET["add"])) {
 
    $newID = $ic->add($_GET, false);
    Event::log($newID, "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][20]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $ic->check($_POST["id"],'w');
 
    $ic->delete($_POST);
    Event::log($_POST["id"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["update"])) {
    $ic->check($_POST["id"],'w');
 
    $ic->update($_POST);
    Event::log($_POST["id"], "infocom", 4, "financial", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
-} else {
-   checkRight("infocom","r");
+   Html::back();
 
-   popHeader($LANG['financial'][3],$_SERVER['PHP_SELF']);
+} else {
+   Session::checkRight("infocom", "r");
+
+   Html::popHeader($LANG['financial'][3],$_SERVER['PHP_SELF']);
 
    if (isset($_GET["id"])) {
-      $ic = new Infocom();
       $ic->getFromDB($_GET["id"]);
       $_GET["itemtype"] = $ic->fields["itemtype"];
       $_GET["items_id"] = $ic->fields["items_id"];
    }
    $item = false;
-   if (isset($_GET["itemtype"]) && class_exists($_GET["itemtype"])) {
-      $item = new $_GET["itemtype"]();
+   if (isset($_GET["itemtype"]) && ($item = getItemForItemtype($_GET["itemtype"]))) {
       if (!isset($_GET["items_id"]) || !$item->getFromDB($_GET["items_id"])) {
          $item = false;
       }
@@ -81,9 +80,8 @@ if (isset($_GET["add"])) {
    } else {
       $withtemplate = 2;
    }
-   Infocom::showForItem($item,$withtemplate);
+   Infocom::showForItem($item, $withtemplate);
 
-   popFooter();
+   Html::popFooter();
 }
-
-?>
+?>
\ No newline at end of file
