@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: knowbaseitem.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: knowbaseitem.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,8 +38,11 @@ include (GLPI_ROOT . "/inc/includes.php");
 if (!isset($_GET["id"])) {
    $_GET["id"] = "";
 }
-if (!isset($_GET["tickets_id"])) {
-   $_GET["tickets_id"] = "";
+if (!isset($_GET["itemtype"])) {
+   $_GET["itemtype"] = "";
+}
+if (!isset($_GET["items_id"])) {
+   $_GET["items_id"] = "";
 }
 if (!isset($_GET["modify"])) {
    $_GET["modify"] = "";
@@ -54,14 +57,14 @@ if (!isset($_GET["removefromfaq"])) {
    $_GET["removefromfaq"] = "";
 }
 
-$kb = new KnowbaseItem;
+$kb = new KnowbaseItem();
 
 if ($_GET["id"] == "new") {
    // on affiche le formulaire de saisie de l'item
    $kb->check(-1,'w');
 
-   commonHeader($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
-   $available_options = array('tickets_id');
+   Html::header($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
+   $available_options = array('itemtype', 'items_id');
    $options           = array();
    foreach ($available_options as $key) {
       if (isset($_GET[$key])) {
@@ -69,7 +72,7 @@ if ($_GET["id"] == "new") {
       }
    }
    $kb->showForm("",$options);
-   commonFooter();
+   Html::footer();
 
 } else if (isset($_POST["add"])) {
    // ajoute un item dans la base de connaisssances
@@ -77,7 +80,7 @@ if ($_GET["id"] == "new") {
 
    $newID = $kb->add($_POST);
    Event::log($newID, "knowbaseitem", 5, "tools", $_SESSION["glpiname"]." ".$LANG['log'][20]);
-   glpi_header($CFG_GLPI["root_doc"]."/front/knowbaseitem.php");
+   Html::redirect($CFG_GLPI["root_doc"]."/front/knowbaseitem.php");
 
 } else if (isset($_POST["update"])) {
    // actualiser  un item dans la base de connaissances
@@ -85,15 +88,15 @@ if ($_GET["id"] == "new") {
 
    $kb->update($_POST);
    Event::log($_POST["id"], "knowbaseitem", 5, "tools", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($CFG_GLPI["root_doc"]."/front/knowbaseitem.form.php?id=".$_POST['id']);
+   Html::redirect($CFG_GLPI["root_doc"]."/front/knowbaseitem.form.php?id=".$_POST['id']);
 
 } else if (isset($_GET["id"]) && strcmp($_GET["modify"],"yes") == 0) {
    // modifier un item dans la base de connaissance
    $kb->check($_GET["id"],'r');
 
-   commonHeader($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
+   Html::header($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
    $kb->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 
 } else if (isset($_GET["id"]) && strcmp($_GET["delete"],"yes") == 0) {
    // effacer un item dans la base de connaissances
@@ -107,27 +110,101 @@ if ($_GET["id"] == "new") {
    // ajouter  un item dans la faq
    $kb->check($_GET["id"],'w');
    $kb->addToFaq();
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_GET["id"]) && strcmp($_GET["removefromfaq"],"yes") == 0) {
    // retirer  un item de la faq
    $kb->check($_GET["id"],'w');
    $kb->removeFromFaq($_GET["id"]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
+
+} else if (isset($_POST["addvisibility"])) {
+   if (isset($_POST["_type"]) && !empty($_POST["_type"])
+       && isset($_POST["knowbaseitems_id"]) && $_POST["knowbaseitems_id"]) {
+      $item = NULL;
+      switch ($_POST["_type"]) {
+         case 'User' :
+            if (isset($_POST['users_id']) && $_POST['users_id']) {
+               $item = new KnowbaseItem_User();
+            }
+            break;
+
+         case 'Group' :
+            if (isset($_POST['groups_id']) && $_POST['groups_id']) {
+               $item = new Group_KnowbaseItem();
+            }
+            break;
+
+         case 'Profile' :
+            if (isset($_POST['profiles_id']) && $_POST['profiles_id']) {
+               $item = new KnowbaseItem_Profile();
+            }
+            break;
+
+         case 'Entity' :
+            $item = new Entity_KnowbaseItem();
+            break;
+      }
+      if (!is_null($item)) {
+         $item->add($_POST);
+         Event::log($_POST["knowbaseitems_id"], "knowbaseitem", 4, "tools",
+                    $_SESSION["glpiname"]." ".$LANG['log'][68]);
+      }
+   }
+   Html::back();
+
+}  else if (isset($_POST["deletevisibility"])) {
+   if (isset($_POST["group"]) && count($_POST["group"])) {
+      $item = new Group_KnowbaseItem();
+      foreach ($_POST["group"] as $key => $val) {
+         if ($item->can($key,'w')) {
+            $item->delete(array('id' => $key));
+         }
+      }
+   }
+
+   if (isset($_POST["user"]) && count($_POST["user"])) {
+      $item = new KnowbaseItem_User();
+      foreach ($_POST["user"] as $key => $val) {
+         if ($item->can($key,'w')) {
+            $item->delete(array('id' => $key));
+         }
+      }
+   }
+
+   if (isset($_POST["entity"]) && count($_POST["entity"])) {
+      $item = new Entity_KnowbaseItem();
+      foreach ($_POST["entity"] as $key => $val) {
+         if ($item->can($key,'w')) {
+            $item->delete(array('id' => $key));
+         }
+      }
+   }
+
+   if (isset($_POST["profile"]) && count($_POST["profile"])) {
+      $item = new KnowbaseItem_Profile();
+      foreach ($_POST["profile"] as $key => $val) {
+         if ($item->can($key,'w')) {
+            $item->delete(array('id' => $key));
+         }
+      }
+   }
+   Event::log($_POST["knowbaseitems_id"], "knowbaseitem", 4, "tools",
+              $_SESSION["glpiname"]." ".$LANG['log'][67]);
+   Html::back();
 
 } else if (empty($_GET["id"])) {
    // No id or no tickets id to create from solution
-   glpi_header($CFG_GLPI["root_doc"]."/front/knowbaseitem.php");
+   Html::redirect($CFG_GLPI["root_doc"]."/front/knowbaseitem.php");
 
 } else {
    // Affiche un item de la base de connaissances
    $kb->check($_GET["id"],'r');
 
-   commonHeader($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
+   Html::header($LANG['title'][5],$_SERVER['PHP_SELF'],"utils","knowbase");
 
    $kb->showFull(true);
 
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
