@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap.group.import.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ldap.group.import.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,9 +38,9 @@ include (GLPI_ROOT . "/inc/includes.php");
 
 $group = new Group();
 $group->checkGlobal('w');
-checkRight('user_authtype','w');
+Session::checkRight('user_authtype', 'w');
 
-commonHeader($LANG['setup'][3], $_SERVER['PHP_SELF'], "admin", "group", "ldap");
+Html::header($LANG['setup'][3], $_SERVER['PHP_SELF'], "admin", "group", "ldap");
 
 if (isset($_GET['next'])) {
    AuthLdap::ldapChooseDirectory($_SERVER['PHP_SELF']);
@@ -51,7 +51,7 @@ if (isset($_GET['next'])) {
          $percent = min(100, round(100*($_SESSION["ldap_import_count"]-$count)
                                    /$_SESSION["ldap_import_count"], 0));
 
-         displayProgressBar(400, $percent);
+         Html::displayProgressBar(400, $percent);
          $key = array_pop($_SESSION["ldap_import"]);
 
          if (isset($_SESSION["ldap_import_entities"][$key])) {
@@ -65,13 +65,13 @@ if (isset($_GET['next'])) {
                                          "entities_id"  => $entity,
                                          "is_recursive" => $_SESSION["ldap_import_recursive"][$key],
                                          "type"         => $_SESSION["ldap_import_type"][$key]));
-         glpi_header($_SERVER['PHP_SELF']);
+         Html::redirect($_SERVER['PHP_SELF']);
 
       } else {
          unset($_SESSION["ldap_import"]);
-         displayProgressBar(400,100);
+         Html::displayProgressBar(400, 100);
 
-         echo "<div class='center b'>".$LANG['ocsng'][8]."<br>";
+         echo "<div class='center b'>".$LANG['ldap'][10]."<br>";
          echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a></div>";
       }
    }
@@ -83,7 +83,7 @@ if (isset($_GET['next'])) {
       if (isset($_POST["ldap_filter2"])) {
          $_SESSION["ldap_group_filter2"] = $_POST["ldap_filter2"];
       }
-      glpi_header($_SERVER['PHP_SELF']);
+      Html::redirect($_SERVER['PHP_SELF']);
 
    } else if (!isset($_POST["import_ok"])) {
       if (!isset($_GET['check'])) {
@@ -100,7 +100,7 @@ if (isset($_GET['next'])) {
          if (isset($_POST["ldap_server"])) {
             $_SESSION["ldap_server"] = $_POST["ldap_server"];
          } else {
-            glpi_header($CFG_GLPI["root_doc"]."/front/ldap.php");
+            Html::redirect($CFG_GLPI["root_doc"]."/front/ldap.php");
          }
       }
 
@@ -144,10 +144,9 @@ if (isset($_GET['next'])) {
             }
          }
       }
-      glpi_header($_SERVER['PHP_SELF']);
+      Html::redirect($_SERVER['PHP_SELF']);
    }
 }
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
