@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ldap.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("import_externalauth_users",'w');
+Session::checkRight("import_externalauth_users", 'w');
 
-commonHeader($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
+Html::header($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
 
 if (isset($_SESSION["ldap_sortorder"])) {
    unset($_SESSION["ldap_sortorder"]);
@@ -55,6 +55,5 @@ echo "<tr class='tab_bg_1'><td class='center b'><a href='ldap.import.php?mode=0&
 
 echo "</table></div>";
 
-commonFooter();
-
+Html::footer();
 ?>
\ No newline at end of file
