@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: link.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,12 +36,12 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
+Session::checkRight("link", "r");
+
 if (empty($_GET["id"])) {
    $_GET["id"] = "";
 }
 
-checkRight("link", "r");
-
 $link = new Link();
 
 if (isset($_POST["add"])) {
@@ -50,7 +50,7 @@ if (isset($_POST["add"])) {
    $newID = $link->add($_POST);
    Event::log($newID, "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]." ".
               $_POST["name"].".");
-   glpi_header(getItemTypeFormURL('Link')."?id=".$newID);
+   Html::redirect(Toolbox::getItemTypeFormURL('Link')."?id=".$newID);
 
 } else if (isset($_POST["delete"])) {
    $link->check($_GET["id"],'w');
@@ -62,13 +62,12 @@ if (isset($_POST["add"])) {
    $link->check($_GET["id"],'w');
    $link->update($_POST);
    Event::log($_GET["id"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else {
-   commonHeader($LANG['title'][33],$_SERVER['PHP_SELF'],"config","link");
+   Html::header($LANG['title'][33],$_SERVER['PHP_SELF'],"config","link");
 
    $link->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
