@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.send.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: link.send.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -30,7 +30,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("link","r");
+Session::checkRight("link", "r");
 
 if (isset($_GET["lID"])) {
    $query = "SELECT `glpi_links`.`id`, `glpi_links`.`link`, `glpi_links`.`data`
@@ -43,8 +43,7 @@ if (isset($_GET["lID"])) {
       $file = $DB->result($result,0,"data");
       $link = $DB->result($result,0,"link");
 
-      if (class_exists($_GET["itemtype"])) {
-         $item = new $_GET["itemtype"]();
+      if ($item = getItemForItemtype($_GET["itemtype"])) {
          if ($item->getFromDB($_GET["id"])) {
             $content_filename = Link::generateLinkContents($link, $item);
             $content_data     = Link::generateLinkContents($file, $item);
@@ -55,6 +54,7 @@ if (isset($_GET["lID"])) {
                // first one (the same for all IP)
                $filename = reset($content_filename);
             }
+
             if (isset($_GET['rank']) && isset($content_data[$_GET['rank']])) {
                $data = $content_data[$_GET['rank']];
             } else {
@@ -69,11 +69,11 @@ if (isset($_GET["lID"])) {
             header('Expires: 0');
 
             // Pour que les \x00 ne devienne pas \0
-            $mc = get_magic_quotes_runtime();
+            $mc = Toolbox::get_magic_quotes_runtime();
             if ($mc) {
                @set_magic_quotes_runtime(0);
             }
-
+            // May have several values due to network datas : use only first one
             echo $data;
 
             if ($mc) {
