@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link_itemtype.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: link_itemtype.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -32,10 +32,11 @@
 // Purpose of file:
 // ----------------------------------------------------------------------
 
+
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 if (empty($_GET["id"])) {
    $_GET["id"] = "";
@@ -50,13 +51,13 @@ if (isset($_POST["add"])) {
    if ($link_itemtype->add($_POST)) {
     Event::log($_POST["links_id"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][32]);
    }
-   glpi_header($CFG_GLPI["root_doc"]."/front/link.form.php?id=".$_POST["links_id"]);
+   Html::redirect($CFG_GLPI["root_doc"]."/front/link.form.php?id=".$_POST["links_id"]);
 }
 else if (isset($_GET["delete"])) {
    $link->check($_GET["links_id"],'w');
 
    $link_itemtype->delete($_GET);
    Event::log($_GET["links_id"], "links", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][33]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 }
 ?>
