@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailcollector.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: mailcollector.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("config", "r");
+Session::checkRight("config", "r");
 
 if (!isset($_GET["id"])) {
    $_GET["id"] = "";
@@ -49,7 +49,7 @@ if (isset($_POST["add"])) {
 
    Event::log($newID, "mailcollector", 4, "setup",
               $_SESSION["glpiname"]." added ".$_POST["name"].".");
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $mailgate->check($_POST['id'],'w');
@@ -65,18 +65,17 @@ if (isset($_POST["add"])) {
 
    Event::log($_POST["id"], "mailcollector", 4, "setup",
               $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["get_mails"])) {
    $mailgate->check($_POST['id'],'w');
    $mailgate->collect($_POST["id"],1);
 
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else {
-   commonHeader($LANG['Menu'][39], $_SERVER['PHP_SELF'], "config", "mailcollector");
+   Html::header($LANG['Menu'][39], $_SERVER['PHP_SELF'], "config", "mailcollector");
    $mailgate->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
