@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: massiveaction.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: massiveaction.php 18724 2012-06-26 10:44:20Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -320,7 +320,9 @@ if (isset($_POST["action"])
                }
                foreach ($_POST["item"] as $key => $val) {
                   if ($val == 1) {
-                     if ($item->can($key,'w')) {
+                     if ($item->can($key,'w')
+                         && $item->canMassiveAction($_POST['action'], $_POST['field'],
+                                                    $_POST[$_POST["field"]])) {
                         if (count($link_entity_type) == 0
                             || in_array($item->fields["entities_id"],$link_entity_type)) {
                            if ($item->update(array('id'            => $key,
@@ -691,8 +693,12 @@ if (isset($_POST["action"])
                   $params["name"]             = $soft->fields["name"];
                   $params["manufacturers_id"] = $soft->fields["manufacturers_id"];
                   $params["comment"]          = $soft->fields["comment"];
-                  //Process rules
-                  if ($soft->update($softcatrule->processAllRules(null, $soft->fields, $params))) {
+                  $output = Toolbox::addslashes_deep($soft->fields);
+                  $params = Toolbox::addslashes_deep($params);
+                  $output = $softcatrule->processAllRules(null, $output, $params);
+                  
+                  if ($soft->update(array('id' => $output['id'],
+                                          'softwarecategories_id' => $output['softwarecategories_id']))) {
                      $nbok++;
                   } else {
                      $nbko++;
@@ -826,7 +832,7 @@ if (isset($_POST["action"])
          break;
 
       case "add_actor" :
-         
+
          $item = new $_POST['itemtype']();
          foreach ($_POST["item"] as $key => $val) {
             if ($val == 1) {
@@ -1026,8 +1032,9 @@ if (isset($_POST["action"])
 } else { //action, itemtype or item not defined
    echo "<div class='center'>".
          "<img src='".$CFG_GLPI["root_doc"]."/pics/warning.png' alt='warning'><br><br>";
-   echo "<span class='b'>".$LANG['common'][24]."</span></div>";
+   echo "<span class='b'>".$LANG['common'][24]."</span><br>";
    Html::displayBackLink();
+   echo "</div>";
 }
 
 Html::footer();
