@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: monitor.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: monitor.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("monitor", "r");
+Session::checkRight("monitor", "r");
 
 if (empty($_GET["id"])) {
    $_GET["id"] = "";
@@ -58,7 +58,7 @@ if (isset($_POST["add"])) {
    $newID = $monitor->add($_POST);
    Event::log($newID, "monitors", 4, "inventory",
               $_SESSION["glpiname"]." ".$LANG['log'][20]." ".$_POST["name"].".");
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $monitor->check($_POST["id"],'d');
@@ -86,21 +86,20 @@ if (isset($_POST["add"])) {
 
    $monitor->update($_POST);
    Event::log($_POST["id"], "monitors", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_GET["unglobalize"])) {
    $monitor->check($_GET["id"],'w');
 
    Computer_Item::unglobalizeItem($monitor);
    Event::log($_GET["id"], "monitors", 4, "inventory", $_SESSION["glpiname"]." ".$LANG['log'][60]);
-   glpi_header($CFG_GLPI["root_doc"]."/front/monitor.form.php?id=".$_GET["id"]);
+   Html::redirect($CFG_GLPI["root_doc"]."/front/monitor.form.php?id=".$_GET["id"]);
 
 } else {
-   commonHeader($LANG['Menu'][3],$_SERVER['PHP_SELF'],"inventory","monitor");
+   Html::header($LANG['Menu'][3],$_SERVER['PHP_SELF'],"inventory","monitor");
 
    $monitor->showForm($_GET["id"], array('withtemplate' => $_GET["withtemplate"]));
 
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
