@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport.form.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: networkport.form.php 18718 2012-06-26 06:51:50Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -111,15 +111,16 @@ if (isset($_POST["add"])) {
    Html::back();
 
 }
-// Interest of this massive action ?
-/*else if(isset($_POST["move"])) {
+// Interest of this massive action ? Replace switch by another : don't re-create manually all ports
+else if(isset($_POST["move"])) {
    Session::checkRight("networking","w");
    if (isset($_POST["del_port"]) && count($_POST["del_port"])) {
       foreach ($_POST["del_port"] as $port_id => $val) {
          if ($np->getFromDB($port_id)) {
             $input = array();
             $input['id'] = $port_id;
-            $input['items_id'] = $_POST["device"];
+            $input['items_id'] = $_POST["items_id"];
+            $input['itemtype'] = 'NetworkEquipment';
             if ($np->can($input['id'],'w')) {
                $np->update($input);
             }
@@ -129,7 +130,7 @@ if (isset($_POST["add"])) {
    Event::log(0, "networkport", 5, "inventory", $_SESSION["glpiname"]."  ".$LANG['log'][75]);
    Html::back();
 
-}*/ else if (isset($_POST["update"])) {
+} else if (isset($_POST["update"])) {
    $np->check($_POST['id'],'w');
 
    $np->update($_POST);
