@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notification.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notification.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("notification", "r");
+Session::checkRight("notification", 'r');
 
 if (!isset($_GET["id"])) {
    $_GET["id"] = "";
@@ -48,7 +48,7 @@ if (isset($_POST["add"])) {
    $newID = $notification->add($_POST);
    Event::log($newID, "notifications", 4, "notification",
               $_SESSION["glpiname"]." ".$LANG['log'][20]." :  ".$_POST["name"].".");
-   glpi_header($_SERVER['PHP_SELF']."?id=$newID");
+   Html::redirect($_SERVER['PHP_SELF']."?id=$newID");
 
 } else if (isset($_POST["delete"])) {
    $notification->check($_POST["id"],'d');
@@ -64,12 +64,11 @@ if (isset($_POST["add"])) {
    $notification->update($_POST);
    Event::log($_POST["id"], "notifications", 4, "notification",
               $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else {
-   commonHeader($LANG['setup'][704],$_SERVER['PHP_SELF'],"config","mailing","notification");
+   Html::header($LANG['setup'][704],$_SERVER['PHP_SELF'],"config","mailing","notification");
    $notification->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
