@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtarget.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationtarget.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -30,8 +30,8 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 NotificationTarget::updateTargets($_POST);
-glpi_header($_SERVER['HTTP_REFERER']);
-?>
+Html::back();
+?>
\ No newline at end of file
