@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ocsng.sync.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ocsng.sync.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,9 +35,9 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("ocsng","w");
+Session::checkRight("ocsng", "w");
 
-commonHeader($LANG['ocsng'][0], $_SERVER['PHP_SELF'], "utils", "ocsng", "sync");
+Html::header($LANG['ocsng'][0], $_SERVER['PHP_SELF'], "utils", "ocsng", "sync");
 
 $display_list = true;
 
@@ -52,9 +52,9 @@ if (isset($_SESSION["ocs_update"]['computers'])) {
       $action = OcsServer::updateComputer($key, $_SESSION["ocsservers_id"], 2);
       OcsServer::manageImportStatistics($_SESSION["ocs_update"]['statistics'], $action['status']);
       OcsServer::showStatistics($_SESSION["ocs_update"]['statistics']);
-      displayProgressBar(400, $percent);
+      Html::displayProgressBar(400, $percent);
 
-      glpi_header($_SERVER['PHP_SELF']);
+      Html::redirect($_SERVER['PHP_SELF']);
 
    } else {
       OcsServer::showStatistics($_SESSION["ocs_update"]['statistics'], true);
@@ -88,9 +88,8 @@ if (!isset($_POST["update_ok"])) {
          }
       }
    }
-   glpi_header($_SERVER['PHP_SELF']);
+   Html::redirect($_SERVER['PHP_SELF']);
 }
 
-commonFooter();
-
+Html::footer();
 ?>
\ No newline at end of file
