@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: phone.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: phone.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -36,12 +36,11 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
+Session::checkRight("phone", "r");
 
-checkRight("phone","r");
-
-commonHeader($LANG['help'][35],$_SERVER['PHP_SELF'],"inventory","phone");
+Html::header($LANG['help'][35],$_SERVER['PHP_SELF'],"inventory","phone");
 
 Search::show('Phone');
 
-commonFooter();
-?>
+Html::footer();
+?>
\ No newline at end of file
