@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: popup.php 17457 2012-02-09 15:26:40Z moyo $
+ * @version $Id: popup.php 17220 2012-01-26 14:25:39Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -30,7 +30,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkLoginUser();
+Session::checkLoginUser();
 
 if (isset($_GET["popup"])) {
    $_SESSION["glpipopup"]["name"] = $_GET["popup"];
@@ -39,7 +39,7 @@ if (isset($_GET["popup"])) {
 if (isset($_SESSION["glpipopup"]["name"])) {
    switch ($_SESSION["glpipopup"]["name"]) {
       case "search_config" :
-         popHeader($LANG['common'][12], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['common'][12], $_SERVER['PHP_SELF']);
          if (isset($_POST["add"])
              || isset($_POST["delete"])
              || isset($_POST["delete_x"])
@@ -55,57 +55,56 @@ if (isset($_SESSION["glpipopup"]["name"])) {
          break;
 
       case "test_rule" :
-         popHeader($LANG['buttons'][50], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['buttons'][50], $_SERVER['PHP_SELF']);
          include "rule.test.php";
          break;
 
       case "test_all_rules" :
-         popHeader($LANG['rulesengine'][84], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['rulesengine'][84], $_SERVER['PHP_SELF']);
          include "rulesengine.test.php";
          break;
 
       case "show_cache" :
-         popHeader($LANG['rulesengine'][100], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['rulesengine'][100], $_SERVER['PHP_SELF']);
          include "rule.cache.php";
          break;
 
       case "load_bookmark" :
-         popHeader($LANG['Menu'][40],$_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['Menu'][40],$_SERVER['PHP_SELF']);
          $_GET["action"] = "load";
          include "bookmark.php";
          break;
 
       case "edit_bookmark" :
-         popHeader($LANG['Menu'][40], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['Menu'][40], $_SERVER['PHP_SELF']);
          $_GET["action"] = "edit";
          include "bookmark.php";
          break;
 
       case "edit_user_notification" :
-         popHeader($LANG['Menu'][40], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['job'][19], $_SERVER['PHP_SELF']);
          include "ticket_user.form.php";
          break;
 
       case "add_ldapuser" :
-         popHeader($LANG['ldap'][35], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['ldap'][35], $_SERVER['PHP_SELF']);
          include "ldap.import.php";
          break;
 
       case "list_notificationtags" :
-         popHeader($LANG['mailing'][138], $_SERVER['PHP_SELF']);
+         Html::popHeader($LANG['mailing'][138], $_SERVER['PHP_SELF']);
          include "notification.tags.php";
          break;
 
       case "show_kb" :
-         popHeader($LANG['title'][5], $_SERVER['PHP_SELF']);
-         $kb = new KnowbaseItem;
+         Html::popHeader($LANG['title'][5], $_SERVER['PHP_SELF']);
+         $kb = new KnowbaseItem();
          $kb->check($_GET["id"],'r');
          $kb->showFull(true);
          break;
    }
    echo "<div class='center'><br><a href='javascript:window.close()'>".$LANG['buttons'][60]."</a>";
    echo "</div>";
-   popFooter();
+   Html::popFooter();
 }
-
-?>
+?>
\ No newline at end of file
