@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: profile.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("profile","r");
+Session::checkRight("profile", "r");
 
 if (!isset($_GET['id'])) {
    $_GET['id'] = "";
@@ -48,7 +48,7 @@ if (isset($_POST["add"])) {
    $ID = $prof->add($_POST);
 
    // We need to redirect to form to enter rights
-   glpi_header($CFG_GLPI["root_doc"]."/front/profile.form.php?id=$ID");
+   Html::redirect($CFG_GLPI["root_doc"]."/front/profile.form.php?id=$ID");
 
 } else if (isset($_POST["delete"])) {
    $prof->check($_POST['id'],'w');
@@ -60,13 +60,12 @@ if (isset($_POST["add"])) {
    $prof->check($_POST['id'],'w');
 
    $prof->update($_POST);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 }
 
-commonHeader($LANG['Menu'][35],$_SERVER['PHP_SELF'],"admin","profile");
+Html::header($LANG['Menu'][35],$_SERVER['PHP_SELF'],"admin","profile");
 
 $prof->showForm($_GET["id"]);
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
