@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reminder.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: reminder.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,17 +35,19 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
-commonHeader($LANG['title'][40],$_SERVER['PHP_SELF'],"utils","reminder");
+Html::header($LANG['title'][40],$_SERVER['PHP_SELF'],"utils","reminder");
 
-Reminder::showList();
+Search::show('Reminder');
 
-if (haveRight("reminder_public","r")) {
-   Reminder::showList(false,false);
-   Reminder::showList(false,true);
-}
 
-commonFooter();
+// Reminder::showList();
+// 
+// if (Session::haveRight("reminder_public","r")) {
+//    Reminder::showList(false,false);
+//    Reminder::showList(false,true);
+// }
 
-?>
+Html::footer();
+?>
\ No newline at end of file
