@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.dynamic.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.dynamic.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 if (isset($_GET["item_type"]) && isset($_GET["display_type"])) {
    if ($_GET["display_type"] < 0) {
@@ -58,23 +58,25 @@ if (isset($_GET["item_type"]) && isset($_GET["display_type"])) {
       case 'Stat' :
          if (isset($_GET["item_type_param"])) {
             $params = unserialize(stripslashes($_GET["item_type_param"]));
+
             switch ($params["type"]) {
                case "comp_champ" :
-                  $val = Stat::getItems($params["date1"], $params["date2"], $params["dropdown"]);
-                  Stat::show($params["type"], $params["date1"], $params["date2"], $params["start"],
+                  $val = Stat::getItems($_GET["itemtype"], $params["date1"], $params["date2"], $params["dropdown"]);
+                  Stat::show($_GET["itemtype"], $params["type"], $params["date1"], $params["date2"], $params["start"],
                              $val, $params["dropdown"]);
                   break;
 
                case "device" :
-                  $val = Stat::getItems($params["date1"], $params["date2"], $params["dropdown"]);
-                  Stat::show($params["type"], $params["date1"], $params["date2"], $params["start"],
+                  $val = Stat::getItems($_GET["itemtype"], $params["date1"], $params["date2"], $params["dropdown"]);
+                  Stat::show($_GET["itemtype"], $params["type"], $params["date1"], $params["date2"], $params["start"],
                              $val, $params["dropdown"]);
                   break;
 
                default :
-                  $val = Stat::getItems($params["date1"], $params["date2"], $params["type"]);
-                  Stat::show($params["type"], $params["date1"], $params["date2"], $params["start"],
-                             $val);
+                  $val2 = (isset($params['value2']) ? $params['value2'] : 0);
+                  $val = Stat::getItems($_GET["itemtype"], $params["date1"], $params["date2"], $params["type"], $val2);
+                  Stat::show($_GET["itemtype"], $params["type"], $params["date1"], $params["date2"], $params["start"],
+                             $val, $val2);
             }
          } else if (isset($_GET["type"]) && $_GET["type"] == "hardwares") {
             Stat::showItems("",$_GET["date1"], $_GET["date2"], $_GET['start']);
@@ -84,7 +86,7 @@ if (isset($_GET["item_type"]) && isset($_GET["display_type"])) {
       default :
          // Plugin case
          if ($plug = isPluginItemType($_GET["item_type"])) {
-            if (doOneHook($plug['plugin'], 'dynamicReport', $_GET)) {
+            if (Plugin::doOneHook($plug['plugin'], 'dynamicReport', $_GET)) {
                exit();
             }
          }
