@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.location.list.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: report.location.list.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -30,11 +30,13 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("reports","r");
+Session::checkRight("reports", "r");
 
 if (isset($_POST["locations_id"]) && $_POST["locations_id"]) {
-   commonHeader($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
-
+   Html::header($LANG['Menu'][6],$_SERVER['PHP_SELF'],"utils","report");
+   
+   Report::title();
+   
    // Titre
    $name = Dropdown::getDropdownName("glpi_locations",$_POST["locations_id"]);
    echo "<div class='center'><h2>".$LANG['reports'][54]." $name </h2><br></div>";
@@ -80,8 +82,7 @@ if (isset($_POST["locations_id"]) && $_POST["locations_id"]) {
 
          if ($networkports_id_1 && $np->getFromDB($networkports_id_1)) {
             $ordi = '';
-            if (class_exists($np->fields["itemtype"])) {
-               $item=new $np->fields["itemtype"]();
+            if ($item = getItemForItemtype($np->fields["itemtype"])) {
                if ($item->getFromDB($np->fields["items_id"])) {
                   $ordi = $item->getName();
                }
@@ -166,10 +167,9 @@ if (isset($_POST["locations_id"]) && $_POST["locations_id"]) {
       }
       echo "</table></div><br><hr><br>";
    }
-   commonFooter();
+   Html::footer();
 
 } else  {
-   glpi_header($CFG_GLPI['root_doc']."/front/report.networking.php");
+   Html::redirect($CFG_GLPI['root_doc']."/front/report.networking.php");
 }
-
 ?>
\ No newline at end of file
