@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.reservation.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: report.reservation.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -55,7 +55,8 @@ User::dropdown(array('name'   => 'id',
 echo "</td>";
 echo "<td rowspan='2' class='center'><input type='submit' class='button' name='submit' value='".
       $LANG['buttons'][7] ."'></td></tr>";
-echo "</table></form>";
+echo "</table>";
+Html::closeForm();
 
 if ($_GET["id"] > 0) {
    Reservation::showForUser($_GET["id"]);
