@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: report.year.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: report.year.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -75,7 +75,8 @@ echo "</select></p></td></tr>";
 echo "<tr class='tab_bg_2'><td colspan='2' class='center'>";
 echo "<input type='submit' value=\"".$LANG['reports'][15]."\" class='submit'></td></tr>";
 
-echo "</table></form>";
+echo "</table>";
+Html::closeForm();
 
 Html::footer();
 ?>
\ No newline at end of file
