@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reservationitem.form.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: reservationitem.form.php 18632 2012-06-08 13:55:47Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -55,6 +55,10 @@ if (isset($_REQUEST["add"])) {
    Html::back();
 
 } else if (isset($_REQUEST["update"])) {
+   // from reservation form
+   if (isset($_POST["id"])) {
+      $_REQUEST = $_POST;
+   } // else from object from
    $ri->update($_REQUEST);
    Event::log($_REQUEST['id'], "reservationitem", 4, "inventory",
               $_SESSION["glpiname"]." ".$LANG['log'][21]);
