@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.cache.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rule.cache.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,10 +37,10 @@ if (!defined('GLPI_ROOT')) {
    include (GLPI_ROOT . "/inc/includes.php");
 }
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 if (!strpos($_SERVER['PHP_SELF'],"popup")) {
-   commonHeader($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", "dictionnary", "cache");
+   Html::header($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", "dictionnary", "cache");
 }
 
 if (isset($_GET["sub_type"])) {
@@ -59,7 +59,6 @@ if (isset($_GET["sub_type"])) {
 }
 
 if (!strpos($_SERVER['PHP_SELF'],"popup")) {
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
