@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.common.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rule.common.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -43,7 +43,7 @@ if (!isset($_GET["id"])) {
    $_GET["id"] = "";
 }
 $rulecriteria = new RuleCriteria(get_class($rule));
-$ruleaction = new RuleAction(get_class($rule));
+$ruleaction   = new RuleAction(get_class($rule));
 
 if (isset($_POST["delete_criteria"])) {
    $rulecollection->checkGlobal('w');
@@ -57,7 +57,7 @@ if (isset($_POST["delete_criteria"])) {
    // Can't do this in RuleCriteria, so do it here
    $rule->update(array('id'       => $_POST['rules_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete_action"])) {
    $rulecollection->checkGlobal('w');
@@ -71,7 +71,7 @@ if (isset($_POST["delete_criteria"])) {
    // Can't do this in RuleAction, so do it here
    $rule->update(array('id'       => $_POST['rules_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["add_criteria"])) {
    $rulecollection->checkGlobal('w');
@@ -80,7 +80,7 @@ if (isset($_POST["delete_criteria"])) {
    // Can't do this in RuleCriteria, so do it here
    $rule->update(array('id'       => $_POST['rules_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["add_action"])) {
    $rulecollection->checkGlobal('w');
@@ -89,21 +89,21 @@ if (isset($_POST["delete_criteria"])) {
    // Can't do this in RuleCriteria, so do it here
    $rule->update(array('id'       => $_POST['rules_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["update"])) {
    $rulecollection->checkGlobal('w');
    $rule->update($_POST);
 
    Event::log($_POST['id'], "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["add"])) {
    $rulecollection->checkGlobal('w');
 
    $newID = $rule->add($_POST);
    Event::log($newID, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][20]);
-   glpi_header($_SERVER['HTTP_REFERER']."?id=$newID");
+   Html::redirect($_SERVER['HTTP_REFERER']."?id=$newID");
 
 } else if (isset($_POST["delete"])) {
    $rulecollection->checkGlobal('w');
@@ -114,10 +114,9 @@ if (isset($_POST["delete_criteria"])) {
    $rule->redirectToList();
 }
 
-commonHeader($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin",
+Html::header($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], 'admin',
              $rulecollection->menu_type, $rulecollection->menu_option);
 
 $rule->showForm($_GET["id"]);
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
