@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.common.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rule.common.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -47,7 +47,7 @@ $rulecollection->checkGlobal('r');
 if (isset($_GET["action"])) {
    $rulecollection->checkGlobal('w');
    $rulecollection->changeRuleOrder($_GET["id"],$_GET["action"]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["action"])) {
    $rulecollection->checkGlobal('w');
@@ -63,7 +63,7 @@ if (isset($_GET["action"])) {
                $rule->delete(array('id' => $key));
             }
             Event::log(0, "rules", 4, "setup", $_SESSION["glpiname"]." ".$LANG['log'][22]);
-            glpi_header($_SERVER['HTTP_REFERER']);
+            Html::back();
          }
          break;
 
@@ -101,21 +101,21 @@ if (isset($_GET["action"])) {
    $max = get_cfg_var("max_execution_time");
    $max = $start + ($max>0 ? $max/2.0 : 30.0);
 
-   commonHeader($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", $rulecollection->menu_type,
+   Html::header($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", $rulecollection->menu_type,
                 $rulecollection->menu_option);
 
    if (!(isset($_POST['replay_confirm']) || isset($_GET['offset']))
        && $rulecollection->warningBeforeReplayRulesOnExistingDB($_SERVER['PHP_SELF'])) {
-      commonFooter();
+      Html::footer();
       exit();
    }
 
    echo "<table class='tab_cadrehov'>";
 
-   echo "<tr><th><div class='relative'><strong>" .$rulecollection->getTitle(). "</strong>";
-   echo " - " .$LANG['rulesengine'][76]. "</th></tr>\n";
+   echo "<tr><th><div class='relative b'>" .$rulecollection->getTitle(). " - " .
+         $LANG['rulesengine'][76]. "</div></th></tr>\n";
    echo "<tr><td class='center'>";
-   createProgressBar($LANG['rulesengine'][90]);
+   Html::createProgressBar($LANG['rulesengine'][90]);
    echo "</td></tr>\n";
    echo "</table>";
 
@@ -138,53 +138,24 @@ if (isset($_GET["action"])) {
       // Work ended
       $end   = explode(" ",microtime());
       $duree = round($end[0]+$end[1]-$start);
-      changeProgressBarMessage($LANG['rulesengine'][91]." (".timestampToString($duree).")");
+      Html::changeProgressBarMessage($LANG['rulesengine'][91]." (".Html::timestampToString($duree).")");
       echo "<a href='".$_SERVER['PHP_SELF']."'>".$LANG['buttons'][13]."</a>";
 
    } else {
       // Need more work
-      glpi_header($_SERVER['PHP_SELF']."?start=$start&replay_rule=1&offset=$offset&manufacturer=".
-                  "$manufacturer");
+      Html::redirect($_SERVER['PHP_SELF']."?start=$start&replay_rule=1&offset=$offset&manufacturer=".
+                   "$manufacturer");
    }
 
-   commonFooter(true);
+   Html::footer(true);
    exit();
 }
 
-commonHeader($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], "admin", $rulecollection->menu_type,
+Html::header($LANG['rulesengine'][17], $_SERVER['PHP_SELF'], 'admin', $rulecollection->menu_type,
              $rulecollection->menu_option);
 
-   if ($rulecollection->showInheritedTab()) {
-      $tabs[0] = array('title'  => $LANG['rulesengine'][20].' : '.
-                                   Dropdown::getDropdownName('glpi_entities',
-                                                             $_SESSION['glpiactive_entity']),
-                       'url'    => $CFG_GLPI['root_doc']."/ajax/rules.tabs.php",
-                       'params' => "target=".$_SERVER['PHP_SELF']."&glpi_tab=1&inherited=1&itemtype=".
-                                    get_class($rulecollection));
-   }
-
-   $title = $LANG['rulesengine'][17];
-   if ($rulecollection->isRuleRecursive()) {
-      $title = $LANG['rulesengine'][23].' : '.Dropdown::getDropdownName('glpi_entities',
-                                                                        $_SESSION['glpiactive_entity']);
-   }
-   $tabs[1] = array('title'  => $title,
-                    'url'    => $CFG_GLPI['root_doc']."/ajax/rules.tabs.php",
-                    'params' => "target=".$_SERVER['PHP_SELF']."&glpi_tab=0&inherited=0&itemtype=".
-                                 get_class($rulecollection));
-
-   if ($rulecollection->showChildrensTab()) {
-      $tabs[2] = array('title'  => $LANG['rulesengine'][21],
-                       'url'    => $CFG_GLPI['root_doc']."/ajax/rules.tabs.php",
-                       'params' => "target=".$_SERVER['PHP_SELF'].
-                                    "&glpi_tab=2&inherited=0&childrens=1&itemtype=".
-                                    get_class($rulecollection));
-   }
-
-
-   echo "<div id='tabspanel' class='center-h'></div>";
-   createAjaxTabs('tabspanel','tabcontent',$tabs,$rulecollection->getRuleClassName());
-   echo "<div id='tabcontent'>&nbsp;</div>";
-   echo "<script type='text/javascript'>loadDefaultTab();</script>";
-commonFooter();
-?>
+$rulecollection->showTabs();
+echo "<div id='tabcontent'>&nbsp;</div>";
+echo "<script type='text/javascript'>loadDefaultTab();</script>";
+Html::footer();
+?>
\ No newline at end of file
