@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rule.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,15 +35,15 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
-commonHeader($LANG['common'][12], $_SERVER['PHP_SELF'], "admin", "rule", -1);
+Html::header($LANG['common'][12], $_SERVER['PHP_SELF'], "admin", "rule", -1);
 
 echo "<table class='tab_cadre'>";
 echo "<tr><th>" . $LANG['rulesengine'][24] . "</th></tr>";
 
 foreach ($CFG_GLPI["rulecollections_types"] as $rulecollectionclass) {
-   $rulecollection = new $rulecollectionclass;
+   $rulecollection = new $rulecollectionclass();
    if ($rulecollection->canList()) {
       if ($plug = isPluginItemType($rulecollectionclass)) {
          $function = 'plugin_version_'.strtolower($plug['plugin']);
@@ -54,12 +54,12 @@ foreach ($CFG_GLPI["rulecollections_types"] as $rulecollectionclass) {
       }
       $title .= $rulecollection->getTitle();
       echo "<tr class='tab_bg_1'><td class='center b'>";
-      echo "<a href='".getItemTypeSearchURL($rulecollection->getRuleClassName())."'>";
+      echo "<a href='".Toolbox::getItemTypeSearchURL($rulecollection->getRuleClassName())."'>";
       echo $title."</a></td></tr>";
    }
 }
 
-if (haveRight("transfer","r" ) && isMultiEntitiesMode()) {
+if (Session::haveRight("transfer","r" ) && Session::isMultiEntitiesMode()) {
    echo "<tr class='tab_bg_1'><td class='center b'>";
    echo "<a href='".$CFG_GLPI['root_doc']."/front/transfer.php'>".$LANG['transfer'][1]."</a>";
    echo "</td></tr>";
@@ -67,6 +67,5 @@ if (haveRight("transfer","r" ) && isMultiEntitiesMode()) {
 
 echo "</table>";
 
-commonFooter();
-
-?>
+Html::footer();
+?>
\ No newline at end of file
