@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulesengine.test.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rulesengine.test.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,7 +37,7 @@ if (!defined('GLPI_ROOT')) {
    include (GLPI_ROOT . "/inc/includes.php");
 }
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 if (isset($_POST["sub_type"])) {
    $sub_type = $_POST["sub_type"];
@@ -54,7 +54,7 @@ if ($rulecollection->isRuleRecursive()) {
 $rulecollection->checkGlobal('r');
 
 if (!strpos($_SERVER['PHP_SELF'],"popup")) {
-   commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"config","display");
+   Html::header($LANG['common'][12],$_SERVER['PHP_SELF'],"config","display");
 }
 
 // Need for RuleEngines
@@ -73,7 +73,6 @@ if (isset($_POST["test_all_rules"])) {
 }
 
 if (!strpos($_SERVER['PHP_SELF'],"popup")) {
-   commonFooter();
+   Html::footer();
 }
-
 ?>
\ No newline at end of file
