@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: search.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: search.php 18344 2012-04-19 07:23:50Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -40,6 +40,9 @@ include (GLPI_ROOT . "/inc/includes.php");
 Session::checkCentralAccess();
 Html::header($LANG['search'][0],$_SERVER['PHP_SELF']);
 
+if (!$CFG_GLPI['allow_search_global']) {
+   Html::displayRightError();
+}
 if (isset($_GET["globalsearch"])) {
    $searchtext=$_GET["globalsearch"];
 
@@ -51,6 +54,11 @@ if (isset($_GET["globalsearch"])) {
 
          Search::manageGetValues($itemtype,false,true);
 
+         if (!isset($_GET["field"][0])) {
+            // From global search only
+            $_GET["field"][0] = 'view';
+         }
+
          if ($_GET["field"][0] =='view') {
             $_GET["contains"][0]   = $searchtext;
             $_GET["searchtype"][0] = 'contains';
