@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: setup.templates.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: setup.templates.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -38,19 +38,17 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkCentralAccess();
+Session::checkCentralAccess();
 
 if (isset($_GET["itemtype"])) {
 
-   $link=getItemTypeFormURL($_GET["itemtype"]);
-
+   $link = Toolbox::getItemTypeFormURL($_GET["itemtype"]);
    $item = str_replace(".form.php","",$link);
    $item = str_replace("front/","",$item);
-   commonHeader($LANG['common'][12],$_SERVER['PHP_SELF'],"inventory",$item);
+   Html::header($LANG['common'][12],$_SERVER['PHP_SELF'],"inventory",$item);
 
-   listTemplates($_GET["itemtype"],$link,$_GET["add"]);
+   CommonDBTM::listTemplates($_GET["itemtype"],$link,$_GET["add"]);
 
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
