@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: slalevel.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: slalevel.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,7 +39,7 @@ if (isset($_POST["update"])) {
    $item->update($_POST);
 
    Event::log($_POST["id"], "slas", 4, "config", $_SESSION["glpiname"]." ".$LANG['log'][21]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["add"])) {
    $item->check(-1, 'w', $_POST);
@@ -47,7 +47,7 @@ if (isset($_POST["update"])) {
    if ($item->add($_POST)) {
       Event::log($_POST["slas_id"], "slas", 4, "config", $_SESSION["glpiname"]." ".$LANG['log'][32]);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
 
@@ -60,16 +60,18 @@ if (isset($_POST["update"])) {
          }
       }
       Event::log($_POST["slas_id"], "slas", 4, "config", $_SESSION["glpiname"]." ".$LANG['log'][22]);
+
    } else if (isset($_POST['id'])) {
       $item->check($_POST['id'], 'd');
       $ok = $item->delete($_POST);
       if ($ok) {
          Event::log($_POST["id"], "slas", 4, "config",
-                  $_SESSION["glpiname"]." ".$LANG['log'][22]." ".$item->getField('name'));
+                    $_SESSION["glpiname"]." ".$LANG['log'][22]." ".$item->getField('name'));
       }
       $item->redirectToList();
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+
+   Html::back();
 
 } else if (isset($_POST["add_action"])) {
    $item->check($_POST['slalevels_id'], 'w');
@@ -80,7 +82,7 @@ if (isset($_POST["update"])) {
    // Can't do this in SlaLevelAction, so do it here
    $item->update(array('id'       => $_POST['slalevels_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete_action"])) {
    $item->check($_POST['slalevels_id'], 'w');
@@ -96,13 +98,12 @@ if (isset($_POST["update"])) {
    // Can't do this in RuleAction, so do it here
    $item->update(array('id'       => $_POST['slalevels_id'],
                        'date_mod' => $_SESSION['glpi_currenttime']));
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
  } else {//print computer informations
-   commonHeader($LANG['sla'][6], $_SERVER['PHP_SELF'], "config", "sla");
+   Html::header($LANG['sla'][6], $_SERVER['PHP_SELF'], "config", "sla");
    //show computer form to add
    $item->showForm($_GET["id"]);
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
