@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: softwareversion.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: softwareversion.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -35,7 +35,7 @@
 define('GLPI_ROOT', '..');
 include (GLPI_ROOT . "/inc/includes.php");
 
-checkRight("software", "r");
+Session::checkRight("software", "r");
 
 if (!isset($_GET["id"])) {
    $_GET["id"] = "";
@@ -52,10 +52,10 @@ if (isset($_POST["add"])) {
    if ($newID = $version->add($_POST)) {
       Event::log($_POST['softwares_id'], "software", 4, "inventory",
                  $_SESSION["glpiname"]." ".$LANG['log'][82]." $newID.");
-      glpi_header($CFG_GLPI["root_doc"]."/front/software.form.php?id=".
+      Html::redirect($CFG_GLPI["root_doc"]."/front/software.form.php?id=".
                   $version->fields['softwares_id']);
    }
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else if (isset($_POST["delete"])) {
    $version->check($_POST['id'],'w');
@@ -71,12 +71,11 @@ if (isset($_POST["add"])) {
    $version->update($_POST);
    Event::log($version->fields['softwares_id'], "software", 4, "inventory",
               $_SESSION["glpiname"]." ".$LANG['log'][83]." ".$_POST["id"]);
-   glpi_header($_SERVER['HTTP_REFERER']);
+   Html::back();
 
 } else {
-   commonHeader($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
+   Html::header($LANG['Menu'][4],$_SERVER['PHP_SELF'],"inventory","software");
    $version->showForm($_GET["id"], array('softwares_id' => $_GET["softwares_id"]));
-   commonFooter();
+   Html::footer();
 }
-
-?>
+?>
\ No newline at end of file
