@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.item.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: stat.item.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -76,7 +76,9 @@ echo "<input type='submit' class='button' name='submit' value='". $LANG['buttons
 echo "<tr class='tab_bg_2'><td class='right'>".$LANG['search'][9]."&nbsp;:</td><td>";
 Html::showDateFormItem("date2",$_POST["date2"]);
 echo "</td></tr>";
-echo "</table></form></div>";
+echo "</table>";
+Html::closeForm();
+echo "</div>";
 
 Stat::showItems($_SERVER['PHP_SELF'],$_POST["date1"],$_POST["date2"],$_GET['start']);
 
