@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: stat.tracking.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: stat.tracking.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -138,7 +138,9 @@ echo "</td><td class='center'>";
 echo "<input type='hidden' name='value2' value='".$_REQUEST["value2"]."'>";
 Dropdown::showYesNo('showgraph', $_REQUEST['showgraph']);
 echo "</td></tr>";
-echo "</table></form></div>";
+echo "</table>";
+Html::closeForm();
+echo "</div>";
 
 $val    = Stat::getItems($_REQUEST["itemtype"], $_REQUEST["date1"], $_REQUEST["date2"], $_REQUEST["type"], $_REQUEST["value2"]);
 $params = array('type'   => $_REQUEST["type"],
