@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticket_user.form.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ticket_user.form.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -34,6 +34,8 @@
 
 $ticket_user = new Ticket_User();
 
+Session ::checkLoginUser();
+
 if (isset($_REQUEST["update"])) {
    $ticket_user->check($_REQUEST["id"], 'w');
 
@@ -44,7 +46,7 @@ if (isset($_REQUEST["update"])) {
    echo "</script>";
 
 } else if (isset($_REQUEST["id"])) {
-   $ticket_user->showForm($_REQUEST["id"]);
+   $ticket_user->showUserNotificationForm($_REQUEST["id"]);
 }
 
 ?>
\ No newline at end of file
