@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: alert.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: alert.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -87,14 +87,14 @@ class Alert extends CommonDBTM {
          $value = $options['value'];
       }
 
-      if (isset($options['inherit_global']) && $options['inherit_global']) {
-         $times[-1] = $LANG['setup'][731];
+      if (isset($options['inherit_parent']) && $options['inherit_parent']) {
+         $times[EntityData::CONFIG_PARENT] = $LANG['common'][102];
       }
 
-      $times[0]               = $LANG['setup'][307];
-      $times[DAY_TIMESTAMP]   = $LANG['setup'][305];
-      $times[WEEK_TIMESTAMP]  = $LANG['setup'][308];
-      $times[MONTH_TIMESTAMP] = $LANG['setup'][309];
+      $times[EntityData::CONFIG_NEVER] = $LANG['setup'][307];
+      $times[DAY_TIMESTAMP]            = $LANG['setup'][305];
+      $times[WEEK_TIMESTAMP]           = $LANG['setup'][308];
+      $times[MONTH_TIMESTAMP]          = $LANG['setup'][309];
 
       Dropdown::showFromArray($options['name'], $times, array('value' => $value));
    }
@@ -109,8 +109,8 @@ class Alert extends CommonDBTM {
          $value = $options['value'];
       }
 
-      if (isset($options['inherit_global']) && $options['inherit_global']) {
-         $times[-1] = $LANG['setup'][731];
+      if (isset($options['inherit_parent']) && $options['inherit_parent']) {
+         $times[EntityData::CONFIG_PARENT] = $LANG['common'][102];
       }
 
       $times[0] = $LANG['choice'][0];
@@ -132,8 +132,8 @@ class Alert extends CommonDBTM {
          $p['toadd'][0] = $LANG['setup'][307];
       }
 
-      if (isset($options['inherit_global']) && $options['inherit_global']) {
-         $p['toadd'][-1] = $LANG['setup'][731];
+      if (isset($options['inherit_parent']) && $options['inherit_parent']) {
+         $p['toadd'][-2] = $LANG['common'][102];
       }
 
       foreach ($options as $key=>$val) {
@@ -159,12 +159,34 @@ class Alert extends CommonDBTM {
    }
 
 
-   static function dropdownInfocomAlert($value) {
+   /**
+    * Get the possible value for infocom alert
+    *
+    * @since version 0.83
+    *
+    * @param $val if not set, ask for all values, else for 1 value
+    *
+    * @return array or string
+    */
+   static function getAlertName($val=NULL) {
       global $LANG;
 
-      $tmp[0] = DROPDOWN_EMPTY_VALUE;
+      $tmp[0] = Dropdown::EMPTY_VALUE;
       $tmp[pow(2, self::END)] = $LANG['financial'][80];
-      Dropdown::showFromArray("default_infocom_alert", $tmp, array('value' => $value));
+
+      if (is_null($val)) {
+         return $tmp;
+      }
+      if (isset($tmp[$val])) {
+         return $tmp[$val];
+      }
+      return NOT_AVAILABLE;
+   }
+
+
+   static function dropdownInfocomAlert($value) {
+
+      Dropdown::showFromArray("default_infocom_alert", self::getAlertName(), array('value' => $value));
    }
 
 
@@ -180,7 +202,8 @@ class Alert extends CommonDBTM {
                    LIMIT 1";
          $result = $DB->query($query);
          if ($DB->numrows($result) > 0) {
-            echo "&nbsp;".$LANG['mailing'][52].' '.convDateTime($DB->result($result,0,'date'));
+            echo "&nbsp;".$LANG['mailing'][52].' '.Html::convDateTime($DB->result($result, 0,
+                                                                                  'date'));
          }
       }
    }
