@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: auth.class.php 17758 2012-03-08 09:33:53Z tsmr $
+ * @version $Id: auth.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -566,14 +566,15 @@ class Auth {
             }
          } else {
              if ($this->user_present) {
+               $input = Toolbox::addslashes_deep($this->user->fields);
                // update user and Blank PWD to clean old database for the external auth
-               $this->user->update($this->user->fields);
+               $this->user->update($input);
                if ($this->extauth) {
                   $this->user->blankPassword();
                }
             } else if ($CFG_GLPI["is_users_auto_add"]) {
                // Auto add user
-               $input = $this->user->fields;
+               $input = Toolbox::addslashes_deep($this->user->fields);
                unset ($this->user->fields);
                $this->user->add($input);
             } else {
@@ -939,7 +940,8 @@ class Auth {
          echo "<input type='hidden' name='id' value='" . $user->getID() . "'>";
          echo "<span id='show_massiveaction_field'></span>";
          echo "</td></tr></table>";
-         echo "</div></form>";
+         echo "</div>";
+         Html::closeForm();
       }
    }
 
@@ -1075,7 +1077,8 @@ class Auth {
       echo "<input type='submit' name='update' class='submit' value=\"".$LANG['buttons'][7]."\" >";
       echo "</td></tr>";
 
-      echo "</table></div></form>\n";
+      echo "</table></div>\n";
+      Html::closeForm();
    }
 
 }
