@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: authldapreplicate.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: authldapreplicate.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -76,7 +76,8 @@ class AuthLdapReplicate extends CommonDBTM {
       echo "<input type='hidden' name='authldaps_id' value='$master_id'>";
       echo "<input type='submit' name='add_replicate' value=\"" .
             $LANG['buttons'][2] . "\" class='submit'></td>";
-      echo "</tr></table></div></form>";
+      echo "</tr></table></div>";
+      Html::closeForm();
    }
 
 }
