@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: bookmark.class.php 17768 2012-03-08 13:32:11Z yllen $
+ * @version $Id: bookmark.class.php 18852 2012-07-06 08:22:58Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,7 +37,8 @@ if (!defined('GLPI_ROOT')) {
  */
 class Bookmark extends CommonDBTM {
 
-   var $auto_message_on_action=false;
+   var       $auto_message_on_action = false;
+   protected $displaylist            = false;
 
    const WIDTH  = 750;
    const SEARCH = 1; //SEARCH SYSTEM bookmark
@@ -243,7 +244,8 @@ class Bookmark extends CommonDBTM {
          echo "<input type='submit' name='delete' value=\"".$LANG['buttons'][6]."\" class='submit'>";
          echo "</div></td></tr>";
       }
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 
@@ -313,7 +315,9 @@ class Bookmark extends CommonDBTM {
                unset($query_tab['link']);
                $new_key = 0;
                foreach ($query_tab_save['field'] as $key => $val) {
-                  if ($val != 'view' && $val != 'all' && !isset($opt[$val])) {
+                  if ($val != 'view' && $val != 'all'
+                     && (!isset($opt[$val])
+                           || (isset($opt[$val]['nosearch']) && $opt[$val]['nosearch']))) {
                      $query_tab['glpisearchcount']--;
                      $partial_load = true;
                   } else {
@@ -335,7 +339,8 @@ class Bookmark extends CommonDBTM {
             }
 
             // Meta search
-            if (isset($query_tab_save['itemtype2']) && count($query_tab_save['itemtype2'])) {
+            if (isset($query_tab_save['itemtype2']) && count($query_tab_save['itemtype2'])
+                && isset($query_tab_save['field2'])) {
                $meta_ok = Search::getMetaItemtypeAvailable($query_tab['itemtype']);
 
                unset($query_tab['field2']);
@@ -590,7 +595,7 @@ class Bookmark extends CommonDBTM {
          } else {
             echo "<tr class='tab_bg_1'><td colspan='5'>".$LANG['bookmark'][3]."</td></tr></table>";
          }
-         echo '</form>';
+         Html::closeForm();
       }
    }
 
