@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridge.class.php 17956 2012-03-21 09:13:14Z moyo $
+ * @version $Id: cartridge.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -144,10 +144,14 @@ class Cartridge extends CommonDBTM {
    function updateCartUse($date_use) {
       global $DB;
 
-      return $this->update(array('id'       => $this->fields['id'],
-                                 'date_use' => $date_use));
+      if ($date_use && ($date_use != 'NULL')) {
+         return $this->update(array('id'       => $this->fields['id'],
+                                    'date_use' => $date_use));
+      }
+      return false;
    }
 
+
   /**
    * Update count pages and date out value of a cartridge
    *
@@ -159,11 +163,15 @@ class Cartridge extends CommonDBTM {
    function updateCartOut($pages, $date_out) {
       global $DB;
 
+      if ($date_out == 'NULL') {
+         $pages = 0;
+      }
       return $this->update(array('id'       => $this->fields['id'],
                                  'date_out' => $date_out,
                                  'pages'    => $pages));
    }
 
+
    /**
    * Link a cartridge to a printer.
    *
@@ -639,7 +647,9 @@ class Cartridge extends CommonDBTM {
          Dropdown::showInteger('to_add',1,1,100);
          echo "</span>&nbsp;";
          echo $LANG['cartridges'][16]."</td></tr>";
-         echo "</table></form></div>";
+         echo "</table>";
+         Html::closeForm();
+         echo "</div>";
       }
    }
 
@@ -720,12 +730,12 @@ class Cartridge extends CommonDBTM {
                 $data["type"]." - ".$data["ref"]."</a></td>";
          echo "<td class='center'>".$date_in."</td>";
          echo "<td class='center'>";
-         
+
          if ($old==0 && $canedit) {
-            Html::showDateFormItem("date_use[$cart_id]", $date_use, true, true, $date_in);
+            Html::showDateFormItem("date_use[$cart_id]", $data["date_use"], false, true, $date_in);
          } else {
             echo $date_use;
-         }         
+         }
 
          $tmp_dbeg = explode("-", $data["date_in"]);
          $tmp_dend = explode("-", $data["date_use"]);
@@ -738,10 +748,11 @@ class Cartridge extends CommonDBTM {
             echo "</td>";
             echo "<td class='center'>";
             if ($canedit) {
-               Html::showDateFormItem("date_out[$cart_id]", $date_out, true, true, $date_use);
+               Html::showDateFormItem("date_out[$cart_id]", $data["date_out"], true, true,
+                                      $date_use);
             } else {
                echo $date_out;
-            }            
+            }
 
             $tmp_dbeg = explode("-", $data["date_use"]);
             $tmp_dend = explode("-", $data["date_out"]);
@@ -749,9 +760,9 @@ class Cartridge extends CommonDBTM {
             $use_time_tmp = mktime(0, 0, 0, $tmp_dend[1], $tmp_dend[2], $tmp_dend[0])
                             - mktime(0, 0, 0, $tmp_dbeg[1], $tmp_dbeg[2], $tmp_dbeg[0]);
             $use_time+=$use_time_tmp;
-            
+
             echo "</td><td class='left'>";
-            
+
             if ($canedit) {
                echo "<input type='text' name='pages[$cart_id]' value=\"".$data['pages']."\" size='6'>";
             } else {
@@ -816,8 +827,8 @@ class Cartridge extends CommonDBTM {
       }
       echo "</table></div>";
       if ($canedit) {
-         echo "</form>";
-      }      
+         Html::closeForm();
+      }
    }
 
 
