@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: cartridgeitem.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: cartridgeitem.class.php 18839 2012-07-04 17:12:00Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -570,7 +570,9 @@ class CartridgeItem extends CommonDBTM {
          echo "<input type='submit' name='addtype' value=\"".$LANG['buttons'][8]."\" class='submit'>";
          echo "</td></tr>";
       }
-      echo "</table></div></form>";
+      echo "</table>";
+      Html::closeForm();
+      echo "</div>";
    }
 
 
