@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondbrelation.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: commondbrelation.class.php 17847 2012-03-15 07:06:52Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -42,7 +42,8 @@ abstract class CommonDBRelation extends CommonDBTM {
 
    var $check_entities = true;
 
-   var $checks_and_logs_only_for_itemtype1 = false;
+   var $checks_only_for_itemtype1 = false;
+   var $logs_only_for_itemtype1   = false;
 
 
    /**
@@ -102,34 +103,34 @@ abstract class CommonDBRelation extends CommonDBTM {
       if (preg_match('/^itemtype/',$this->itemtype_1)) {
          $type1 = $input[$this->itemtype_1];
       }
-
-      if (!class_exists($type1)) {
+      if (!($item1 = getItemForItemtype($type1))) {
          return false;
       }
 
-      $item1 = new $type1();
       // Can create a relation with a dropdown/device (use it) without read right
       if (!($item1 instanceof CommonDropdown)
           && !$item1->can($input[$this->items_id_1],'r')) {
          return false;
       }
 
+
       // Must can read second Item of the relation
       $type2 = $this->itemtype_2;
       if (preg_match('/^itemtype/',$this->itemtype_2)) {
          $type2 = $input[$this->itemtype_2];
       }
 
-      if (!class_exists($type2)) {
+      if (!($item2 = getItemForItemtype($type2))) {
          return false;
       }
-      $item2 = new $type2();
-      if (!$this->checks_and_logs_only_for_itemtype1
+
+      if (!$this->checks_only_for_itemtype1
           && !($item2 instanceof CommonDropdown)) {
          if (!$item2->can($input[$this->items_id_2],'r')) {
             return false;
          }
       } else {
+         // TODO : need to be improved, only some classe should allow relation to 0
          // id==0 is used in some relation (tickets_users)
          if ($input[$this->items_id_2]>0 && !$item2->getFromDB($input[$this->items_id_2])) {
             return false;
@@ -143,7 +144,7 @@ abstract class CommonDBRelation extends CommonDBTM {
 
       // Check entity compatibility / no check for delete just check write access
       // No check if checking only itemtype1
-      if (!$this->checks_and_logs_only_for_itemtype1
+      if (!$this->checks_only_for_itemtype1
           && $this->check_entities
           && $right!='d') {
 
@@ -180,7 +181,7 @@ abstract class CommonDBRelation extends CommonDBTM {
 
       // can write one item is enough
       if ($item1->can($input[$this->items_id_1],'w')
-          || ($this->checks_and_logs_only_for_itemtype1
+          || ($this->checks_only_for_itemtype1
               || $item2->can($input[$this->items_id_2],'w'))) {
          return true;
       }
@@ -205,11 +206,10 @@ abstract class CommonDBRelation extends CommonDBTM {
          $type1 = $this->fields[$this->itemtype_1];
       }
 
-      if (!class_exists($type1)) {
+      if (!($item1 = getItemForItemtype($type1))) {
          return false;
       }
 
-      $item1 = new $type1();
       if (!$item1->getFromDB($this->fields[$this->items_id_1])) {
          return false;
       }
@@ -219,11 +219,10 @@ abstract class CommonDBRelation extends CommonDBTM {
          $type2 = $this->fields[$this->itemtype_2];
       }
 
-      if (!class_exists($type2)) {
+      if (!($item2 = getItemForItemtype($type2))) {
          return false;
       }
 
-      $item2 = new $type2();
       if (!$item2->getFromDB($this->fields[$this->items_id_2])) {
          return false;
       }
@@ -233,15 +232,15 @@ abstract class CommonDBRelation extends CommonDBTM {
          $changes[1] = "";
          $changes[2] = addslashes($item2->getNameID(false, true));
          Log::history($item1->fields["id"], get_class($item1), $changes, get_class($item2),
-                      HISTORY_ADD_RELATION);
+                      Log::HISTORY_ADD_RELATION);
       }
 
-      if (!$this->checks_and_logs_only_for_itemtype1 && $item2->dohistory) {
+      if (!$this->logs_only_for_itemtype1 && $item2->dohistory) {
          $changes[0] = '0';
          $changes[1] = "";
          $changes[2] = addslashes($item1->getNameID(false, true));
          Log::history($item2->fields["id"], get_class($item2), $changes, get_class($item1),
-                      HISTORY_ADD_RELATION);
+                      Log::HISTORY_ADD_RELATION);
       }
    }
 
@@ -263,11 +262,10 @@ abstract class CommonDBRelation extends CommonDBTM {
          $type1 = $this->fields[$this->itemtype_1];
       }
 
-      if (!class_exists($type1)) {
+      if (!($item1 = getItemForItemtype($type1))) {
          return false;
       }
 
-      $item1 = new $type1();
       if (!$item1->getFromDB($this->fields[$this->items_id_1])) {
          return false;
       }
@@ -278,11 +276,10 @@ abstract class CommonDBRelation extends CommonDBTM {
          $type2 = $this->fields[$this->itemtype_2];
       }
 
-      if (!class_exists($type2)) {
+      if (!($item2 = getItemForItemtype($type2))) {
          return false;
       }
 
-      $item2 = new $type2();
       if (!$item2->getFromDB($this->fields[$this->items_id_2])) {
          return false;
       }
@@ -292,15 +289,15 @@ abstract class CommonDBRelation extends CommonDBTM {
          $changes[1] = addslashes($item2->getNameID(false, true));
          $changes[2] = "";
          Log::history($item1->fields["id"], get_class($item1), $changes, get_class($item2),
-                      HISTORY_DEL_RELATION);
+                      Log::HISTORY_DEL_RELATION);
       }
 
-      if (!$this->checks_and_logs_only_for_itemtype1 && $item2->dohistory) {
+      if (!$this->logs_only_for_itemtype1 && $item2->dohistory) {
          $changes[0] = '0';
          $changes[1] = addslashes($item1->getNameID(false, true));
          $changes[2] = "";
          Log::history($item2->fields["id"], get_class($item2), $changes, get_class($item1),
-                      HISTORY_DEL_RELATION);
+                      Log::HISTORY_DEL_RELATION);
       }
    }
 
