@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondbtm.class.php 17756 2012-03-08 07:56:45Z remi $
+ * @version $Id: commondbtm.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -671,7 +671,7 @@ class CommonDBTM extends CommonGLPI {
 
       if ($this->input && is_array($this->input)) {
          //Check values to inject
-         $this->filterValues();
+         $this->filterValues(!isCommandLine());
       }
 
       if ($this->input && is_array($this->input)) {
@@ -882,7 +882,7 @@ class CommonDBTM extends CommonGLPI {
             unset($this->input['update']);
          }
 
-         $this->filterValues();
+         $this->filterValues(!isCommandLine());
       }
 
       // Valid input for update
@@ -1630,6 +1630,21 @@ class CommonDBTM extends CommonGLPI {
    }
 
 
+   /**
+    * check if this action can be done on this field of this item by massive actions
+    *
+    * @since 0.83
+    *
+    * @param $action    string   name of the action
+    * @param $field     integer  id of the field
+    * @param $value     string   value of the field
+    *
+   **/
+   function canMassiveAction($action, $field, $value){
+      return true;
+   }
+
+
    /**
     * Display a 2 columns Footer for Form buttons
     * Close the form is user can edit
@@ -1669,7 +1684,7 @@ class CommonDBTM extends CommonGLPI {
          echo "</table></div>";
          // Form Header always open form
          if (!$params['canedit']) {
-            echo "</form>";
+            Html::closeForm();
          }
          return false;
       }
@@ -1718,6 +1733,9 @@ class CommonDBTM extends CommonGLPI {
             echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\"
                    class='submit'>";
          }
+         if ($this->isField('date_mod')) {
+            echo "<input type='hidden' name='_read_date_mod' value='".$this->getField('date_mod')."'>";
+         }
       }
 
       if ($ID>0) {
@@ -1739,7 +1757,8 @@ class CommonDBTM extends CommonGLPI {
       }
 
       // Close for Form
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 
@@ -2914,7 +2933,7 @@ class CommonDBTM extends CommonGLPI {
       echo "</table></div>";
 
       if ($canedit) {
-         echo "</form>";
+         Html::closeForm();
       }
    }
 
