@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commondropdown.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: commondropdown.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -121,6 +121,21 @@ abstract class CommonDropdown extends CommonDBTM {
    }
 
 
+   function prepareInputForAdd($input) {
+
+      if (isset($input['name'])) {
+         // leading/ending space will break findID/import
+         $input['name'] = trim($input['name']);
+      }
+      return $input;
+   }
+
+
+   function prepareInputForUpdate($input) {
+      return self::prepareInputForAdd($input);
+   }
+
+
    function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
@@ -408,7 +423,7 @@ abstract class CommonDropdown extends CommonDBTM {
          echo "<td><input class='button' type='submit' name='annuler' value=\"".
                     $LANG['buttons'][34]."\">";
          echo "</td></tr></table>\n";
-         echo "</form>";
+         Html::closeForm();
       }
 
       // Replace form (set to new value)
@@ -437,7 +452,7 @@ abstract class CommonDropdown extends CommonDBTM {
       echo "</td><td>";
       echo "<input class='button' type='submit' name='annuler' value=\"".$LANG['buttons'][34]."\">";
       echo "</td></tr></table>\n";
-      echo "</form>";
+      Html::closeForm();
       echo "</div>";
    }
 
