@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commonglpi.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: commonglpi.class.php 17239 2012-01-27 10:22:43Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -43,6 +43,7 @@ class CommonGLPI {
 
    public $showdebug      = false;
 
+   static protected $othertabs = array();
 
    /**
     * Return the localized name of the current Type
@@ -71,19 +72,243 @@ class CommonGLPI {
    }
 
 
+   /**
+    * Register tab on an objet
+    *
+    * @since version 0.83
+    *
+    * @param $typeform string object class name to add tab on form
+    * @param $typetab  string object class name which manage the tab
+   **/
+   static function registerStandardTab($typeform, $typetab) {
+
+      if (isset(self::$othertabs[$typeform])) {
+         self::$othertabs[$typeform][] = $typetab;
+      } else {
+         self::$othertabs[$typeform] = array($typetab);
+      }
+   }
+
+
+   /**
+    * Get the array of Tab managed by other types
+    * Getter for plugin (ex PDF) to access protected property
+    *
+    * @since version 0.83
+    *
+    * @param $typeform string object class name to add tab on form
+    *
+    * @return array of types
+   **/
+   static function getOtherTabs($typeform) {
+
+      if (isset(self::$othertabs[$typeform])) {
+         return self::$othertabs[$typeform];
+      }
+      return array();
+   }
+
+
    /**
     * Define tabs to display
     *
+    * NB : Only called for existing object
+    *
     * @param $options array
     *     - withtemplate is a template view ?
     *
-    *  @return array containing the onglets
+    * @return array containing the onglets
    **/
    function defineTabs($options=array()) {
       return array();
    }
 
 
+   /**
+    * return all the tabs for current object
+    *
+    * @since version 0.83
+    *
+    * @param $options array
+    *     - withtemplate is a template view ?
+    *
+    * @return array containing the onglets
+   **/
+   final function defineAllTabs($options=array()) {
+
+      // Tabs known by the object
+      if ($this->isNewItem()) {
+         $onglets  = array();
+      } else {
+         $onglets  = $this->defineTabs($options);
+      }
+
+      // Object with class with 'addtabon' attribute
+      if (isset(self::$othertabs[$this->getType()]) && !$this->isNewItem()) {
+         foreach(self::$othertabs[$this->getType()] as $typetab) {
+            $this->addStandardTab($typetab, $onglets, $options);
+         }
+      }
+
+      // Single tab
+      if (empty($onglets)) {
+         $onglets['empty'] = $this->getTypeName();
+      }
+
+      return $onglets;
+   }
+
+
+   /**
+    * Add standard define tab
+    *
+    * @param $itemtype  itemtype link to the tab
+    * @param $ong       array defined tab array
+    * @param $options   array of options (for withtemplate)
+    *
+    *  @return nothing (set the tab array)
+   **/
+   function addStandardTab($itemtype, &$ong, $options) {
+      global $LANG;
+
+      $withtemplate = 0;
+      if (isset($options['withtemplate'])) {
+         $withtemplate = $options['withtemplate'];
+      }
+
+      switch ($itemtype) {
+         case 'Note' :
+            if (Session::haveRight("notes","r")) {
+               $ong['Note'] = $LANG['title'][37];
+            }
+            break;
+
+         default :
+            if (!is_integer($itemtype) && ($obj = getItemForItemtype($itemtype))) {
+               $titles = $obj->getTabNameForItem($this, $withtemplate);
+               if (!is_array($titles)) {
+                  $titles = array(1 => $titles);
+               }
+
+               foreach ($titles as $key => $val) {
+                  if (!empty($val)) {
+                     $ong[$itemtype.'$'.$key] = $val;
+                  }
+               }
+            }
+            break;
+      }
+   }
+
+
+   /**
+    * Get Tab Name used for itemtype
+    *
+    * NB : Only called for existing object
+    *      Must check right on what will be displayed + template
+    *
+    * @since version 0.83
+    *
+    * @param $item         CommonDBTM object for which the tab need to be displayed
+    * @param $withtemplate boolean is a template object ?
+    *
+    *  @return string tab name
+   **/
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      return '';
+   }
+
+
+   /**
+    * show Tab content
+    *
+    * @since version 0.83
+    *
+    * @param $item         CommonGLPI object for which the tab need to be displayed
+    * @param $tabnum       integer tab number
+    * @param $withtemplate boolean is a template object ?
+    *
+    * @return true
+   **/
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+      return false;
+   }
+
+
+   /**
+    * display standard tab contents
+    *
+    * @param $item CommonGLPI object for which the tab need to be displayed
+    * @param $tab string tab name
+    * @param $withtemplate boolean is a template object ?
+    *
+    * @return true
+   **/
+   static function displayStandardTab(CommonGLPI $item, $tab, $withtemplate=0) {
+
+      switch ($tab) {
+         // All tab
+         case -1 :
+            // get tabs and loop over
+            $ong = $item->defineAllTabs(array('withtemplate' => $withtemplate));
+            if (count($ong)) {
+               foreach ($ong as $key => $val) {
+                  if ($key != 'empty') {
+                     echo "<div class='alltab'>$val</div>";
+                     self::displayStandardTab($item, $key, $withtemplate);
+                  }
+               }
+            }
+            // Display plugin datas
+            Plugin::displayAction($item, $tab);
+            return true;
+
+         case 'Note' :
+            $item->showNotesForm();
+            return true;
+
+         default :
+            if (Plugin::displayAction($item, $tab, $withtemplate)) {
+               return true;
+            }
+
+            $data     = explode('$',$tab);
+            $itemtype = $data[0];
+            // Default set
+            $tabnum   = 1;
+            if (isset($data[1])) {
+               $tabnum = $data[1];
+            }
+
+            if (!is_integer($itemtype)
+                && $itemtype!='empty'
+                && ($obj = getItemForItemtype($itemtype))) {
+               return $obj->displayTabContentForItem($item, $tabnum, $withtemplate);
+            }
+            break;
+      }
+      return false;
+
+   }
+
+
+   /**
+    * create tab text entry
+    *
+    * @param $text string text to display
+    * @param $nb integer number of items
+    *
+    *  @return array containing the onglets
+   **/
+   static function createTabEntry($text, $nb=0) {
+
+      if ($nb) {
+         $text .= "<sup>($nb)</sup>";
+      }
+      return $text;
+   }
+
+
    /**
     * Redirect to the list page from which the item was selected
     * Default to the search engine for the type
@@ -93,19 +318,31 @@ class CommonGLPI {
 
       if (isset($_GET['withtemplate'])
           && !empty($_GET['withtemplate'])) {
-         glpi_header($CFG_GLPI["root_doc"]."/front/setup.templates.php?add=0&itemtype=".
+         Html::redirect($CFG_GLPI["root_doc"]."/front/setup.templates.php?add=0&itemtype=".
                      $this->getType());
 
       } else if (isset($_SESSION['glpilisturl'][$this->getType()])
                  && !empty($_SESSION['glpilisturl'][$this->getType()])) {
-         glpi_header($_SESSION['glpilisturl'][$this->getType()]);
+         Html::redirect($_SESSION['glpilisturl'][$this->getType()]);
 
       } else {
-         glpi_header($this->getSearchURL());
+         Html::redirect($this->getSearchURL());
       }
    }
 
 
+   /**
+    * is the current object a new  one - Always false here (virtual Objet)
+    *
+    * @since version 0.83
+    *
+    * @return boolean
+    */
+   function isNewItem() {
+      return false;
+   }
+
+
    /**
     * Show onglets
     *
@@ -134,8 +371,10 @@ class CommonGLPI {
             $withtemplate = $options['withtemplate'];
          }
          foreach ($options as $key => $val) {
-            $extraparamhtml .= "&amp;$key=$val";
-            $extraparam     .= "&$key=$val";
+            if ($key[0] != '_') {
+               $extraparamhtml .= "&amp;$key=$val";
+               $extraparam     .= "&$key=$val";
+            }
          }
       }
 
@@ -176,7 +415,7 @@ class CommonGLPI {
 
             }
          }
-         $cleantarget = cleanParametersURL($target);
+         $cleantarget = HTML::cleanParametersURL($target);
          echo "<ul>";
          echo "<li><a href=\"javascript:showHideDiv('tabsbody','tabsbodyimg','".$CFG_GLPI["root_doc"].
                     "/pics/deplier_down.png','".$CFG_GLPI["root_doc"]."/pics/deplier_up.png')\">";
@@ -186,9 +425,9 @@ class CommonGLPI {
          echo "<li><a href=\"".$glpilisturl."\">";
 
          if ($glpilisttitle) {
-            if (utf8_strlen($glpilisttitle) > $_SESSION['glpidropdown_chars_limit']) {
-               $glpilisttitle = utf8_substr($glpilisttitle, 0,
-                                            $_SESSION['glpidropdown_chars_limit'])
+            if (Toolbox::strlen($glpilisttitle) > $_SESSION['glpidropdown_chars_limit']) {
+               $glpilisttitle = Toolbox::substr($glpilisttitle, 0,
+                                                $_SESSION['glpidropdown_chars_limit'])
                                 . "&hellip;";
             }
             echo $glpilisttitle;
@@ -243,7 +482,8 @@ class CommonGLPI {
       echo "<div id='tabspanel' class='center-h'></div>";
 
       $active      = 0;
-      $onglets     = $this->defineTabs($options);
+      $onglets = $this->defineAllTabs($options);
+
       $display_all = true;
       if (isset($onglets['no_all_tab'])) {
          $display_all = false;
@@ -251,7 +491,7 @@ class CommonGLPI {
       }
 
       $class = $this->getType();
-      if ($_SESSION['glpi_use_mode']==DEBUG_MODE
+      if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE
           && ($ID > 0 || $this->showdebug)
           && (method_exists($class, 'showDebug')
               || in_array($class, $CFG_GLPI["infocom_types"])
@@ -271,8 +511,10 @@ class CommonGLPI {
                                             "&glpi_tab=$key&id=$ID$extraparam");
          }
 
+         // Plugin with plugin_get_headings_xxx
          $plug_tabs = Plugin::getTabs($target,$this, $withtemplate);
          $tabs += $plug_tabs;
+
          // Not all tab for templates and if only 1 tab
          if ($display_all && empty($withtemplate) && count($tabs)>1) {
             $tabs[-1] = array('title'  => $LANG['common'][66],
@@ -281,7 +523,7 @@ class CommonGLPI {
                                           "&glpi_tab=-1&id=$ID$extraparam");
          }
 
-         createAjaxTabs('tabspanel', 'tabcontent', $tabs, $this->getType());
+         Ajax::createTabs('tabspanel', 'tabcontent', $tabs, $this->getType());
       }
    }
 
@@ -292,7 +534,7 @@ class CommonGLPI {
     * @param $full path or relative one
    **/
    function getTabsURL($full=true) {
-      return getItemTypeTabsURL(get_class($this), $full);
+      return Toolbox::getItemTypeTabsURL(get_class($this), $full);
    }
 
 
@@ -302,7 +544,7 @@ class CommonGLPI {
     * @param $full path or relative one
    **/
    function getSearchURL($full=true) {
-      return getItemTypeSearchURL(get_class($this), $full);
+      return Toolbox::getItemTypeSearchURL(get_class($this), $full);
    }
 
 
@@ -312,16 +554,24 @@ class CommonGLPI {
     * @param $full path or relative one
    **/
    function getFormURL($full=true) {
-      return getItemTypeFormURL(get_class($this), $full);
+      return Toolbox::getItemTypeFormURL(get_class($this), $full);
+   }
+
+
+   /**
+    * Add div to display form's tabs
+   **/
+   function addDivForTabs() {
+
+      echo "<div id='tabcontent'>&nbsp;</div>";
+      echo "<script type='text/javascript'>loadDefaultTab();</script>";
    }
 
 
    function show() {
 
-      $this->showTabs(0);
-
-      echo "<div id='tabcontent'>&nbsp;</div>";
-      echo "<script type='text/javascript'>loadDefaultTab();</script>";
+      $this->showTabs();
+      $this->addDivForTabs();
    }
 
 
