@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: commonitiltask.class.php 18086 2012-03-28 21:48:34Z yllen $
+ * @version $Id: commonitiltask.class.php 18849 2012-07-05 11:12:13Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -324,6 +324,8 @@ abstract class CommonITILTask  extends CommonDBTM {
 
          $this->fields['is_private'] = 1;
       }
+      // Default is todo
+      $this->fields['state'] = 1;
    }
 
 
@@ -458,30 +460,30 @@ abstract class CommonITILTask  extends CommonDBTM {
       if ($who_group==="mine") {
          if (count($_SESSION["glpigroups"])) {
             $groups = implode("','",$_SESSION['glpigroups']);
-            $ASSIGN = "`users_id` IN (SELECT DISTINCT `users_id`
+            $ASSIGN = "`users_id_tech` IN (SELECT DISTINCT `users_id`
                                       FROM `glpi_groups_users`
                                       WHERE `groups_id` IN ('$groups'))
                                             AND ";
          } else { // Only personal ones
-            $ASSIGN = "`users_id` = '$who'
+            $ASSIGN = "`users_id_tech` = '$who'
                        AND ";
          }
 
       } else {
          if ($who>0) {
-            $ASSIGN = "`users_id` = '$who'
+            $ASSIGN = "`users_id_tech` = '$who'
                        AND ";
          }
 
          if ($who_group>0) {
-            $ASSIGN = "`users_id` IN (SELECT `users_id`
+            $ASSIGN = "`users_id_tech` IN (SELECT `users_id`
                                       FROM `glpi_groups_users`
                                       WHERE `groups_id` = '$who_group')
                                             AND ";
          }
       }
       if (empty($ASSIGN)) {
-         $ASSIGN = "`users_id` IN (SELECT DISTINCT `glpi_profiles_users`.`users_id`
+         $ASSIGN = "`users_id_tech` IN (SELECT DISTINCT `glpi_profiles_users`.`users_id`
                                    FROM `glpi_profiles`
                                    LEFT JOIN `glpi_profiles_users`
                                      ON (`glpi_profiles`.`id` = `glpi_profiles_users`.`profiles_id`)
@@ -565,10 +567,11 @@ abstract class CommonITILTask  extends CommonDBTM {
       global $CFG_GLPI;
 
       $item = new $itemtype();
+      $objectitemtype = $item->getItilObjectItemType();
       $out  = $item->getTypeName().' : '.Html::convDateTime($val["begin"]).' -> '.
               Html::convDateTime($val["end"]).' : ';
-      $out .= "<a href='".Toolbox::getItemTypeFormURL($itemtype)."?id=".
-                $val[getForeignKeyFieldForItemType($itemtype)]."'>";
+      $out .= "<a href='".Toolbox::getItemTypeFormURL($objectitemtype)."?id=".
+                $val[getForeignKeyFieldForItemType($objectitemtype)]."&amp;forcetab=".$itemtype."$1'>";
       $out .= Html::resume_text($val["name"],80).'</a>';
 
       return $out;
@@ -817,11 +820,17 @@ abstract class CommonITILTask  extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['job'][31]."&nbsp;:</td><td>";
+      $toadd = array();
+      for ($i=9;$i<=100;$i++) {
+         $toadd[] = $i*HOUR_TIMESTAMP;
+      }
 
       Dropdown::showTimeStamp("actiontime",array('min'             => 0,
                                                  'max'             => 8*HOUR_TIMESTAMP,
                                                  'value'           => $this->fields["actiontime"],
-                                                 'addfirstminutes' => true));
+                                                 'addfirstminutes' => true,
+                                                 'inhours'          => true,
+                                                 'toadd'           => $toadd));
 
       echo "</td></tr>\n";
 
