@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: computer.class.php 17831 2012-03-13 16:09:45Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -68,73 +68,37 @@ class Computer extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('computer', 'w');
+      return Session::haveRight('computer', 'w');
    }
 
 
    function canView() {
-      return haveRight('computer', 'r');
+      return Session::haveRight('computer', 'r');
    }
 
 
    function defineTabs($options=array()) {
       global $LANG, $CFG_GLPI;
 
-      if ($this->fields['id'] > 0) {
-         $ong[1]  = $LANG['title'][30];
-         $ong[20] = $LANG['computers'][8];
+      $ong = array();
+      $this->addStandardTab('DeviceProcessor', $ong, $options); // All devices : use one to define tab
+      $this->addStandardTab('ComputerDisk', $ong, $options);
+      $this->addStandardTab('Computer_SoftwareVersion', $ong, $options);
+      $this->addStandardTab('Computer_Item', $ong, $options);
+      $this->addStandardTab('NetworkPort', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Contract_Item', $ong, $options);
+      $this->addStandardTab('Document', $ong, $options);
+      $this->addStandardTab('ComputerVirtualMachine', $ong, $options);
+      $this->addStandardTab('RegistryKey', $ong, $options);
+      $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Item_Problem', $ong, $options);      
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
+      $this->addStandardTab('Reservation', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
+      $this->addStandardTab('OcsLink', $ong, $options);
 
-         if (haveRight("software","r")) {
-            $ong[2] = $LANG['Menu'][4];
-         }
-
-         if (haveRight("networking","r")
-             || haveRight("printer","r")
-             || haveRight("monitor","r")
-             || haveRight("peripheral","r")
-             || haveRight("phone","r")) {
-
-            $ong[3] = $LANG['title'][27];
-         }
-
-         if (haveRight("contract","r") || haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-
-         Document::addTab($this,$ong);
-
-         if (!isset($options['withtemplate']) || empty($options['withtemplate'])) {
-
-            $ong[21] = $LANG['computers'][57];
-
-            if ($CFG_GLPI["use_ocs_mode"]) {
-               $ong[14] = $LANG['title'][43];
-            }
-            if (haveRight("show_all_ticket","1")) {
-               $ong[6] = $LANG['title'][28];
-            }
-            if (haveRight("link","r")) {
-               $ong[7] = $LANG['title'][34];
-            }
-            if (haveRight("notes","r")) {
-               $ong[10] = $LANG['title'][37];
-            }
-            if (haveRight("reservation_central","r")) {
-               $ong[11] = $LANG['Menu'][17];
-            }
-
-            $ong[12] = $LANG['title'][38];
-
-            if ($CFG_GLPI["use_ocs_mode"]
-                && (haveRight("sync_ocsng","w") ||haveRight("computer","w"))) {
-
-               $ong[13] = $LANG['Menu'][33];
-            }
-         }
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
       return $ong;
    }
 
@@ -209,7 +173,7 @@ class Computer extends CommonDBTM {
             }
 
             if ($update_done) {
-               addMessageAfterRedirect($LANG['computers'][49], true);
+               Session::addMessageAfterRedirect($LANG['computers'][49], true);
             }
          }
 
@@ -260,7 +224,7 @@ class Computer extends CommonDBTM {
                }
             }
             if ($update_done) {
-               addMessageAfterRedirect($LANG['computers'][50], true);
+               Session::addMessageAfterRedirect($LANG['computers'][50], true);
             }
          }
 
@@ -296,7 +260,7 @@ class Computer extends CommonDBTM {
                }
             }
             if ($update_done) {
-               addMessageAfterRedirect($LANG['computers'][56], true);
+               Session::addMessageAfterRedirect($LANG['computers'][56], true);
             }
          }
 
@@ -336,7 +300,7 @@ class Computer extends CommonDBTM {
                }
             }
             if ($update_done) {
-               addMessageAfterRedirect($LANG['computers'][48], true);
+               Session::addMessageAfterRedirect($LANG['computers'][48], true);
             }
          }
       }
@@ -365,7 +329,7 @@ class Computer extends CommonDBTM {
          $compdev->cloneComputer($this->input["_oldID"], $this->fields['id']);
 
          // ADD Infocoms
-         $ic = new Infocom();
+         $ic= new Infocom();
          $ic->cloneItem($this->getType(), $this->input["_oldID"], $this->fields['id']);
 
          // ADD volumes
@@ -519,10 +483,6 @@ class Computer extends CommonDBTM {
    function showForm($ID, $options=array()) {
       global $LANG, $CFG_GLPI, $DB;
 
-      if (!haveRight("computer","r")) {
-        return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -533,14 +493,14 @@ class Computer extends CommonDBTM {
       if (isset($options['withtemplate']) && $options['withtemplate'] == 2) {
          $template   = "newcomp";
          $datestring = $LANG['computers'][14]." : ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
       } else if (isset($options['withtemplate']) && $options['withtemplate'] == 1) {
          $template   = "newtemplate";
          $datestring = $LANG['computers'][14]." : ";
-         $date       = convDateTime($_SESSION["glpi_currenttime"]);
+         $date       = Html::convDateTime($_SESSION["glpi_currenttime"]);
       } else {
          $datestring = $LANG['common'][26].": ";
-         $date       = convDateTime($this->fields["date_mod"]);
+         $date       = Html::convDateTime($this->fields["date_mod"]);
          $template   = false;
       }
 
@@ -552,7 +512,7 @@ class Computer extends CommonDBTM {
       echo "<td>";
       $objectName = autoName($this->fields["name"], "name", ($template === "newcomp"),
                              $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'name', array('value' => $objectName));
+      Html::autocompletionTextField($this, 'name', array('value' => $objectName));
       echo "</td>";
       echo "<td>".$LANG['state'][0]."&nbsp;:</td>";
       echo "<td>";
@@ -584,9 +544,12 @@ class Computer extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][21]."&nbsp;: </td>";
-      echo "<td >";
-      autocompletionTextField($this,'contact_num');
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
 
       echo "</td>";
       echo "<td>".$LANG['common'][22]."&nbsp;: </td>";
@@ -595,15 +558,25 @@ class Computer extends CommonDBTM {
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][18]."&nbsp;:</td>";
-      echo "<td>";
-      autocompletionTextField($this,'contact');
-
+      echo "<td>".$LANG['common'][21]."&nbsp;: </td>";
+      echo "<td >";
+      Html::autocompletionTextField($this,'contact_num');
       echo "</td>";
       echo "<td>".$LANG['common'][19]."&nbsp;:</td>";
       echo "<td >";
-      autocompletionTextField($this,'serial');
+      Html::autocompletionTextField($this,'serial');
+      echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][18]."&nbsp;:</td>";
+      echo "<td>";
+      Html::autocompletionTextField($this,'contact');
+      echo "</td>";
+      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
+      echo "<td>";
+      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
+                             $this->getType(), $this->fields["entities_id"]);
+      Html::autocompletionTextField($this, 'otherserial', array('value' => $objectName));
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
@@ -613,34 +586,55 @@ class Computer extends CommonDBTM {
                            'entity' => $this->fields["entities_id"],
                            'right'  => 'all'));
       echo "</td>";
-      echo "<td>".$LANG['common'][20].($template?"*":"")."&nbsp;:</td>";
-      echo "<td>";
-      $objectName = autoName($this->fields["otherserial"], "otherserial", ($template === "newcomp"),
-                             $this->getType(), $this->fields["entities_id"]);
-      autocompletionTextField($this, 'otherserial', array('value' => $objectName));
-      echo "</td></tr>\n";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
-      echo "<td>";
-      Dropdown::show('Group', array('value'  => $this->fields["groups_id"],
-                                    'entity' => $this->fields["entities_id"]));
-
-      echo "</td>";
       echo "<td>".$LANG['setup'][88]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::show('Network', array('value' => $this->fields["networks_id"]));
       echo "</td></tr>\n";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][35]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('value'     => $this->fields["groups_id"],
+                                    'entity'    => $this->fields["entities_id"],
+                                    'condition' => '`is_itemgroup`'));
+
+      echo "</td>";
+      
+      // Get OCS Datas :
+      $dataocs = array();
+      $rowspan = 10;
+      $ocs_show = false;
+      
+      if (!empty($ID)
+          && $this->fields["is_ocs_import"]
+          && Session::haveRight("view_ocsng","r")) {
+
+         $query = "SELECT *
+                   FROM `glpi_ocslinks`
+                   WHERE `computers_id` = '$ID'";
+
+         $result = $DB->query($query);
+         if ($DB->numrows($result)==1) {
+            $dataocs = $DB->fetch_array($result);
+         }
+      }      
+      
+      if (count($dataocs)) {
+         $ocs_config = OcsServer::getConfig(OcsServer::getByMachineID($ID));
+         $ocs_show = true;
+         $rowspan -=4;    
+      }
+      
+      echo "<td rowspan='$rowspan'>".$LANG['common'][25]."&nbsp;:</td>";
+      echo "<td rowspan='$rowspan' class='middle'>";
+      echo "<textarea cols='45' rows='".($rowspan+3)."' name='comment' >".$this->fields["comment"]."</textarea>";
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['setup'][89]."&nbsp;:</td>";
       echo "<td >";
       Dropdown::show('Domain', array('value' => $this->fields["domains_id"]));
-      echo "</td>";
-      echo "<td rowspan='8'>".$LANG['common'][25]."&nbsp;:</td>";
-      echo "<td rowspan='8' class='middle'>";
-      echo "<textarea cols='45' rows='11' name='comment' >".$this->fields["comment"]."</textarea>";
-      echo "</td></tr>\n";
+      echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['computers'][9]."&nbsp;:</td>";
@@ -655,7 +649,6 @@ class Computer extends CommonDBTM {
                      array('value' => $this->fields["operatingsystemservicepacks_id"]));
       echo "</td></tr>\n";
 
-
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['computers'][52]."&nbsp;:</td>";
       echo "<td >";
@@ -666,33 +659,75 @@ class Computer extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['computers'][11]."&nbsp;:</td>";
       echo "<td >";
-      autocompletionTextField($this, 'os_licenseid');
+      Html::autocompletionTextField($this, 'os_licenseid');
       echo "</td></tr>\n";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['computers'][10]."&nbsp;:</td>";
       echo "<td >";
-      autocompletionTextField($this, 'os_license_number');
-      echo "</td></tr>\n";
+      Html::autocompletionTextField($this, 'os_license_number');
+      echo "</td>";
+      if ($ocs_show) {
+         echo "<th colspan='2'>";
+         if (Session::haveRight("ocsng","w") && $ocs_config["ocs_url"] != '') {
+            echo OcsServer::getComputerLinkToOcsConsole (OcsServer::getByMachineID($ID),
+                                                               $dataocs["ocsid"],
+                                                               $LANG['ocsng'][58]);
+         } else {
+            echo $LANG['ocsng'][58];
+         }
+         echo "</th>";
+      }
+         
+
+      echo "</tr>\n";
 
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['computers'][58]."&nbsp;:</td>";
       echo "<td >";
-      autocompletionTextField($this, 'uuid');
-      echo "</td></tr>\n";
-
-      // Get OCS Datas :
-      $dataocs = array();
-      if (!empty($ID) && $this->fields["is_ocs_import"] && haveRight("view_ocsng","r")) {
-         $query = "SELECT *
-                   FROM `glpi_ocslinks`
-                   WHERE `computers_id` = '$ID'";
-
-         $result = $DB->query($query);
-         if ($DB->numrows($result)==1) {
-            $dataocs = $DB->fetch_array($result);
+      Html::autocompletionTextField($this, 'uuid');
+      echo "</td>";
+      if ($ocs_show) {
+         echo "<td colspan='2' rowspan='3'>";
+         echo "<table class='format'><tr><td>";
+         echo $LANG['ocsng'][14]."&nbsp;:</td><td>".Html::convDateTime($dataocs["last_ocs_update"]);
+         echo "</td></tr><tr><td>";
+         echo $LANG['ocsng'][13]."&nbsp;:</td><td> ".Html::convDateTime($dataocs["last_update"]);
+         echo "</td></tr>";
+         echo "<tr><td>".$LANG['common'][52]."&nbsp;:</td><td>";
+         if (Session::haveRight("ocsng","r")) {
+            echo "<a href='".$CFG_GLPI["root_doc"]."/front/ocsserver.form.php?id="
+                  .OcsServer::getByMachineID($ID)."'>".OcsServer::getServerNameByID($ID)."</a>";
+         } else {
+            echo OcsServer::getServerNameByID($ID);
          }
-      }
+         
+         echo "</td></tr>";
+         
+         if ($dataocs["ocs_agent_version"] != NULL) {
+            echo "<tr><td>".$LANG['ocsng'][49]."&nbsp;:</td><td>".$dataocs["ocs_agent_version"].'</td></tr>';
+         }
+         if (Session::haveRight("sync_ocsng","w")) {
+            echo "</tr><td>".$LANG['ocsng'][6]." ".$LANG['ocsconfig'][0]."&nbsp;:</td>";
+            echo "<td>";
+            Dropdown::showYesNo("_auto_update_ocs",$dataocs["use_auto_update"]);
+            echo "</td></tr>";
+         }     
+         
+         echo "</table>";
+         echo "</td>";
+      } 
+
+      echo "</tr>\n";
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['computers'][51]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('AutoUpdateSystem', array('value' => $this->fields["autoupdatesystems_id"]));
+      echo "</td>";
+      
+      echo "</tr>";
+
 
       echo "<tr class='tab_bg_1'>";
       echo "<td colspan='2' class='center'>".$datestring.$date;
@@ -700,63 +735,11 @@ class Computer extends CommonDBTM {
          echo "<span class='small_space'>(".$LANG['common'][13]."&nbsp;: ".
                $this->fields['template_name'].")</span>";
       }
-      if (!empty($ID)
-          && $this->fields["is_ocs_import"]
-          && haveRight("view_ocsng","r")
-          && count($dataocs)) {
-
-         echo "<br>";
-         echo $LANG['ocsng'][14]."&nbsp;: ".convDateTime($dataocs["last_ocs_update"]);
-         echo "<br>";
-         echo $LANG['ocsng'][13]."&nbsp;: ".convDateTime($dataocs["last_update"]);
-         echo "<br>";
-         if (haveRight("ocsng","r")) {
-            echo $LANG['common'][52]." <a href='".$CFG_GLPI["root_doc"]."/front/ocsserver.form.php?id="
-                 .OcsServer::getByMachineID($ID)."'>".OcsServer::getServerNameByID($ID)."</a>";
-            $query = "SELECT `ocs_agent_version`, `ocsid`
-                      FROM `glpi_ocslinks`
-                      WHERE `computers_id` = '$ID'";
-
-            $result_agent_version = $DB->query($query);
-            $data_version = $DB->fetch_array($result_agent_version);
-
-            $ocs_config = OcsServer::getConfig(OcsServer::getByMachineID($ID));
-
-            //If have write right on OCS and ocsreports url is not empty in OCS config
-            if (haveRight("ocsng","w") && $ocs_config["ocs_url"] != '') {
-               echo ", ".OcsServer::getComputerLinkToOcsConsole (OcsServer::getByMachineID($ID),
-                                                                 $data_version["ocsid"],
-                                                                 $LANG['ocsng'][57]);
-            }
-
-            if ($data_version["ocs_agent_version"] != NULL) {
-               echo " , ".$LANG['ocsng'][49]."&nbsp;: ".$data_version["ocs_agent_version"];
-            }
-
-         } else {
-            echo $LANG['common'][52]." ".OcsServer::getServerNameByID($ID);
-         }
-      }
+      
+    
+      
       echo "</td></tr>\n";
 
-      echo "<tr class='tab_bg_1'>";
-      if (!empty($ID)
-          && $this->fields["is_ocs_import"]
-          && haveRight("view_ocsng","r")
-          && haveRight("sync_ocsng","w")
-          && count($dataocs)) {
-
-         echo "<td >".$LANG['ocsng'][6]." ".$LANG['Menu'][33]."&nbsp;:</td>";
-         echo "<td >";
-         Dropdown::showYesNo("_auto_update_ocs",$dataocs["use_auto_update"]);
-         echo "</td>";
-      } else {
-         echo "<td colspan=2></td>";
-      }
-      echo "<td>".$LANG['computers'][51]."&nbsp;:</td>";
-      echo "<td >";
-      Dropdown::show('AutoUpdateSystem', array('value' => $this->fields["autoupdatesystems_id"]));
-      echo "</td></tr>";
 
       $this->showFormButtons($options);
       $this->addDivForTabs();
@@ -770,7 +753,7 @@ class Computer extends CommonDBTM {
     *
     * @return a SQL command which return a set of (itemtype, items_id)
     */
-   function getSelectLinkedItem () {
+   function getSelectLinkedItem() {
 
       return "SELECT `itemtype`, `items_id`
               FROM `glpi_computers_items`
@@ -779,7 +762,7 @@ class Computer extends CommonDBTM {
 
 
    function getSearchOptions() {
-      global $LANG;
+      global $LANG,$CFG_GLPI;
 
       $tab = array();
       $tab['common'] = $LANG['common'][32];
@@ -807,7 +790,7 @@ class Computer extends CommonDBTM {
       $tab[40]['name']  = $LANG['common'][22];
 
       $tab[31]['table'] = 'glpi_states';
-      $tab[31]['field'] = 'name';
+      $tab[31]['field'] = 'completename';
       $tab[31]['name']  = $LANG['state'][0];
 
       $tab[45]['table'] = 'glpi_operatingsystems';
@@ -873,9 +856,10 @@ class Computer extends CommonDBTM {
       $tab[70]['field'] = 'name';
       $tab[70]['name']  = $LANG['common'][34];
 
-      $tab[71]['table'] = 'glpi_groups';
-      $tab[71]['field'] = 'name';
-      $tab[71]['name']  = $LANG['common'][35];
+      $tab[71]['table']     = 'glpi_groups';
+      $tab[71]['field']     = 'completename';
+      $tab[71]['name']      = $LANG['common'][35];
+      $tab[71]['condition'] = '`is_itemgroup`';
 
       $tab[19]['table']         = $this->getTable();
       $tab[19]['field']         = 'date_mod';
@@ -900,12 +884,18 @@ class Computer extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[80]['table'] = 'glpi_entities';
       $tab[80]['field'] = 'completename';
       $tab[80]['name']  = $LANG['entity'][0];
 
 
-      $tab['periph'] = $LANG['title'][30];
+      $tab['periph'] = Toolbox::ucfirst($LANG['log'][18]);
 
       $tab[7]['table']         = 'glpi_deviceprocessors';
       $tab[7]['field']         = 'designation';
@@ -1079,71 +1069,72 @@ class Computer extends CommonDBTM {
                                          => array('table'      => 'glpi_computerdisks',
                                                   'joinparams' => array('jointype' => 'child')));
 
-      $tab['ocsng'] = $LANG['Menu'][33];
+      if ($CFG_GLPI["use_ocs_mode"]) {
+         $tab['ocsng'] = $LANG['ocsconfig'][0];
 
-      $tab[102]['table']         = 'glpi_ocslinks';
-      $tab[102]['field']         = 'last_update';
-      $tab[102]['name']          = $LANG['ocsng'][13];
-      $tab[102]['datatype']      = 'datetime';
-      $tab[102]['massiveaction'] = false;
-      $tab[102]['joinparams']    = array('jointype' => 'child');
+         $tab[102]['table']         = 'glpi_ocslinks';
+         $tab[102]['field']         = 'last_update';
+         $tab[102]['name']          = $LANG['ocsng'][13];
+         $tab[102]['datatype']      = 'datetime';
+         $tab[102]['massiveaction'] = false;
+         $tab[102]['joinparams']    = array('jointype' => 'child');
 
-      $tab[103]['table']         = 'glpi_ocslinks';
-      $tab[103]['field']         = 'last_ocs_update';
-      $tab[103]['name']          = $LANG['ocsng'][14];
-      $tab[103]['datatype']      = 'datetime';
-      $tab[103]['massiveaction'] = false;
-      $tab[103]['joinparams']    = array('jointype' => 'child');
+         $tab[103]['table']         = 'glpi_ocslinks';
+         $tab[103]['field']         = 'last_ocs_update';
+         $tab[103]['name']          = $LANG['ocsng'][14];
+         $tab[103]['datatype']      = 'datetime';
+         $tab[103]['massiveaction'] = false;
+         $tab[103]['joinparams']    = array('jointype' => 'child');
 
-      $tab[100]['table']         = $this->getTable();
-      $tab[100]['field']         = 'is_ocs_import';
-      $tab[100]['name']          = $LANG['ocsng'][7];
-      $tab[100]['massiveaction'] = false;
-      $tab[100]['datatype']      = 'bool';
+         $tab[100]['table']         = $this->getTable();
+         $tab[100]['field']         = 'is_ocs_import';
+         $tab[100]['name']          = $LANG['ocsng'][7];
+         $tab[100]['massiveaction'] = false;
+         $tab[100]['datatype']      = 'bool';
 
-      $tab[101]['table']      = 'glpi_ocslinks';
-      $tab[101]['field']      = 'use_auto_update';
-      $tab[101]['linkfield']  = '_auto_update_ocs'; // update through compter update process
-      $tab[101]['name']       = $LANG['ocsng'][6]." ".$LANG['Menu'][33];
-      $tab[101]['datatype']   = 'bool';
-      $tab[101]['joinparams'] = array('jointype' => 'child');
+         $tab[101]['table']      = 'glpi_ocslinks';
+         $tab[101]['field']      = 'use_auto_update';
+         $tab[101]['linkfield']  = '_auto_update_ocs'; // update through compter update process
+         $tab[101]['name']       = $LANG['ocsng'][6]." ".$LANG['ocsconfig'][0];
+         $tab[101]['datatype']   = 'bool';
+         $tab[101]['joinparams'] = array('jointype' => 'child');
 
-      $tab[104]['table']         = 'glpi_ocslinks';
-      $tab[104]['field']         = 'ocs_agent_version';
-      $tab[104]['name']          = $LANG['ocsng'][49];
-      $tab[104]['massiveaction'] = false;
-      $tab[104]['joinparams']    = array('jointype' => 'child');
+         $tab[104]['table']         = 'glpi_ocslinks';
+         $tab[104]['field']         = 'ocs_agent_version';
+         $tab[104]['name']          = $LANG['ocsng'][49];
+         $tab[104]['massiveaction'] = false;
+         $tab[104]['joinparams']    = array('jointype' => 'child');
 
-      $tab[105]['table']         = 'glpi_ocslinks';
-      $tab[105]['field']         = 'tag';
-      $tab[105]['name']          = $LANG['ocsconfig'][39];
-      $tab[105]['datatype']      = 'string';
-      $tab[105]['massiveaction'] = false;
-      $tab[105]['joinparams']    = array('jointype' => 'child');
+         $tab[105]['table']         = 'glpi_ocslinks';
+         $tab[105]['field']         = 'tag';
+         $tab[105]['name']          = $LANG['ocsconfig'][39];
+         $tab[105]['datatype']      = 'string';
+         $tab[105]['massiveaction'] = false;
+         $tab[105]['joinparams']    = array('jointype' => 'child');
 
-      $tab[106]['table']         = 'glpi_ocslinks';
-      $tab[106]['field']         = 'ocsid';
-      $tab[106]['name']          = $LANG['ocsng'][45];
-      $tab[106]['datatype']      = 'number';
-      $tab[106]['massiveaction'] = false;
-      $tab[106]['joinparams']    = array('jointype' => 'child');
+         $tab[106]['table']         = 'glpi_ocslinks';
+         $tab[106]['field']         = 'ocsid';
+         $tab[106]['name']          = $LANG['ocsng'][45];
+         $tab[106]['datatype']      = 'number';
+         $tab[106]['massiveaction'] = false;
+         $tab[106]['joinparams']    = array('jointype' => 'child');
 
-      $tab['registry'] = $LANG['title'][43];
+         $tab['registry'] = $LANG['title'][43];
 
-      $tab[110]['table']         = 'glpi_registrykeys';
-      $tab[110]['field']         = 'value';
-      $tab[110]['name']          = $LANG['title'][43]." : ".$LANG['registry'][3];
-      $tab[110]['forcegroupby']  = true;
-      $tab[110]['massiveaction'] = false;
-      $tab[110]['joinparams']    = array('jointype' => 'child');
-
-      $tab[111]['table']         = 'glpi_registrykeys';
-      $tab[111]['field']         = 'ocs_name';
-      $tab[111]['name']          = $LANG['title'][43]." : ".$LANG['registry'][6];
-      $tab[111]['forcegroupby']  = true;
-      $tab[111]['massiveaction'] = false;
-      $tab[111]['joinparams']    = array('jointype' => 'child');
+         $tab[110]['table']         = 'glpi_registrykeys';
+         $tab[110]['field']         = 'value';
+         $tab[110]['name']          = $LANG['title'][43]." : ".$LANG['registry'][3];
+         $tab[110]['forcegroupby']  = true;
+         $tab[110]['massiveaction'] = false;
+         $tab[110]['joinparams']    = array('jointype' => 'child');
 
+         $tab[111]['table']         = 'glpi_registrykeys';
+         $tab[111]['field']         = 'ocs_name';
+         $tab[111]['name']          = $LANG['title'][43]." : ".$LANG['registry'][6];
+         $tab[111]['forcegroupby']  = true;
+         $tab[111]['massiveaction'] = false;
+         $tab[111]['joinparams']    = array('jointype' => 'child');
+      }
       $tab['virtualmachine'] = $LANG['computers'][57];
 
       $tab[160]['table']         = 'glpi_computervirtualmachines';
@@ -1207,4 +1198,4 @@ class Computer extends CommonDBTM {
    }
 }
 
-?>
+?>
\ No newline at end of file
