@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_device.class.php 17447 2012-02-08 09:49:41Z tsmr $
+ * @version $Id: computer_device.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -296,7 +296,8 @@ class Computer_Device extends CommonDBTM {
          echo $LANG['devices'][0]."&nbsp;: ";
          Dropdown::showAllItems('items_id', '', 0, -1, $devtypes);
          echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
-         echo "</tr></table></form>";
+         echo "</tr></table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
@@ -496,6 +497,7 @@ class Computer_Device extends CommonDBTM {
             $data['computers_id'] = $newid;
             $data['_itemtype']    = $itemtype;
             $data['_no_history']  = true;
+            $data = Toolbox::addslashes_deep($data);
 
             $this->add($data);
          }
