@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_item.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: computer_item.class.php 18805 2012-07-03 08:55:22Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -365,9 +365,14 @@ class Computer_Item extends CommonDBRelation{
          if ($item->canView()) {
             $query = "SELECT *
                       FROM `glpi_computers_items`
+                      LEFT JOIN `".getTableForItemType($itemtype)."`
+                        ON (`".getTableForItemType($itemtype)."`.`id` = `glpi_computers_items`.`items_id`)
                       WHERE `computers_id` = '$ID'
                             AND `itemtype` = '".$itemtype."'";
-
+            if ($item->maybetemplate()) {
+               $query.= " AND NOT `".getTableForItemType($itemtype)."`.`is_template` ";
+            }
+            
             $result = $DB->query($query);
             if ($result) {
                $nb = $DB->numrows($result);
@@ -473,7 +478,7 @@ class Computer_Item extends CommonDBRelation{
                                         $comp->fields["entities_id"], $withtemplate, $used);
                   echo "<input type='submit' name='connect' value=\"".$LANG['buttons'][9]."\"
                          class='submit'>";
-                  echo "</form>";
+                  Html::closeForm();
                }
             }
             echo "</td>";
@@ -566,7 +571,7 @@ class Computer_Item extends CommonDBRelation{
             }
             echo "<input type='submit' name='connect' value=\"".$LANG['buttons'][9]."\"
                    class='submit'>";
-            echo "</form>";
+            Html::closeForm();
          } else {
             echo "&nbsp;";
          }
@@ -589,7 +594,7 @@ class Computer_Item extends CommonDBRelation{
             }
             echo "<input type='submit' name='connect' value=\"".$LANG['buttons'][9]."\"
                    class='submit'>";
-            echo "</form>";
+            Html::closeForm();
          } else {
             echo "&nbsp;";
          }
