@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: computer_softwarelicense.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: computer_softwarelicense.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -231,7 +231,8 @@ class Computer_SoftwareLicense extends CommonDBRelation {
          echo "<td><input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
          echo "</td></tr>";
 
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
       }
 
       if ($number < 1) {
@@ -375,7 +376,7 @@ class Computer_SoftwareLicense extends CommonDBRelation {
                      $LANG['buttons'][20]."\" class='submit'>&nbsp;";
                Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
 
-               echo "</form>";
+               Html::closeForm();
             }
 
          } else { // Not found
