@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: config.class.php 17985 2012-03-23 08:50:03Z remi $
+ * @version $Id: config.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -98,6 +98,10 @@ class Config extends CommonDBTM {
    **/
    function prepareInputForUpdate($input) {
 
+      if (isset($input['allow_search_view']) && !$input['allow_search_view']) {
+         // Global search need "view"
+         $input['allow_search_global'] = 0;
+      }
       if (isset($input["smtp_passwd"])) {
          if (empty($input["smtp_passwd"])) {
             unset($input["smtp_passwd"]);
@@ -268,13 +272,38 @@ class Config extends CommonDBTM {
          echo "</tr>";
       }
 
+      echo "<tr class='tab_bg_1'><td colspan='4' class='center b'>".$LANG['setup'][22]."</td></tr>";
+      echo "<tr class='tab_bg_2'>";
+      echo "<td>" . $LANG['search'][11] . "</td><td>"; // Items seens
+      $values = array(0 => $LANG['choice'][0],
+                      1 => $LANG['choice'][1].' ('.$LANG['setup'][23].')',
+                      2 => $LANG['choice'][1].' ('.$LANG['setup'][24].')');
+      Dropdown::showFromArray('allow_search_view', $values,
+                              array('value' => $CFG_GLPI['allow_search_view']));
+
+      echo "</td><td>". $LANG['setup'][25]."</td><td>"; // Global search
+      if ($CFG_GLPI['allow_search_view']) {
+         Dropdown::showYesNo('allow_search_global', $CFG_GLPI['allow_search_global']);
+      } else {
+         echo Dropdown::getYesNo(0);
+      }
+      echo "</td></tr>";
+
+      echo "<tr class='tab_bg_2'>";
+      echo "<td>" . $LANG['common'][66] . "</td><td>"; // All
+      $values = array(0 => $LANG['choice'][0],
+                      1 => $LANG['choice'][1].' ('.$LANG['setup'][23].')');
+      Dropdown::showFromArray('allow_search_all', $values,
+                              array('value' => $CFG_GLPI['allow_search_all']));
+      echo "</td><td colspan='2'></td></tr>";
+
       echo "<tr class='tab_bg_2'>";
       echo "<td colspan='4' class='center'>";
       echo "<input type='submit' name='update' class='submit' value=\"".$LANG['buttons'][2]."\">";
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -408,7 +437,7 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -450,7 +479,7 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -519,7 +548,7 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -658,7 +687,7 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -777,6 +806,14 @@ class Config extends CommonDBTM {
       }
       echo "</td></tr>";
 
+      if ($oncentral) {
+         echo "<tr class='tab_bg_2'>";
+         echo "<td colspan='2'></td>";
+         echo "<td>" . $LANG['setup'][133] . "&nbsp;:</td><td>";
+         Dropdown::showInteger('display_count_on_home', $data['display_count_on_home'], 0, 30);
+         echo "</td></tr>";
+      }
+
       if ($oncentral) {
          echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG['title'][24]."</th></tr>";
 
@@ -859,7 +896,7 @@ class Config extends CommonDBTM {
       echo "</td></tr>";
 
       echo "</table></div>";
-      echo "</form>";
+      Html::closeForm();
    }
 
 
@@ -925,7 +962,7 @@ class Config extends CommonDBTM {
       echo "</tr>";
 
       echo "</table>";
-      echo "</form>";
+      Html::closeForm();
 
       $width = 128;
 
