@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: consumableitem.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: consumableitem.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -46,20 +46,23 @@ class ConsumableItem extends CommonDBTM {
    // From CommonDBTM
    protected $forward_entity_to = array('Consumable', 'Infocom');
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['consumables'][12];
+      if ($nb>1) {
+         return $LANG['consumables'][4];
+      }
+      return $LANG['consumables'][3];
    }
 
 
    function canCreate() {
-      return haveRight('consumable', 'w');
+      return Session::haveRight('consumable', 'w');
    }
 
 
    function canView() {
-      return haveRight('consumable', 'r');
+      return Session::haveRight('consumable', 'r');
    }
 
 
@@ -102,10 +105,11 @@ class ConsumableItem extends CommonDBTM {
    }
 
 
-   function post_getEmpty () {
-      global $CFG_GLPI;
+   function post_getEmpty() {
 
-      $this->fields["alarm_threshold"] = $CFG_GLPI["default_alarm_threshold"];
+     $this->fields["alarm_threshold"] = EntityData::getUsedConfig("consumables_alert_repeat",
+                                                                   $this->fields["entities_id"],
+                                                                   "default_alarm_threshold", 10);
    }
 
 
@@ -113,28 +117,11 @@ class ConsumableItem extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      if ($this->fields['id'] > 0) {
-         $ong[1] = $LANG['Menu'][32];
-
-         if (haveRight("infocom","r")) {
-            $ong[4] = $LANG['Menu'][26];
-         }
-
-         if (haveRight("document","r")) {
-            $ong[5] = $LANG['Menu'][27];
-         }
-
-         if (haveRight("link","r")) {
-            $ong[7] = $LANG['title'][34];
-         }
-
-         if (haveRight("notes","r")) {
-            $ong[10] = $LANG['title'][37];
-         }
-
-      } else { // New item
-         $ong[1] = $LANG['title'][26];
-      }
+      $this->addStandardTab('Consumable', $ong, $options);
+      $this->addStandardTab('Infocom', $ong, $options);
+      $this->addStandardTab('Document',$ong, $options);
+      $this->addStandardTab('Link', $ong, $options);
+      $this->addStandardTab('Note', $ong, $options);
 
       return $ong;
    }
@@ -151,11 +138,11 @@ class ConsumableItem extends CommonDBTM {
     * @return Nothing (display)
     *
     **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $CFG_GLPI, $LANG;
 
       // Show ConsumableItem or blank form
-      if (!haveRight("consumable","r")) {
+      if (!Session::haveRight("consumable","r")) {
          return false;
       }
 
@@ -172,20 +159,8 @@ class ConsumableItem extends CommonDBTM {
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
-      echo "<td rowspan='7' class='middle right'>".$LANG['common'][25]."&nbsp;: </td>";
-      echo "<td class='center middle' rowspan='7'>";
-      echo "<textarea cols='45' rows='9' name='comment' >".$this->fields["comment"]."</textarea>";
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_1'>";
-      echo "<td>".$LANG['consumables'][2]."&nbsp;:</td>\n";
-      echo "<td>";
-      autocompletionTextField($this, "ref");
-      echo "</td></tr>";
-
-      echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['common'][17]."&nbsp;: </td>";
       echo "<td>";
       Dropdown::show('ConsumableItemType',
@@ -193,6 +168,10 @@ class ConsumableItem extends CommonDBTM {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['consumables'][2]."&nbsp;:</td>\n";
+      echo "<td>";
+      Html::autocompletionTextField($this, "ref");
+      echo "</td>";
       echo "<td>".$LANG['common'][5]."&nbsp;:</td>";
       echo "<td>";
       Dropdown::show('Manufacturer', array('value' => $this->fields["manufacturers_id"]));
@@ -205,8 +184,21 @@ class ConsumableItem extends CommonDBTM {
                            'value'  => $this->fields["users_id_tech"],
                            'right'  => 'interface',
                            'entity' => $this->fields["entities_id"]));
+      echo "</td>";
+      echo "<td rowspan='4' class='middle'>".$LANG['common'][25]."&nbsp;: </td>";
+      echo "<td class='middle' rowspan='4'>
+             <textarea cols='45' rows='9' name='comment' >".$this->fields["comment"]."</textarea>";
       echo "</td></tr>";
 
+      echo "<tr class='tab_bg_1'>";
+      echo "<td>".$LANG['common'][109]."&nbsp;:</td>";
+      echo "<td>";
+      Dropdown::show('Group', array('name'      => 'groups_id_tech',
+                                    'value'     => $this->fields['groups_id_tech'],
+                                    'entity'    => $this->fields['entities_id'],
+                                    'condition' => '`is_assign`'));
+      echo "</td></tr>\n";
+
       echo "<tr class='tab_bg_1'>";
       echo "<td>".$LANG['consumables'][36]."&nbsp;:</td>";
       echo "<td>";
@@ -268,6 +260,12 @@ class ConsumableItem extends CommonDBTM {
       $tab[24]['linkfield'] = 'users_id_tech';
       $tab[24]['name']      = $LANG['common'][10];
 
+      $tab[49]['table']     = 'glpi_groups';
+      $tab[49]['field']     = 'completename';
+      $tab[49]['linkfield'] = 'groups_id_tech';
+      $tab[49]['name']      = $LANG['common'][109];
+      $tab[49]['condition'] = '`is_assign`';
+
       $tab[8]['table']     = $this->getTable();
       $tab[8]['field']     = 'alarm_threshold';
       $tab[8]['name']      = $LANG['consumables'][38];
@@ -363,8 +361,9 @@ class ConsumableItem extends CommonDBTM {
                                                           $entity)." :  $message\n");
                      $task->addVolume(1);
                   } else {
-                     addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
-                                                                       $entity)." :  $message");
+                     Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                                $entity).
+                                                      " :  $message");
                   }
 
                   $input["type"]     = Alert::THRESHOLD;
@@ -382,8 +381,10 @@ class ConsumableItem extends CommonDBTM {
                      $task->log(Dropdown::getDropdownName("glpi_entities", $entity).
                                 " : Send consumable alert failed\n");
                   } else {
-                     addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities", $entity).
-                                             " : Send consumable alert failed",false,ERROR);
+                     Session::addMessageAfterRedirect(Dropdown::getDropdownName("glpi_entities",
+                                                                                $entity)
+                                                        ." : Send consumable alert failed",
+                                                      false, ERROR);
                   }
                }
             }
@@ -417,6 +418,7 @@ class ConsumableItem extends CommonDBTM {
       $options['consumables']  = array($item);
       NotificationEvent::debugEvent(new Consumable(), $options);
    }
+
 }
 
 ?>
