@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contact.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: contact.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -429,7 +429,8 @@ class Contact extends CommonDBTM{
             echo "</tr>";
          }
       }
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 
