@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: contract.class.php 17231 2012-01-27 10:06:40Z tsmr $
+ * @version $Id: contract.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -96,7 +96,18 @@ class Contract extends CommonDBTM {
       return $ong;
    }
 
+   function prepareInputForAdd($input) {
 
+      if (isset($input["id"]) && $input["id"]>0) {
+         $input["_oldID"] = $input["id"];
+      }
+      unset($input['id']);
+      unset($input['withtemplate']);
+
+      return $input;
+   }
+
+   
    function pre_updateInDB() {
 
       // Clean end alert if begin_date is after old one
@@ -520,6 +531,17 @@ class Contract extends CommonDBTM {
       $tab[72]['massiveaction'] = false;
       $tab[72]['joinparams']    = array('jointype' => 'child');
 
+      $tab[29]['table']         = 'glpi_suppliers';
+      $tab[29]['field']         = 'name';
+      $tab[29]['name']          = $LANG['financial'][65];
+      $tab[29]['forcegroupby']  = true;
+      $tab[29]['datatype']      = 'itemlink';
+      $tab[29]['itemlink_type'] = 'Supplier';
+      $tab[29]['massiveaction'] = false;
+      $tab[29]['joinparams']    = array('beforejoin'
+                                       => array('table'      => 'glpi_contracts_suppliers',
+                                                'joinparams' => array('jointype' => 'child')));
+
       return $tab;
    }
 
@@ -762,7 +784,8 @@ class Contract extends CommonDBTM {
             echo "</tr>";
          }
          }
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 
@@ -816,7 +839,7 @@ class Contract extends CommonDBTM {
       echo "<th>".$LANG['common'][16]."</th>";
       echo "<th>".$LANG['common'][19]."</th>";
       echo "<th>".$LANG['common'][20]."</th>";
-      echo "<th>".$LANG['state'][0]."</th>";      
+      echo "<th>".$LANG['state'][0]."</th>";
       echo "</tr>";
 
       $totalnb = 0;
@@ -899,7 +922,7 @@ class Contract extends CommonDBTM {
                      echo Dropdown::getDropdownName("glpi_states",$data['states_id']);
                   } else {
                      echo '&nbsp;';
-                  }                         
+                  }
                   echo "</td></tr>";
                }
             }
@@ -918,7 +941,7 @@ class Contract extends CommonDBTM {
             echo "<tr class='tab_bg_1'><td colspan='5' class='right'>";
             Dropdown::showAllItems("items_id", 0, 0,
                                    ($this->fields['is_recursive']?-1:$this->fields['entities_id']),
-                                   $CFG_GLPI["contract_types"]);
+                                   $CFG_GLPI["contract_types"], false, true);
             echo "</td><td class='center'>";
             echo "<input type='submit' name='additem' value=\"".$LANG['buttons'][8]."\"
                    class='submit'>";
@@ -933,7 +956,8 @@ class Contract extends CommonDBTM {
       } else {
          echo "</table>";
       }
-      echo "</div></form>";
+      echo "</div>";
+      Html::closeForm();
    }
 
 
@@ -1095,7 +1119,7 @@ class Contract extends CommonDBTM {
       echo "</table>";
 
       if ($withtemplate!=2) {
-         echo "</form>";
+         Html::closeForm();
       }
       echo "</div>";
    }
