@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: db.function.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: db.function.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -52,6 +52,17 @@ function getForeignKeyFieldForTable($table) {
   return str_replace("glpi_","",$table)."_id";
 }
 
+/**
+ * Return foreign key field name for an itemtype
+ *
+ * @param $itemtype string: itemtype
+ *
+ * @return string field name used for a foreign key to the parameter itemtype
+**/
+function getForeignKeyFieldForItemType($itemtype) {
+   return getForeignKeyFieldForTable(getTableForItemType($itemtype));
+}
+
 
 /**
  * Return table name for a given foreign key name
@@ -88,26 +99,24 @@ function getItemTypeForTable($table) {
 
       if (preg_match('/^plugin_([a-z0-9]+)_/',$table,$matches)) {
          $table  = preg_replace('/^plugin_[a-z0-9]+_/','',$table);
-         $prefix = "Plugin".ucfirst($matches[1]);
+         $prefix = "Plugin".Toolbox::ucfirst($matches[1]);
       }
 
       if (strstr($table,'_')) {
          $split = explode('_', $table);
 
          foreach ($split as $key => $part) {
-            $split[$key] = ucfirst(getSingular($part));
+            $split[$key] = Toolbox::ucfirst(getSingular($part));
          }
          $table = implode('_',$split);
 
       } else {
-         $table = ucfirst(getSingular($table));
+         $table = Toolbox::ucfirst(getSingular($table));
       }
 
       $itemtype=$prefix.$table;
-
       // Get real existence of itemtype
-      if (class_exists($itemtype)) {
-         $item     = new $itemtype();
+      if ($item = getItemForItemtype($itemtype)) {
          $itemtype = get_class($item);
          $CFG_GLPI['glpiitemtypetables'][$inittable] = $itemtype;
          $CFG_GLPI['glpitablesitemtype'][$itemtype]  = $inittable;
@@ -163,6 +172,24 @@ function getTableForItemType($itemtype) {
 }
 
 
+/**
+ * Get new item objet for an itemtype
+ *
+ * @since version 0.83
+ *
+ * @param $itemtype string: itemtype
+ *
+ * @return itemtype object or false if class does not exists
+**/
+function getItemForItemtype($itemtype) {
+
+   if (class_exists($itemtype)) {
+      return new $itemtype();
+   }
+   return false;
+}
+
+
 /**
  * Return the plural of a string
  *
@@ -173,21 +200,26 @@ function getTableForItemType($itemtype) {
 function getPlural($string) {
 
    $rules = array(//'singular' => 'plural'
+                  /// TODO : real singular is criterion and plural criteria. Need to update class / tables names
+                  'criterias$'   =>'criterias',// Special case (criterias) when getPLural is called on already plural form
                   's$'           =>'ses',
                   '([^aeiou])y$' => '\1ies', // special case : category (but not key)
                   'ch$'          =>'ches',
                   'sh$'          =>'shes',
                   'x$'           =>'xes',
+                  'ed$'         => 'ed',  // case table without plural (ex. imported)
                   '([^s])$'      => '\1s',   // Add at the end if not exists
-                  'eds$'         => 'ed');   // case table without plural (ex. imported)
+                  );
 
    foreach ($rules as $singular => $plural) {
-      $string = preg_replace("/$singular/", "$plural", $string);
+      $string = preg_replace("/$singular/", "$plural", $string, -1, $count);
+      if ($count > 0) {
+         break;
+      }
    }
    return $string;
 }
 
-
 /**
  * Return the singular of a string
  *
@@ -198,16 +230,25 @@ function getPlural($string) {
 function getSingular($string) {
 
    $rules = array(//'plural' => 'singular'
-                  'ies$' => 'y', // special case : category
-                  's$'   => ''); // Add at the end if not exists
+                  'ches$'          => 'ch',
+                  'shes$'          => 'sh',
+                  'sses$'          => 'ss', // Case like addresses
+//                   'cases$'          => 'case', // Case like cases
+                  '([aeiou]{2})ses$' => '\1s', // Case like aliases
+                  'ss$'            => 'ss', // Special case (addresses) when getSingular is called on already singular form
+                  'alias$'           => 'alias', // Special case (aliases) when getSingular is called on already singular form
+                  'ies$'           => 'y', // special case : category
+                  's$'             => ''); // Add at the end if not exists
 
    foreach ($rules as  $plural => $singular) {
-      $string = preg_replace("/$plural/", "$singular", $string);
+      $string = preg_replace("/$plural/", "$singular", $string, -1, $count);
+      if ($count > 0) {
+         break;
+      }
    }
    return $string;
 }
 
-
 /**
  * Is a table used for devices
  *
@@ -408,7 +449,9 @@ function getTreeValueCompleteName($table, $ID, $withcomment=false) {
       if ($result=$DB->query($query)) {
          if ($DB->numrows($result)==1) {
             $name    = $DB->result($result,0,"completename");
-            $comment = $name." :<br>".$DB->result($result ,0, "comment");
+            $comment = "<span class='b'>".$LANG['common'][51]."&nbsp;: </span>".$name.
+                       "<br><span class='b'>".$LANG['common'][25]."&nbsp;: </span>".
+                       nl2br($DB->result($result, 0, "comment"));
          }
       }
    }
@@ -796,47 +839,14 @@ function regenerateTreeCompleteName($table) {
          list($name, $level) = getTreeValueName($table, $data['id']);
 
          $query = "UPDATE `$table`
-                   SET `completename` = '".addslashes($name)."'
+                   SET `completename` = '".addslashes($name)."',
+                       `level` = '$level'
                    WHERE `id` = '".$data['id']."'";
          $DB->query($query);
       }
    }
 }
 
-
-/**
- * Compute completename of Dropdown Tree table under the element of ID $ID
- *
- * @param $table : dropdown tree table to compute
- * @param $ID : root ID to used : regenerate all under this element
- *
- * @return nothing
-**/
-function regenerateTreeCompleteNameUnderID($table, $ID) {
-   global $DB;
-
-   $parentIDfield      = getForeignKeyFieldForTable($table);
-   list($name, $level) = getTreeValueName($table, $ID);
-
-   $query = "UPDATE `$table`
-             SET `completename` = '".addslashes($name)."',
-                 `level` = '$level'
-             WHERE `id` = '$ID'";
-   $DB->query($query);
-
-   $query = "SELECT `id`
-             FROM `$table`
-             WHERE `$parentIDfield` = '$ID'";
-   $result = $DB->query($query);
-
-   if ($DB->numrows($result)>0) {
-      while ($data=$DB->fetch_array($result)) {
-         regenerateTreeCompleteNameUnderID($table, $data["id"]);
-      }
-   }
-}
-
-
 /**
  * Get the ID of the next Item
  *
@@ -1054,8 +1064,8 @@ function formatUserName($ID, $login, $realname, $firstname, $link=0, $cut=0, $fo
          }
       }
 
-      if ($cut>0 && utf8_strlen($temp)>$cut) {
-         $temp = utf8_substr($temp, 0, $cut)." ...";
+      if ($cut>0 && Toolbox::strlen($temp)>$cut) {
+         $temp = Toolbox::substr($temp, 0, $cut)." ...";
       }
 
    } else {
@@ -1118,8 +1128,9 @@ function getUserName($ID, $link=0) {
             $user["comment"] = $LANG['common'][16]."&nbsp;: ".$username."<br>".$LANG['setup'][18].
                                "&nbsp;: ".$data["name"]."<br>";
 
-            if (!empty($data["email"])) {
-               $user["comment"] .= $LANG['setup'][14]."&nbsp;: ".$data["email"]."<br>";
+            $email = UserEmail::getDefaultForUser($ID);
+            if (!empty($email)) {
+               $user["comment"] .= $LANG['setup'][14]."&nbsp;: $email<br>";
             }
 
             if (!empty($data["phone"])) {
@@ -1186,15 +1197,17 @@ function TableExists($tablename) {
 /**
  * Verify if a DB field exists
  *
- *@param $table string : Name of the table we want to verify.
- *@param $field string : Name of the field we want to verify.
+ * @param $table     String : Name of the table we want to verify.
+ * @param $field     String : Name of the field we want to verify.
+ * @param $usecache  Boolean : if use field list cache (default true)
+ * @
  *
  *@return bool : true if exists, false elseway.
 **/
-function FieldExists($table, $field) {
+function FieldExists($table, $field, $usecache=true) {
    global $DB;
 
-   if ($fields = $DB->list_fields($table)) {
+   if ($fields = $DB->list_fields($table, $usecache)) {
       if (isset($fields[$field])) {
          return true;
       }
@@ -1242,14 +1255,14 @@ function isIndex($table, $field) {
 function autoName($objectName, $field, $isTemplate, $itemtype, $entities_id=-1) {
    global $DB, $CFG_GLPI;
 
-   $len = utf8_strlen($objectName);
+   $len = Toolbox::strlen($objectName);
 
    if ($isTemplate
        && $len > 8
-       && utf8_substr($objectName,0,4) === '&lt;'
-       && utf8_substr($objectName,$len - 4,4) === '&gt;') {
+       && Toolbox::substr($objectName,0,4) === '&lt;'
+       && Toolbox::substr($objectName,$len - 4,4) === '&gt;') {
 
-      $autoNum = utf8_substr($objectName, 4, $len - 8);
+      $autoNum = Toolbox::substr($objectName, 4, $len - 8);
       $mask    = '';
 
       if (preg_match( "/\\#{1,10}/", $autoNum, $mask)) {
@@ -1270,7 +1283,7 @@ function autoName($objectName, $field, $isTemplate, $itemtype, $entities_id=-1)
                                 $autoNum);
          $mask = $mask[0];
          $pos  = strpos($autoNum, $mask) + 1;
-         $len  = utf8_strlen($mask);
+         $len  = Toolbox::strlen($mask);
          $like = str_replace('#', '_', $autoNum);
 
          if ($global == 1) {
@@ -1326,7 +1339,7 @@ function autoName($objectName, $field, $isTemplate, $itemtype, $entities_id=-1)
          $objectName = str_replace(array($mask,
                                          '\\_',
                                          '\\%'),
-                                   array(utf8_str_pad($newNo, $len, '0', STR_PAD_LEFT),
+                                   array(Toolbox::str_pad($newNo, $len, '0', STR_PAD_LEFT),
                                          '_',
                                          '%'),
                                    $autoNum);
@@ -1369,34 +1382,6 @@ function formatOutputWebLink($link) {
    return $link;
 }
 
-
-/**
-* Clean fields if needed
-*
-* @param $table table name name
-* @param $fields fields to set NULL : may be a string or an array (sons_cache, ancestors_cache, ...)
-**/
-function CleanFields($table,$fields) {
-   global $DB;
-
-   if (!is_array($fields)) {
-      $fields = array($fields);
-   }
-
-   $query = '';
-   foreach ($fields as $field) {
-      if (FieldExists($table,$field)) {
-         $query .= (empty($query)?"UPDATE `$table` SET" : ",")." `$field` = NULL ";
-
-      }
-   }
-
-   if (!empty($query)) {
-      $DB->query($query);
-   }
-}
-
-
 /**
  * Add dates for request
  *
@@ -1461,4 +1446,124 @@ function importArrayFromDB($DATA) {
    return $TAB;
 }
 
-?>
+
+/**
+ * Get hour from sql
+ *
+ * @param $time datetime: time
+ *
+ * @return  array
+**/
+function get_hour_from_sql($time) {
+
+   $t = explode(" ", $time);
+   $p = explode(":", $t[1]);
+
+   return $p[0].":".$p[1];
+}
+
+
+/**
+ * Get the $RELATION array. It's defined all relations between tables in the DB.
+ *
+ * @return the $RELATION array
+**/
+function getDbRelations() {
+   global $CFG_GLPI;
+
+   include (GLPI_ROOT . "/inc/relation.constant.php");
+
+   // Add plugins relations
+   $plug_rel = Plugin::getDatabaseRelations();
+   if (count($plug_rel)>0) {
+      $RELATION = array_merge_recursive($RELATION,$plug_rel);
+   }
+   return $RELATION;
+}
+
+
+/**
+ * Get SQL request to restrict to current entities of the user
+ *
+ * @param $separator : separator in the begin of the request
+ * @param $table : table where apply the limit (if needed, multiple tables queries)
+ * @param $field : field where apply the limit (id != entities_id)
+ * @param $value : entity to restrict (if not set use $_SESSION['glpiactiveentities']). single item or array
+ * @param $is_recursive : need to use recursive process to find item (field need to be named recursive)
+ * @param $complete_request : need to use a complete request and not a simple one when have acces to all entities (used for reminders)
+ *
+ * @return String : the WHERE clause to restrict
+**/
+function getEntitiesRestrictRequest($separator = "AND", $table = "", $field = "",$value='',
+                                    $is_recursive=false, $complete_request=false) {
+
+   $query = $separator ." ( ";
+
+   // !='0' needed because consider as empty
+   if (!$complete_request
+       && $value!='0'
+       && empty($value)
+       && isset($_SESSION['glpishowallentities'])
+       && $_SESSION['glpishowallentities']) {
+
+      // Not ADD "AND 1" if not needed
+      if (trim($separator)=="AND") {
+         return "";
+      }
+      return $query." 1 ) ";
+   }
+
+   if (!empty($table)) {
+      $query .= "`$table`.";
+   }
+   if (empty($field)) {
+      if ($table=='glpi_entities') {
+         $field = "id";
+      } else {
+         $field = "entities_id";
+      }
+   }
+
+   $query .= "`$field`";
+
+   if (is_array($value)) {
+      $query .= " IN ('" . implode("','",$value) . "') ";
+   } else {
+      if (strlen($value)==0) {
+         $query .= " IN (".$_SESSION['glpiactiveentities_string'].") ";
+      } else {
+         $query .= " = '$value' ";
+      }
+   }
+
+   if ($is_recursive) {
+      $ancestors = array();
+      if (is_array($value)) {
+         foreach ($value as $val) {
+            $ancestors = array_unique(array_merge(getAncestorsOf("glpi_entities", $val),
+                                                  $ancestors));
+         }
+         $ancestors = array_diff($ancestors, $value);
+
+      } else if (strlen($value)==0) {
+         $ancestors = $_SESSION['glpiparententities'];
+
+      } else {
+         $ancestors = getAncestorsOf("glpi_entities", $value);
+      }
+
+      if (count($ancestors)) {
+         if ($table=='glpi_entities') {
+            $query .= " OR `$table`.`$field` IN ('" . implode("','",$ancestors) . "')";
+         } else {
+            $query .= " OR (`$table`.`is_recursive`='1'
+                            AND `$table`.`$field` IN ('" . implode("','",$ancestors) . "'))";
+         }
+      }
+   }
+   $query .= " ) ";
+
+   return $query;
+}
+
+?>
\ No newline at end of file
