@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dbmysql.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: dbmysql.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -166,7 +166,8 @@ class DBmysql {
    function query($query) {
       global $CFG_GLPI, $DEBUG_SQL, $SQL_TOTAL_REQUEST;
 
-      if ($_SESSION['glpi_use_mode']==DEBUG_MODE && $CFG_GLPI["debug_sql"]) {
+      if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE
+          && $CFG_GLPI["debug_sql"]) {
          $SQL_TOTAL_REQUEST++;
          $DEBUG_SQL["queries"][$SQL_TOTAL_REQUEST] = $query;
          $TIMER = new Timer();
@@ -196,15 +197,17 @@ class DBmysql {
             }
 
             $error .= $_SERVER["SCRIPT_FILENAME"]. "\n";
-            logInFile("sql-errors", $error."\n");
+            Toolbox::logInFile("sql-errors", $error."\n");
 
-            if ($_SESSION['glpi_use_mode']==DEBUG_MODE && $CFG_GLPI["debug_sql"]) {
+            if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE
+                && $CFG_GLPI["debug_sql"]) {
                $DEBUG_SQL["errors"][$SQL_TOTAL_REQUEST] = $this->error();
             }
          }
       }
 
-      if ($_SESSION['glpi_use_mode']==DEBUG_MODE && $CFG_GLPI["debug_sql"]) {
+      if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE
+          && $CFG_GLPI["debug_sql"]) {
          $TIME                                   = $TIMER->getTime();
          $DEBUG_SQL["times"][$SQL_TOTAL_REQUEST] = $TIME;
       }
@@ -223,8 +226,9 @@ class DBmysql {
    **/
    function result($result, $i, $field) {
 
-      $value = get_magic_quotes_runtime()?stripslashes_deep(mysql_result($result, $i, $field))
-                                         :mysql_result($result, $i, $field);
+      $value = Toolbox::get_magic_quotes_runtime()
+                  ? Toolbox::stripslashes_deep(mysql_result($result, $i, $field))
+                  : mysql_result($result, $i, $field);
       return $value;
    }
 
@@ -250,8 +254,9 @@ class DBmysql {
    **/
    function fetch_array($result) {
 
-      $value = get_magic_quotes_runtime()?stripslashes_deep(mysql_fetch_array($result))
-                                         :mysql_fetch_array($result);
+      $value = Toolbox::get_magic_quotes_runtime()
+                  ? Toolbox::stripslashes_deep(mysql_fetch_array($result))
+                  : mysql_fetch_array($result);
       return $value;
    }
 
@@ -265,8 +270,9 @@ class DBmysql {
    **/
    function fetch_row($result) {
 
-      $value = get_magic_quotes_runtime()?stripslashes_deep(mysql_fetch_row($result))
-                                         :mysql_fetch_row($result);
+      $value = Toolbox::get_magic_quotes_runtime()
+                  ? Toolbox::stripslashes_deep(mysql_fetch_row($result))
+                  : mysql_fetch_row($result);
       return $value;
    }
 
@@ -280,8 +286,9 @@ class DBmysql {
    **/
    function fetch_assoc($result) {
 
-      $value = get_magic_quotes_runtime()?stripslashes_deep(mysql_fetch_assoc($result))
-                                         :mysql_fetch_assoc($result);
+      $value = Toolbox::get_magic_quotes_runtime()
+                  ? Toolbox::stripslashes_deep(mysql_fetch_assoc($result))
+                  : mysql_fetch_assoc($result);
       return $value;
    }
 
@@ -362,19 +369,25 @@ class DBmysql {
    /**
     * List fields of a table
     *
-    * @param $table table name condition
+    * @param $table     String : table name condition
+    * @param $usecache  Boolean : if use field list cache (default true)
     *
     * @return list of fields
    **/
-   function list_fields($table) {
+   function list_fields($table, $usecache=true) {
+      static $cache = array();
 
+      if ($usecache && isset($cache[$table])) {
+         return $cache[$table];
+      }
       $result = $this->query("SHOW COLUMNS FROM `$table`");
       if ($result) {
          if ($this->numrows($result) > 0) {
+            $cache[$table] = array();
             while ($data = mysql_fetch_assoc($result)) {
-               $ret[$data["Field"]] = $data;
+               $cache[$table][$data["Field"]] = $data;
             }
-            return $ret;
+            return $cache[$table];
          }
          return array();
       }
@@ -470,9 +483,11 @@ class DBmysql {
 
          // do not strip comments due to problems when # in begin of a data line
          $formattedQuery .= $buffer;
-         if (substr(rtrim($formattedQuery),-1) == ";") {
+         if (substr(rtrim($formattedQuery),-1) == ";"
+             && substr(rtrim($formattedQuery),-4) != "&gt;"
+             && substr(rtrim($formattedQuery),-4) != "160;") {
 
-            if (get_magic_quotes_runtime()) {
+            if (Toolbox::get_magic_quotes_runtime()) {
                $formattedQuerytorun = stripslashes($formattedQuery);
             } else {
                $formattedQuerytorun = $formattedQuery;
@@ -518,9 +533,53 @@ class DBmysql {
     * @return DBIterator
    **/
    public function request ($tableorsql, $crit="") {
-      return new DBmysqlIterator ($this, $tableorsql, $crit);
+      return new DBmysqlIterator($this, $tableorsql, $crit);
    }
 
+
+    /**
+     *  Optimize sql table
+     *
+     * @param $migration migration class
+     * @param $cron to know if optimize must be done
+     *
+     * @return number of tables
+    **/
+    static function optimize_tables($migration=NULL, $cron=false) {
+       global $LANG, $DB;
+
+       if (!is_null($migration) && method_exists($migration,'displayMessage')) {
+          $migration->displayTitle($LANG['update'][139]);
+          $migration->setVersion('999'); // to force new ajax zone
+          $migration->displayMessage("optimize - start");
+       }
+       $result = $DB->list_tables("glpi_%");
+       $nb     = 0;
+
+
+       while ($line = $DB->fetch_array($result)) {
+          $table = $line[0];
+
+       // For big database to reduce delay of migration
+          if ($cron || countElementsInTable($table) < 15000000) {
+
+             if (!is_null($migration) && method_exists($migration,'displayMessage')) {
+                $migration->displayMessage("optimize - $table");
+             }
+
+             $query = "OPTIMIZE TABLE `".$table."` ;";
+             $DB->query($query);
+             $nb++;
+          }
+       }
+       $DB->free_result($result);
+
+       if (!is_null($migration) && method_exists($migration,'displayMessage') ){
+          $migration->displayMessage("optimize - end");
+       }
+
+       return $nb;
+    }
 }
 
 
@@ -685,7 +744,7 @@ class DBmysqlIterator  implements Iterator {
    }
 
 
-   public function rewind () {
+   public function rewind() {
 
       if ($this->res && $this->conn->numrows($this->res)) {
          $this->conn->data_seek($this->res,0);
