@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: document_item.class.php 17688 2012-03-01 11:41:03Z remi $
+ * @version $Id: document_item.class.php 18728 2012-06-26 11:42:20Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -69,6 +69,18 @@ class Document_Item extends CommonDBRelation{
       if (countElementsInTable($this->getTable(),$restrict)>0) {
          return false;
       }
+
+      // Set default entities_id and is_recursive if not set.
+      if (!isset($input['entities_id'])) {
+         if (($item = getItemForItemtype($input['itemtype']))
+            && $item->getFromDB($input['items_id'])) {
+            $input['entities_id'] = $item->getEntityID();
+            $input['is_recursive'] = 0;
+            if ($item->isField('is_recursive')) {
+               $input['is_recursive'] = $item->getField('is_recursive');
+            }
+         }
+      }
       return $input;
    }
 
