@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: dropdown.class.php 18028 2012-03-27 09:23:41Z moyo $
+ * @version $Id: dropdown.class.php 18684 2012-06-22 08:06:15Z tsmr $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -822,7 +822,7 @@ class Dropdown {
             $values[$key] = $val[0];
          }
       }
-      self::showFromArray($myname,$values,$options);
+      return self::showFromArray($myname,$values,$options);
    }
 
 
@@ -895,7 +895,7 @@ class Dropdown {
     *
     * @param $types     Array of types used (default "state_types")
     * @param $options   Array of optional options
-    *        value, rand, emptylabel, display_emptychoice, on_change
+    *        value, rand, emptylabel, display_emptychoice, on_change, checkright
     *
     * @return integer rand for select id
     */
@@ -911,6 +911,7 @@ class Dropdown {
       $params['emptylabel']  = self::EMPTY_VALUE;
       //Display emptychoice ?
       $params['display_emptychoice'] = true;
+      $params['checkright']          = false;
 
       if (is_array($options) && count($options)) {
          foreach ($options as $key => $val) {
@@ -925,6 +926,9 @@ class Dropdown {
 
       foreach ($types as $type) {
          if ($item = getItemForItemtype($type)) {
+            if ($params['checkright'] && !$item->canView()) {
+               continue;
+            }
             $options[$type] = $item->getTypeName($type);
          }
       }
@@ -961,14 +965,17 @@ class Dropdown {
     * @param $entity_restrict Restrict to a defined entity
     * @param $types Types used
     * @param $onlyglobal Restrict to global items
+    * @param $checkright      Restrict to items with read rights (false by default)
     *
     * @return nothing (print out an HTML select box)
    **/
    static function showAllItems($myname, $value_type=0, $value=0, $entity_restrict=-1, $types='',
-                                $onlyglobal=false) {
+                                $onlyglobal=false, $checkright=false) {
       global $CFG_GLPI;
 
-      $rand    = self::showItemType($types);
+      $options = array();
+      $options['checkright'] = $checkright;
+      $rand = self::showItemType($types, $options);
 
       if ($rand) {
          $params = array('idtable'          => '__VALUE__',
@@ -1047,6 +1054,8 @@ class Dropdown {
     *    - max : max value : default DAY_TIMESTAMP
     *    - value : default value
     *    - addfirstminutes : add first minutes before first step (default false)
+    *    - toadd : array of values to add
+    *    - inhours : only show timestamp in hours not in days
    **/
    static function showTimeStamp($myname, $options = array()) {
       global $LANG, $CFG_GLPI;
@@ -1057,6 +1066,8 @@ class Dropdown {
       $params['step']             = $CFG_GLPI["time_step"]*MINUTE_TIMESTAMP;
       $params['emptylabel']       = self::EMPTY_VALUE;
       $params['addfirstminutes']  = false;
+      $params['toadd']            = array();
+      $params['inhours']          = false;
 
       if (is_array($options) && count($options)) {
          foreach ($options as $key => $val) {
@@ -1073,14 +1084,19 @@ class Dropdown {
       $params['max'] = max($params['value'], $params['max']);
 
       // Floor with MINUTE_TIMESTAMP for rounded purpose
-      $params['value'] = floor(($params['value'])/$params['step'])*$params['step'];
+      if (($params['value'] < max($params['min'], 10*MINUTE_TIMESTAMP))
+          && $params['addfirstminutes']) {
+         $params['value'] = floor(($params['value'])/MINUTE_TIMESTAMP)*MINUTE_TIMESTAMP;
+      } else {
+         $params['value'] = floor(($params['value'])/$params['step'])*$params['step'];
+      }
 
       $values = array(0  => $params['emptylabel']);
 
       if ($params['value']) {
          $values[$params['value']] = '';
       }
-      
+
       if ($params['addfirstminutes']) {
          for ($i=MINUTE_TIMESTAMP; $i<max($params['min'], 10*MINUTE_TIMESTAMP); $i+=MINUTE_TIMESTAMP) {
             $values[$i] = '';
@@ -1090,11 +1106,22 @@ class Dropdown {
       for ($i = $params['min'] ; $i <= $params['max']; $i+=$params['step']) {
          $values[$i] = '';
       }
-      
+      if (count($params['toadd'])) {
+         foreach ($params['toadd'] as $key) {
+            $values[$key] = '';
+         }
+         ksort($values);
+      }
+
       foreach ($values as $i => $val){
-         if (empty($val)) {      
-            $day        = floor($i/DAY_TIMESTAMP);
-            $hour       = floor(($i%DAY_TIMESTAMP)/HOUR_TIMESTAMP);
+         if (empty($val)) {
+            if ($params['inhours']) {
+               $day  = 0;
+               $hour = floor($i/HOUR_TIMESTAMP);
+            } else {
+               $day  = floor($i/DAY_TIMESTAMP);
+               $hour = floor(($i%DAY_TIMESTAMP)/HOUR_TIMESTAMP);
+            }
             $minute     = floor(($i%HOUR_TIMESTAMP)/MINUTE_TIMESTAMP);
             $values[$i] = '';
             if ($day > 0) {
@@ -1361,19 +1388,20 @@ class Dropdown {
       /// for specific actions (return a array of action name and title)
 
       if (!($item = getItemForItemtype($itemtype))) {
-         return false;
+         return array();
       }
       $actions = array();
-      
+
       if ($itemtype == 'NetworkPort') {
          $actions['delete']        = $LANG['buttons'][6];
          $actions['assign_vlan']   = $LANG['networking'][55];
          $actions['unassign_vlan'] = $LANG['networking'][58];
+         $actions['move']          = $LANG['buttons'][20];
       } else {
          $infocom = new Infocom();
          $isadmin = $item->canUpdate();
 
-         
+
          if (!in_array($itemtype,$CFG_GLPI["massiveaction_noupdate_types"])
              && (($isadmin && $itemtype != 'Ticket')
                  || (in_array($itemtype,$CFG_GLPI["infocom_types"]) && $infocom->canUpdate())
@@ -1597,7 +1625,7 @@ class Dropdown {
       } else {
          $link = $CFG_GLPI["root_doc"]."/ajax/dropdownMassiveAction.php";
       }
-      
+
       if (count($actions)) {
          echo "<select name='massiveaction' id='massiveaction'>";
          echo "<option value='-1' selected>".self::EMPTY_VALUE."</option>";
@@ -1719,4 +1747,4 @@ class Dropdown {
       echo "</select>";
    }
 }
-?>
\ No newline at end of file
+?>
