@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entity.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: entity.class.php 18307 2012-04-18 12:37:14Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -195,6 +195,13 @@ class Entity extends CommonTreeDropdown {
       // most use entities_id, RuleDictionnarySoftwareCollection use new_entities_id
       Rule::cleanForItemAction($this, '%entities_id');
       Rule::cleanForItemCriteria($this);
+
+      $gki = new Entity_KnowbaseItem();
+      $gki->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
+      $gr = new Entity_Reminder();
+      $gr->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
    }
 
 
