@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: entitydata.class.php 17230 2012-01-27 09:47:15Z tsmr $
+ * @version $Id: entitydata.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -272,7 +272,8 @@ class EntityData extends CommonDBChild {
          }
 
          echo "</td></tr>";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
@@ -366,7 +367,8 @@ class EntityData extends CommonDBChild {
          }
 
          echo "</td></tr>";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
@@ -520,7 +522,8 @@ class EntityData extends CommonDBChild {
          }
 
          echo "</td></tr>";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
@@ -675,7 +678,8 @@ class EntityData extends CommonDBChild {
          }
 
          echo "</td></tr>";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
@@ -936,7 +940,8 @@ class EntityData extends CommonDBChild {
          }
 
          echo "</td></tr>";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
 
       } else {
          echo "</table>";
