@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: fieldblacklist.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: fieldblacklist.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,20 +39,23 @@ if (!defined('GLPI_ROOT')) {
 /// Class Fieldblacklist
 class Fieldblacklist extends CommonDropdown {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['setup'][829];
+      }
       return $LANG['setup'][828];
    }
 
 
    function canCreate() {
-      return haveRight('config', 'w');
+      return Session::haveRight('config', 'w');
    }
 
 
    function canView() {
-      return haveRight('config', 'r');
+      return Session::haveRight('config', 'r');
    }
 
 
@@ -104,7 +107,7 @@ class Fieldblacklist extends CommonDropdown {
 
    function prepareInputForAdd($input) {
 
-      $input = parent::prepareInputForAdd ($input);
+      $input = parent::prepareInputForAdd($input);
       return $input;
    }
 
@@ -149,16 +152,15 @@ class Fieldblacklist extends CommonDropdown {
       global $CFG_GLPI;
 
       if ($this->fields['id'] > 0) {
-         $item = new $this->fields['itemtype'];
+         $item = new $this->fields['itemtype']();
          echo $item->getTypeName();
          echo "<input type='hidden' name='itemtype' value='".$this->fields['itemtype']."'>";
 
       } else {
          //Add criteria : display dropdown
-         $options[0] = DROPDOWN_EMPTY_VALUE;
+         $options[0] = Dropdown::EMPTY_VALUE;
          foreach ($CFG_GLPI['unicity_types'] as $itemtype) {
-            if (class_exists($itemtype)) {
-               $item = new $itemtype();
+            if ($item = getItemForItemtype($itemtype)) {
                if ($item->can(-1,'r')) {
                   $options[$itemtype] = $item->getTypeName($itemtype);
                }
@@ -170,9 +172,9 @@ class Fieldblacklist extends CommonDropdown {
 
          $params = array('itemtype' => '__VALUE__',
                          'id'       => $this->fields['id']);
-         ajaxUpdateItemOnSelectEvent("dropdown_itemtype$rand", "span_fields",
-                                     $CFG_GLPI["root_doc"]."/ajax/dropdownFieldsBlacklist.php",
-                                     $params);
+         Ajax::updateItemOnSelectEvent("dropdown_itemtype$rand", "span_fields",
+                                       $CFG_GLPI["root_doc"]."/ajax/dropdownFieldsBlacklist.php",
+                                       $params);
       }
    }
 
@@ -190,7 +192,7 @@ class Fieldblacklist extends CommonDropdown {
       if (!isset($this->fields['entities_id'])) {
          $this->fields['entities_id'] = $_SESSION['glpiactive_entity'];
       }
-      $target = new $this->fields['itemtype'];
+      $target = new $this->fields['itemtype']();
 
       $criteria = array();
       foreach ($DB->list_fields($target->getTable()) as $field) {
@@ -214,9 +216,9 @@ class Fieldblacklist extends CommonDropdown {
       $params = array('itemtype' => $this->fields['itemtype'],
                       'id_field' => '__VALUE__',
                       'id'       => $this->fields['id']);
-      ajaxUpdateItemOnSelectEvent("dropdown_field$rand", "span_values",
-                                  $CFG_GLPI["root_doc"]."/ajax/dropdownValuesBlacklist.php",
-                                  $params);
+      Ajax::updateItemOnSelectEvent("dropdown_field$rand", "span_values",
+                                    $CFG_GLPI["root_doc"]."/ajax/dropdownValuesBlacklist.php",
+                                    $params);
       echo "</span>";
    }
 
@@ -256,7 +258,7 @@ class Fieldblacklist extends CommonDropdown {
                case 'text' :
                case 'string' :
                default :
-                  autocompletionTextField($this, 'value', array('value' => $value));
+                  Html::autocompletionTextField($this, 'value', array('value' => $value));
                   break;
 
                case 'bool':
