@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group.class.php 17695 2012-03-02 14:41:18Z remi $
+ * @version $Id: group.class.php 18871 2012-07-10 09:46:18Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -81,6 +81,16 @@ class Group extends CommonTreeDropdown {
       $gt = new Group_Ticket();
       $gt->cleanDBonItemDelete($this->getType(), $this->fields['id']);
 
+      $gp = new Group_Problem();
+      $gp->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
+      $gki = new Group_KnowbaseItem();
+      $gki->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
+      $gr = new Group_Reminder();
+      $gr->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
+
       // Ticket rules use various _groups_id_*
       Rule::cleanForItemAction($this, '_groups_id%');
       Rule::cleanForItemCriteria($this, '_groups_id%');
@@ -336,10 +346,10 @@ class Group extends CommonTreeDropdown {
       $tab[13]['name']          = $LANG['group'][1];
       $tab[13]['datatype']      = 'bool';
 
-      $tab[14]['table']         = $this->getTable();
-      $tab[14]['field']         = 'is_itemgroup';
-      $tab[14]['name']          = $LANG['search'][2]." ".$LANG['common'][96];
-      $tab[14]['datatype']      = 'bool';
+      $tab[17]['table']         = $this->getTable();
+      $tab[17]['field']         = 'is_itemgroup';
+      $tab[17]['name']          = $LANG['search'][2]." ".$LANG['common'][96];
+      $tab[17]['datatype']      = 'bool';
 
       $tab[15]['table']         = $this->getTable();
       $tab[15]['field']         = 'is_usergroup';
@@ -351,6 +361,7 @@ class Group extends CommonTreeDropdown {
       $tab[70]['name']  = $LANG['common'][64];
       $tab[70]['itemlink_type'] = 'User';
       $tab[70]['forcegroupby']  = true;
+      $tab[70]['massiveaction'] = false;     
       $tab[70]['joinparams']    = array('beforejoin'
                                         => array('table'      => 'glpi_groups_users',
                                                  'joinparams' => array('jointype' => 'child',
@@ -361,6 +372,7 @@ class Group extends CommonTreeDropdown {
       $tab[71]['name']  = $LANG['common'][123];
       $tab[71]['itemlink_type'] = 'User';
       $tab[71]['forcegroupby']  = true;
+      $tab[71]['massiveaction'] = false;
       $tab[71]['joinparams']    = array('beforejoin'
                                         => array('table'      => 'glpi_groups_users',
                                                  'joinparams' => array('jointype' => 'child',
@@ -416,8 +428,6 @@ class Group extends CommonTreeDropdown {
       $options = array('colspan' => 1,
                        'candel'  => false);
       $this->showFormButtons($options);
-
-      echo "</table></div></form>";
    }
 
 
@@ -550,9 +560,11 @@ class Group extends CommonTreeDropdown {
       echo "<tr class='tab_bg_1'><th colspan='3'>$title</tr>";
       echo "<tr class='tab_bg_1'><td class='center'>";
       echo $LANG['common'][17]."&nbsp;:&nbsp;";
-      Dropdown::showItemType($types, array('value'     => $type,
-                                           'name'      => 'onlytype',
-                                           'on_change' => 'reloadTab("start=0&onlytype="+this.value)'));
+      Dropdown::showItemType($types,
+                             array('value'      => $type,
+                                   'name'       => 'onlytype',
+                                   'on_change'  => 'reloadTab("start=0&onlytype="+this.value)',
+                                   'checkright' => true));
       if ($this->haveChildren()) {
          echo "</td><td class='center'>".$LANG['group'][3]."&nbsp;:&nbsp;";
          Dropdown::showYesNo('tree', $tree, -1,
@@ -633,8 +645,8 @@ class Group extends CommonTreeDropdown {
          echo "&nbsp;";
          Html::closeArrowMassives(array('changegroup' => $LANG['buttons'][20]));
       }
-
-      echo "</form></div>";
+      Html::closeForm();
+      echo "</div>";
    }
 
 }
