@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: group_user.class.php 17559 2012-02-21 10:27:45Z remi $
+ * @version $Id: group_user.class.php 18859 2012-07-09 17:49:24Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -193,7 +193,7 @@ class Group_User extends CommonDBRelation{
             Html::openArrowMassives("groupuser_form$rand", true);
             Html::closeArrowMassives(array('deletegroup' => $LANG['buttons'][6]));
          }
-         echo "</form>";
+         Html::closeForm();
       }
       echo "</div>";
    }
@@ -241,7 +241,8 @@ class Group_User extends CommonDBRelation{
          echo "<input type='submit' name='adduser' value=\"".$LANG['buttons'][8]."\"
                 class='submit'>";
          echo "</td></tr>";
-         echo "</table></div></form>";
+         echo "</table></div>";
+         Html::closeForm();
       }
    }
 
@@ -366,7 +367,7 @@ class Group_User extends CommonDBRelation{
       echo "</td></tr></table>";
 
       $number = count($used);
-      $start  = (isset($_REQUEST['start']) ? $_REQUEST['start'] : 0);
+      $start  = (isset($_REQUEST['start']) ? intval($_REQUEST['start']) : 0);
       if ($start>=$number) {
          $start = 0;
       }
@@ -438,6 +439,7 @@ class Group_User extends CommonDBRelation{
             Dropdown::showFromArray('action', $actions);
             echo "&nbsp;";
             Html::closeArrowMassives(array('do' => $LANG['buttons'][2]));
+            Html::closeForm();
          }
          echo "</div>";
       } else {
