@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: holiday.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: holiday.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,20 +39,23 @@ if (!defined('GLPI_ROOT')) {
 /// Class Holiday
 class Holiday extends CommonDropdown {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['calendar'][11];
+      if ($nb>1) {
+         return $LANG['calendar'][11];
+      }
+      return $LANG['calendar'][4];
    }
 
 
    function canCreate() {
-      return haveRight('calendar', 'w');
+      return Session::haveRight('calendar', 'w');
    }
 
 
    function canView() {
-      return haveRight('calendar', 'r');
+      return Session::haveRight('calendar', 'r');
    }
 
 
@@ -102,7 +105,7 @@ class Holiday extends CommonDropdown {
 
    function prepareInputForAdd($input) {
 
-      $input = parent::prepareInputForAdd ($input);
+      $input = parent::prepareInputForAdd($input);
 
       if (empty($input['end_date'])
           || $input['end_date'] == 'NULL'
