@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: includes.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: includes.php 18872 2012-07-10 09:52:13Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -131,4 +131,35 @@ if (isset($_REQUEST['glpi_tab']) && isset($_REQUEST['itemtype'])) {
 if (isset($_REQUEST['glpilist_limit'])) {
    $_SESSION['glpilist_limit']=$_REQUEST['glpilist_limit'];
 }
+
+// Security : Check HTTP_REFERRER : need to be in GLPI.
+if (!defined('DO_NOT_CHECK_HTTP_REFERER') && !isCommandLine()
+   && isset($_POST) && is_array($_POST) && count($_POST)) {
+   // Do not applyed for plugins on 0.83
+   if (strstr($_SERVER['REQUEST_URI'],$CFG_GLPI['root_doc'].'/plugins/') === FALSE) {
+      if (!isset($_SERVER['HTTP_REFERER'])
+          || !is_array($url=parse_url($_SERVER['HTTP_REFERER']))
+          || !isset($url['host'])
+          || ($url['host']!=$_SERVER['SERVER_NAME'])
+          || !isset($url['path'])
+          || (!empty($CFG_GLPI['root_doc']) && strpos($url['path'], $CFG_GLPI['root_doc'])!==0)) {
+         Html::displayErrorAndDie("Error calling the previous page from forbidden one.", true);
+      }
+   }
+}
+
+// Security : check CSRF token
+// No CSRF check if a plugin is not compliant
+if (GLPI_USE_CSRF_CHECK
+   && isset($_POST) && is_array($_POST) && count($_POST)
+   && Plugin::isAllPluginsCSRFCompliant()) {
+   // No ajax pages
+   if (!preg_match(':'.$CFG_GLPI['root_doc'].'(/plugins/[^/]*|)/ajax/:', $_SERVER['REQUEST_URI'])) {
+      if (!Session::validateCSRF($_POST)) {
+         Html::displayErrorAndDie("The action you have requested is not allowed. Reload previous page before doing action again.", true);
+      }
+   }
+}
+// SET new global Token
+$CURRENTCSRFTOKEN = '';
 ?>
