@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: infocom.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: infocom.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -1062,7 +1062,8 @@ class Infocom extends CommonDBChild {
                echo "<input type='submit' name='delete' value=\"".$LANG['buttons'][6]."\"
                       class='submit'>";
                echo "</td></tr>";
-               echo "</table></div></form>";
+               echo "</table></div>";
+               Html::closeForm();
             } else {
                echo "</table></div>";
             }
@@ -1464,6 +1465,7 @@ class Infocom extends CommonDBChild {
 
       if ($this->getFromDBforDevice($itemtype, $oldid)) {
          $input             = $this->fields;
+         $input             = Toolbox::addslashes_deep($input);
          $input['items_id'] = $newid;
          if (!empty($newitemtype)) {
             $input['itemtype'] = $newitemtype;
