@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: knowbaseitem.class.php 17902 2012-03-20 08:20:21Z tsmr $
+ * @version $Id: knowbaseitem.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -74,6 +74,9 @@ class KnowbaseItem extends CommonDBTM {
       if ($this->fields['users_id'] == Session::getLoginUserID()) {
          return true;
       }
+      if (Session::haveRight('knowbase_admin', '1')) {
+         return true;
+      }
 
       if ($this->fields["is_faq"]) {
          return (((Session::haveRight('knowbase', 'r') || Session::haveRight('faq', 'r'))
@@ -87,7 +90,8 @@ class KnowbaseItem extends CommonDBTM {
    function canUpdateItem() {
 
       // Personal knowbase or visibility and write access
-      return ($this->fields['users_id'] == Session::getLoginUserID()
+      return (Session::haveRight('knowbase_admin', '1')
+              || $this->fields['users_id'] == Session::getLoginUserID()
               || ((($this->fields["is_faq"] && Session::haveRight("faq", "w"))
                    || (!$this->fields["is_faq"] && Session::haveRight("knowbase", "w")))
                   && $this->haveVisibilityAccess()));
@@ -176,6 +180,19 @@ class KnowbaseItem extends CommonDBTM {
    }
 
 
+   function cleanDBonPurge() {
+
+      $class = new KnowbaseItem_User();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new Entity_KnowbaseItem();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new Group_KnowbaseItem();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new KnowbaseItem_Profile();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+   }
+
+
    /**
     * @since version 0.83
     */
@@ -230,6 +247,10 @@ class KnowbaseItem extends CommonDBTM {
       if ($this->fields['users_id'] == Session::getLoginUserID()) {
          return true;
       }
+      // Admin
+      if (Session::haveRight('knowbase_admin', '1')) {
+         return true;
+      }
 
       // Users
       if (isset($this->users[Session::getLoginUserID()])) {
@@ -312,7 +333,6 @@ class KnowbaseItem extends CommonDBTM {
    static function addVisibilityJoins($forceall=false) {
 
       $join = '';
-
       // Users
       $join .= " LEFT JOIN `glpi_knowbaseitems_users`
                      ON (`glpi_knowbaseitems_users`.`knowbaseitems_id` = `glpi_knowbaseitems`.`id`) ";
@@ -354,37 +374,39 @@ class KnowbaseItem extends CommonDBTM {
     * @return string restrict to add
    **/
    static function addVisibilityRestrict() {
+      $restrict = '';
+      if (Session::getLoginUserID() && !Session::haveRight('knowbase_admin', '1')) {
 
-      $restrict = "(`glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."' ";
+         $restrict = "(`glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."' ";
+         // Users
+         $restrict .= " OR `glpi_knowbaseitems_users`.`users_id` = '".Session::getLoginUserID()."' ";
+         // Groups
+         if (isset($_SESSION["glpigroups"]) && count($_SESSION["glpigroups"])) {
+            $restrict .= " OR (`glpi_groups_knowbaseitems`.`groups_id`
+                                    IN ('".implode("','",$_SESSION["glpigroups"])."')
+                              AND (`glpi_groups_knowbaseitems`.`entities_id` < 0
+                                    ".getEntitiesRestrictRequest("OR", "glpi_groups_knowbaseitems",
+                                                               '', '', true).")) ";
+         }
 
-      // Users
-      $restrict .= " OR `glpi_knowbaseitems_users`.`users_id` = '".Session::getLoginUserID()."' ";
+         // Profiles
+         if (isset($_SESSION["glpiactiveprofile"]) && isset($_SESSION["glpiactiveprofile"]['id'])) {
+            $restrict .= " OR (`glpi_knowbaseitems_profiles`.`profiles_id`
+                                    = '".$_SESSION["glpiactiveprofile"]['id']."'
+                              AND (`glpi_knowbaseitems_profiles`.`entities_id` < 0
+                                    ".getEntitiesRestrictRequest("OR", "glpi_knowbaseitems_profiles",
+                                                               '', '', true).")) ";
+         }
+         // Entities
+         if (isset($_SESSION["glpiactiveentities"]) && count($_SESSION["glpiactiveentities"])) {
+            // Force complete SQL not summary when access to all entities
+            $restrict .= getEntitiesRestrictRequest("OR", "glpi_entities_knowbaseitems", '', '', true, true);
+         }
 
-      // Groups
-      if (isset($_SESSION["glpigroups"]) && count($_SESSION["glpigroups"])) {
-         $restrict .= " OR (`glpi_groups_knowbaseitems`.`groups_id`
-                                 IN ('".implode("','",$_SESSION["glpigroups"])."')
-                            AND (`glpi_groups_knowbaseitems`.`entities_id` < 0
-                                 ".getEntitiesRestrictRequest("OR", "glpi_groups_knowbaseitems",
-                                                              '', '', true).")) ";
+         $restrict .= ") ";
+      } else {
+         $restrict = '1';
       }
-
-      // Profiles
-      if (isset($_SESSION["glpiactiveprofile"]) && isset($_SESSION["glpiactiveprofile"]['id'])) {
-         $restrict .= " OR (`glpi_knowbaseitems_profiles`.`profiles_id`
-                                 = '".$_SESSION["glpiactiveprofile"]['id']."'
-                            AND (`glpi_knowbaseitems_profiles`.`entities_id` < 0
-                                 ".getEntitiesRestrictRequest("OR", "glpi_knowbaseitems_profiles",
-                                                              '', '', true).")) ";
-      }
-
-      // Entities
-      if (isset($_SESSION["glpiactiveentities"]) && count($_SESSION["glpiactiveentities"])) {
-         // Force complete SQL not summary when access to all entities
-         $restrict .= getEntitiesRestrictRequest("OR", "glpi_entities_knowbaseitems", '', '', true, true);
-      }
-
-      $restrict .= ") ";
       return $restrict;
    }
 
@@ -555,7 +577,9 @@ class KnowbaseItem extends CommonDBTM {
 
          echo "<span class='big_space'>";
          echo "<input type='reset' class='submit' value=\"".$LANG['buttons'][16]."\"></span>";
-         echo "</p></form></div>";
+         echo "</p>";
+         Html::closeForm();
+         echo "</div>";
          return true;
       }
       //  ELSE Cannot edit
@@ -720,9 +744,9 @@ class KnowbaseItem extends CommonDBTM {
       echo "</td></tr>";
       echo "<tr class='tab_bg_3'><td class='left' colspan='4'><h2>".$LANG['knowbase'][15]."</h2>\n";
 
-      $answer = Toolbox::unclean_cross_side_scripting_deep($this->fields["answer"]);
-
-      echo "<div id='kbanswer'>".$answer."</div>";
+      echo "<div id='kbanswer'>";
+      echo Toolbox::unclean_html_cross_side_scripting_deep($this->fields["answer"]);
+      echo "</div>";
       echo "</td></tr>";
 
       echo "<tr><th class='tdkb'  colspan='2'>";
@@ -806,7 +830,7 @@ class KnowbaseItem extends CommonDBTM {
          echo "<input type='hidden' name='itemtype' value='".$options['itemtype']."'>";
          echo "<input type='hidden' name='items_id' value='".$options['items_id']."'>";
       }
-      echo "</form>";
+      Html::closeForm();
 
       echo "</td>";
 
@@ -822,7 +846,9 @@ class KnowbaseItem extends CommonDBTM {
          Dropdown::show('KnowbaseItemCategory',
                         array('value' => '$params["knowbaseitemcategories_id)"]'));
          echo "</td><td><input type='submit' value=\"".$LANG['buttons'][2]."\" class='submit'></td>";
-         echo "</tr></table></form></td>";
+         echo "</tr></table>";
+         Html::closeForm();
+         echo "</td>";
       }
       echo "</tr></table></div>";
    }
@@ -906,7 +932,7 @@ class KnowbaseItem extends CommonDBTM {
          $order  = " ORDER BY `glpi_knowbaseitems`.`name` ASC";
       }
 
-      $query = "SELECT `glpi_knowbaseitems`.*,
+      $query = "SELECT DISTINCT `glpi_knowbaseitems`.*,
                        `glpi_knowbaseitemcategories`.`completename` AS category
                        $score
                 FROM `glpi_knowbaseitems`
@@ -916,7 +942,6 @@ class KnowbaseItem extends CommonDBTM {
                            = `glpi_knowbaseitems`.`knowbaseitemcategories_id`)
                 WHERE $where
                 $order";
-
       return $query;
    }
 
@@ -1129,11 +1154,14 @@ class KnowbaseItem extends CommonDBTM {
       if ($type=="notpublished") {
          $title = $LANG['knowbase'][2];
          // not published = no visibility set
-         $faq_limit = "WHERE `glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'
-                             AND `glpi_entities_knowbaseitems`.`entities_id` IS NULL
+         $faq_limit = "WHERE `glpi_entities_knowbaseitems`.`entities_id` IS NULL
                              AND `glpi_knowbaseitems_profiles`.`profiles_id` IS NULL
                              AND `glpi_groups_knowbaseitems`.`groups_id` IS NULL
                              AND `glpi_knowbaseitems_users`.`users_id` IS NULL";
+
+         if (!Session::haveRight('knowbase_admin', '1')) {
+            $faq_limit .= " AND `glpi_knowbaseitems`.`users_id` = '".Session::getLoginUserID()."'";
+         }
       } else {
          // Only published
          $faq_limit .= " AND (`glpi_entities_knowbaseitems`.`entities_id` IS NOT NULL
@@ -1146,7 +1174,7 @@ class KnowbaseItem extends CommonDBTM {
          $faq_limit .= " AND (`glpi_knowbaseitems`.`is_faq` = '1')";
       }
 
-      $query = "SELECT `glpi_knowbaseitems`.*
+      $query = "SELECT DISTINCT `glpi_knowbaseitems`.*
                 FROM `glpi_knowbaseitems`
                 $join
                 $faq_limit
@@ -1284,10 +1312,7 @@ class KnowbaseItem extends CommonDBTM {
       echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG['common'][116]."</th></tr>";
       echo "<tr class='tab_bg_1'><td class='tab_bg_2' width='100px'>";
 
-      $types = array( 'Group', 'Profile', 'User');
-      if (Session::isMultiEntitiesMode()) {
-         $types[] = 'Entity';
-      }
+      $types = array( 'Group', 'Profile', 'User', 'Entity');
 
       $addrand = Dropdown::dropdownTypes('_type', '', $types);
       $params  = array('type'  => '__VALUE__',
@@ -1434,10 +1459,10 @@ class KnowbaseItem extends CommonDBTM {
          $confirm= array();
          if ($this->fields['users_id'] != Session::getLoginUserID()) {
             $confirm = array('deletevisibility' => $LANG['common'][120]);
-         }         
-         
+         }
+
          Html::closeArrowMassives(array('deletevisibility' => $LANG['buttons'][6]), $confirm);
-         echo "</form>";
+         Html::closeForm();
       }
 
       echo "</div>";
@@ -1448,4 +1473,4 @@ class KnowbaseItem extends CommonDBTM {
 
 
 }
-?>
\ No newline at end of file
+?>
