@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: link.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: link.class.php 17637 2012-02-27 13:50:29Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,20 +39,45 @@ if (!defined('GLPI_ROOT')) {
 // CLASSES link
 class Link extends CommonDBTM {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['title'][33];
+      if ($nb>1) {
+         return $LANG['title'][33];
+      }
+      return $LANG['title'][32];
    }
 
 
    function canCreate() {
-      return haveRight('link', 'w');
+      return Session::haveRight('link', 'w');
    }
 
 
    function canView() {
-      return haveRight('link', 'r');
+      return Session::haveRight('link', 'r');
+   }
+
+
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (Session::haveRight("link","r")) {
+         if ($_SESSION['glpishow_count_on_tabs']) {
+            return self::createTabEntry($LANG['title'][34],
+                                        countElementsInTable('glpi_links_itemtypes',
+                                                             "`itemtype` = '".$item->getType()."'"));
+         }
+         return $LANG['title'][34];
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      self::showForItem($item);
+      return true;
    }
 
 
@@ -60,7 +85,8 @@ class Link extends CommonDBTM {
       global $LANG;
 
       $ong = array();
-      $ong[1] = $LANG['title'][26];
+      $this->addStandardTab('Link_ItemType', $ong, $options);
+
       return $ong;
    }
 
@@ -84,12 +110,9 @@ class Link extends CommonDBTM {
    *@return Nothing (display)
    *
    **/
-   function showForm ($ID, $options=array()) {
+   function showForm($ID, $options=array()) {
       global $LANG;
 
-      if (!haveRight("link","r")) {
-         return false;
-      }
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -106,12 +129,12 @@ class Link extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'><td>".$LANG['common'][16]."&nbsp;:</td>";
       echo "<td colspan='3'>";
-      autocompletionTextField($this, "name", array('size' => 84));
+      Html::autocompletionTextField($this, "name", array('size' => 84));
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'><td>".$LANG['links'][1]."&nbsp;:</td>";
       echo "<td colspan='2'>";
-      autocompletionTextField($this, "link", array('size' => 84));
+      Html::autocompletionTextField($this, "link", array('size' => 84));
       echo "</td><td width='1'></td></tr>";
 
       echo "<tr class='tab_bg_1'><td>".$LANG['links'][9]."&nbsp;:</td>";
@@ -163,12 +186,10 @@ class Link extends CommonDBTM {
    *
    * @param $link string : original string content
    * @param $item CommonDBTM : item used to make replacements
-   * @param $name string : name used for multi link generation
-   * @param $noip boolean : true to not evaluate IP/MAC
    *
    * @return array of link contents (may have several when item have several IP / MAC cases)
    */
-   static function generateLinkContents($link, CommonDBTM $item, $name='', $noip=false) {
+   static function generateLinkContents($link, CommonDBTM $item) {
       global $DB;
 
       if (strstr($link,"[ID]")) {
@@ -235,7 +256,7 @@ class Link extends CommonDBTM {
       }
       $ipmac = array();
 
-      if ($noip || (!strstr($link,"[IP]") && !strstr($link,"[MAC]"))) {
+      if (!strstr($link,"[IP]") && !strstr($link,"[MAC]")) {
          return array($link);
 
       } else { // Return sevral links id several IP / MAC
@@ -247,7 +268,7 @@ class Link extends CommonDBTM {
                     ORDER BY `logical_number`";
          $result2 = $DB->query($query2);
 
-         if (get_class($item)=='NetworkEquipment') {
+         if (get_class($item) == 'NetworkEquipment') {
             $ipmac[0]['ip']     = $item->getField('ip');
             $ipmac[0]['mac']    = $item->getField('mac');
             $ipmac[0]['number'] = '';
@@ -260,11 +281,10 @@ class Link extends CommonDBTM {
             }
          }
 
-         // Add IP/MAC internal switch
          if (count($ipmac)>0) {
             foreach ($ipmac as $key => $val) {
                $tmplink = $link;
-               $disp = 1;
+               $disp    = 1;
                if (strstr($link,"[IP]")) {
                   if (empty($val['ip'])) {
                      $disp = 0;
@@ -297,22 +317,17 @@ class Link extends CommonDBTM {
    /**
     * Show Links for an item
     *
-    * @param $itemtype integer : item type
-    * @param $ID integer : item ID
-    */
-   static function showForItem($itemtype, $ID) {
+    * @param $item CommonDBTM object
+    * @param $withtemplate integer : withtemplate param
+   **/
+   static function showForItem(CommonDBTM $item, $withtemplate='') {
       global $DB, $LANG, $CFG_GLPI;
 
-      if (!class_exists($itemtype)) {
+      if (!Session::haveRight("link","r")) {
          return false;
       }
 
-      $item = new $itemtype;
-      if (!$item->getFromDB($ID)) {
-         return false;
-      }
-
-      if (!haveRight("link","r")) {
+      if ($item->isNewID($item->getID())) {
          return false;
       }
 
@@ -323,7 +338,7 @@ class Link extends CommonDBTM {
                 FROM `glpi_links`
                 INNER JOIN `glpi_links_itemtypes`
                      ON `glpi_links`.`id` = `glpi_links_itemtypes`.`links_id`
-                WHERE `glpi_links_itemtypes`.`itemtype`='$itemtype' " .
+                WHERE `glpi_links_itemtypes`.`itemtype`='".$item->getType()."' " .
                       getEntitiesRestrictRequest(" AND", "glpi_links", "entities_id",
                                                  $item->getEntityID(), true)."
                 ORDER BY name";
@@ -339,13 +354,16 @@ class Link extends CommonDBTM {
             if (empty($name)) {
                $name = $data["link"];
             }
+            $names = self::generateLinkContents($name, $item);
+
             $file = trim($data["data"]);
 
             if (empty($file)) {
                // Generate links
-               $links = self::generateLinkContents($data['link'], $item, $name);
-               $i=1;
+               $links = self::generateLinkContents($data['link'], $item);
+               $i     = 1;
                foreach ($links as $key => $link) {
+                  $name =  (isset($names[$key]) ? $names[$key] : reset($names));
                   echo "<tr class='tab_bg_2'>";
                   $url = $link;
                   echo "<td class='center'><a href='$url' target='_blank'>$name #$i : $link</a>";
@@ -354,10 +372,11 @@ class Link extends CommonDBTM {
                }
             } else {
                // Generate files
-               $files = self::generateLinkContents($data['link'], $item, $name);
-               $links = self::generateLinkContents($data['data'], $item, $name);
-               $i=1;
+               $files = self::generateLinkContents($data['link'], $item);
+               $links = self::generateLinkContents($data['data'], $item);
+               $i     = 1;
                foreach ($links as $key => $link) {
+                  $name =  (isset($names[$key]) ? $names[$key] : reset($names));
                   if (isset($files[$key])) {
                      // a different name for each file, ex name = foo-[IP].txt
                      $file = $files[$key];
@@ -367,7 +386,8 @@ class Link extends CommonDBTM {
                   }
                   echo "<tr class='tab_bg_2'>";
                   $url = $CFG_GLPI["root_doc"]."/front/link.send.php?lID=".$data['id'].
-                         "&amp;itemtype=$itemtype&amp;id=$ID&amp;rank=$key";
+                         "&amp;itemtype=".$item->getType().
+                         "&amp;id=".$item->getID()."&amp;rank=$key";
                   echo "<td class='center'><a href='$url' target='_blank'>$name #$i : $file</a>";
                   echo "</td></tr>";
                   $i++;
@@ -383,5 +403,4 @@ class Link extends CommonDBTM {
       }
    }
 }
-
 ?>
\ No newline at end of file
