@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: link_itemtype.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: link_itemtype.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -99,7 +99,8 @@ class Link_ItemType extends CommonDBTM{
                             $LANG['buttons'][8]."\" class='submit'>";
          echo "</td></tr>";
       }
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 
