@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: log.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: log.class.php 17985 2012-03-23 08:50:03Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -40,6 +40,27 @@ if (!defined('GLPI_ROOT')) {
 // Log class
 class Log extends CommonDBTM {
 
+   const HISTORY_ADD_DEVICE         = 1;
+   const HISTORY_UPDATE_DEVICE      = 2;
+   const HISTORY_DELETE_DEVICE      = 3;
+   const HISTORY_INSTALL_SOFTWARE   = 4;
+   const HISTORY_UNINSTALL_SOFTWARE = 5;
+   const HISTORY_DISCONNECT_DEVICE  = 6;
+   const HISTORY_CONNECT_DEVICE     = 7;
+   const HISTORY_OCS_IMPORT         = 8;
+   const HISTORY_OCS_DELETE         = 9;
+   const HISTORY_OCS_IDCHANGED      = 10;
+   const HISTORY_OCS_LINK           = 11;
+   const HISTORY_LOG_SIMPLE_MESSAGE = 12;
+   const HISTORY_DELETE_ITEM        = 13;
+   const HISTORY_RESTORE_ITEM       = 14;
+   const HISTORY_ADD_RELATION       = 15;
+   const HISTORY_DEL_RELATION       = 16;
+   const HISTORY_ADD_SUBITEM        = 17;
+   const HISTORY_UPDATE_SUBITEM     = 18;
+   const HISTORY_DELETE_SUBITEM     = 19;
+   const HISTORY_CREATE_ITEM        = 20;
+
 
    static function getTypeName() {
       global $LANG;
@@ -48,6 +69,29 @@ class Log extends CommonDBTM {
    }
 
 
+   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
+      global $LANG;
+
+      if (!$withtemplate) {
+         if ($_SESSION['glpishow_count_on_tabs']) {
+            return self::createTabEntry($LANG['title'][38],
+                                        countElementsInTable('glpi_logs',
+                                                             "itemtype = '".$item->getType()."'
+                                                               AND items_id = '".$item->getID()."'"));
+         }
+         return $LANG['title'][38];
+      }
+      return '';
+   }
+
+
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
+
+      self::showForItem($item);
+      return true;
+   }
+
+
    /**
     * Construct  history for an item
     *
@@ -64,18 +108,9 @@ class Log extends CommonDBTM {
          return false;
       }
       // needed to have  $SEARCHOPTION
-      if ($item->getType() == 'TicketSatisfaction') {
-         $real_type = 'Ticket';
-         $real_id   = $item->fields['tickets_id'];
+      list($real_type, $real_id) = $item->getLogTypeID();
+      // toolbox::logDebug("constructHistory:", $item->getType(), $real_type, $real_id, $oldvalues);
 
-      } else if ($item->getType() == 'Infocom') {
-         $real_type = $item->fields['itemtype'];
-         $real_id   = $item->fields['items_id'];
-
-      } else {
-         $real_type = $item->getType();
-         $real_id   = $item->fields['id'];
-      }
       $searchopt = Search::getOptions($real_type);
 
       if (!is_array($searchopt)) {
@@ -83,105 +118,61 @@ class Log extends CommonDBTM {
       }
       $result = 0;
 
+      // type for which getValueToDisplay() could be used (fully tested)
+      $oktype = array('Entity');
+
       foreach ($oldvalues as $key => $oldval) {
          $changes = array();
 
-         if ($real_type == 'Infocom') {
-            // Parsing $SEARCHOPTION to find infocom
-            foreach ($searchopt as $key2 => $val2) {
-               if (($val2["field"] == $key && strpos($val2['table'], 'infocoms'))
-                   || ($key == 'budgets_id' && $val2['table'] == 'glpi_budgets')
-                   || ($key == 'suppliers_id' && $val2['table'] == 'glpi_suppliers')) {
-
-                  $id_search_option = $key2; // Give ID of the $SEARCHOPTION
-                  if ($val2["table"] == "glpi_infocoms") {
-                     // 1st case : text field -> keep datas
-                     $changes = array($id_search_option, addslashes($oldval), $values[$key]);
-
-                  } else if ($val2["table"] == "glpi_suppliers") {
-                     // 2nd case ; link field -> get data from glpi_suppliers
-                     $changes = array($id_search_option,
-                                      addslashes(Dropdown::getDropdownName("glpi_suppliers",
-                                                                           $oldval)),
-                                      addslashes(Dropdown::getDropdownName("glpi_suppliers",
-                                                                           $values[$key])));
-
-                  } else {
-                     // 3rd case ; link field -> get data from dropdown (budget)
-                     $changes = array($id_search_option,
-                                      addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                           $oldval)),
-                                      addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                           $values[$key])));
-                  }
-                  break; // foreach exit
-               }
+         // Parsing $SEARCHOPTION to find changed field
+         foreach ($searchopt as $key2 => $val2) {
+            if (!is_array($val2)) {
+               // skip sub-title
+               continue;
             }
+            // Linkfield or standard field not massive action enable
+            if ($val2['linkfield'] == $key
+                || ($key == $val2['field'] && $val2['table'] == $item->getTable())) {
+               $id_search_option = $key2; // Give ID of the $SEARCHOPTION
 
-         } else { // Not an Infocom
-            // Parsing $SEARCHOPTION to find changed field
-            foreach ($searchopt as $key2 => $val2) {
-               // Linkfield or standard field not massive action enable
-               if ($val2["linkfield"] == $key
-                   || ($key == $val2["field"] && $val2["table"] == $item->getTable())) {
-                  $id_search_option = $key2; // Give ID of the $SEARCHOPTION
-
-                  // 1st case : Ticket specific dropdown case (without table)
-                  if ($real_type=='Ticket' && in_array($key, array('status', 'urgency', 'impact',
-                                                                   'priority', 'global_validation'))) {
-                     switch ($key) {
-                        case 'global_validation' :
-                           $changes = array($id_search_option,
-                                            addslashes(TicketValidation::getStatus($oldval)),
-                                            addslashes(TicketValidation::getStatus($values[$key])));
-                           break;
-
-                        case 'status' :
-                           $changes = array($id_search_option,
-                                            addslashes(Ticket::getStatus($oldval)),
-                                            addslashes(Ticket::getStatus($values[$key])));
-                           break;
-
-                        case 'urgency' :
-                           $changes = array($id_search_option,
-                                            addslashes(Ticket::getUrgencyName($oldval)),
-                                            addslashes(Ticket::getUrgencyName($values[$key])));
-                           break;
-
-                        case 'impact' :
-                           $changes = array($id_search_option,
-                                            addslashes(Ticket::getImpactName($oldval)),
-                                            addslashes(Ticket::getImpactName($values[$key])));
-                           break;
-
-                        case 'priority' :
-                           $changes = array($id_search_option,
-                                            addslashes(Ticket::getPriorityName($oldval)),
-                                            addslashes(Ticket::getPriorityName($values[$key])));
-                           break;
-                     }
-
-                  } else if ($val2["table"] == $item->getTable()) {
-                     // 2nd case : text field -> keep datas
-                     $changes = array($id_search_option, addslashes($oldval), $values[$key]);
+               // 1st case : Ticket specific dropdown case (without table)
+               if ($real_type=='Ticket'
+                   && in_array($key, array('global_validation', 'impact', 'items_id', 'itemtype',
+                                           'status', 'type', 'urgency', 'priority'))) {
+                  $changes = array($id_search_option,
+                                   addslashes(Ticket::getSpecificValueToDisplay($key, $oldvalues)),
+                                   addslashes(Ticket::getSpecificValueToDisplay($key, $values)));
 
+               } else if ($val2['table'] == $item->getTable()) {
+                  if (in_array($real_type, $oktype)) {
+                     // 2nd case : use getValueToDisplay();
+                     $changes = array($key2,
+                                addslashes($item->getValueToDisplay($searchopt[$key2],
+                                                                    $oldvalues)),
+                                addslashes($item->getValueToDisplay($searchopt[$key2],
+                                                                    $values)));
+                     // toolbox::logDebug("CHANGES for $key in", $item->getTable(), $changes);
                   } else {
+                     // 3rd case : text field -> keep datas
+                     $changes = array($id_search_option, addslashes($oldval), $values[$key]);
+                  }
+
+               } else {
 //                      if ($val2['table'] == 'glpi_users_validation') {
 //                         $val2['table'] = 'glpi_users';
 //                      }
 
-                     // other cases ; link field -> get data from dropdown
-                     if ($val2["table"] != 'glpi_complete_entities' 
-                        && $val2["table"] != 'glpi_auth_tables' ) {
-                        $changes = array($id_search_option,
-                                         addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                              $oldval)),
-                                         addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                              $values[$key])));
-                     }
+                  // other cases ; link field -> get data from dropdown
+                  if ($val2['table'] != 'glpi_complete_entities'
+                     && $val2["table"] != 'glpi_auth_tables') {
+                     $changes = array($id_search_option,
+                                      addslashes(Dropdown::getDropdownName($val2["table"],
+                                                                           $oldval)),
+                                      addslashes(Dropdown::getDropdownName($val2["table"],
+                                                                           $values[$key])));
                   }
-                  break;
                }
+               break;
             }
          }
 
@@ -217,7 +208,7 @@ class Log extends CommonDBTM {
       $old_value        = $changes[1];
       $new_value        = $changes[2];
 
-      if ($uid=getLoginUserID(false)) {
+      if ($uid=Session::getLoginUserID(false)) {
          if (is_numeric($uid)) {
             $username = getUserName($uid,$link=0);
          } else { // For cron management
@@ -228,15 +219,15 @@ class Log extends CommonDBTM {
          $username = "";
       }
 
-      $old_value = mysql_real_escape_string(utf8_substr(stripslashes($old_value), 0, 180));
-      $new_value = mysql_real_escape_string(utf8_substr(stripslashes($new_value), 0, 180));
+      $old_value = mysql_real_escape_string(Toolbox::substr(stripslashes($old_value), 0, 180));
+      $new_value = mysql_real_escape_string(Toolbox::substr(stripslashes($new_value), 0, 180));
 
       // Security to be sure that values do not pass over the max length
-      if (utf8_strlen($old_value)>255) {
-         $old_value = utf8_substr($old_value,0,250);
+      if (Toolbox::strlen($old_value)>255) {
+         $old_value = Toolbox::substr($old_value,0,250);
       }
-      if (utf8_strlen($new_value)>255) {
-         $new_value = utf8_substr($new_value,0,250);
+      if (Toolbox::strlen($new_value)>255) {
+         $new_value = Toolbox::substr($new_value,0,250);
       }
 
       // Build query
@@ -248,7 +239,7 @@ class Log extends CommonDBTM {
                         '$old_value', '$new_value')";
 
       if ($DB->query($query)) {
-         return $DB->insert_id();
+         return $_SESSION['glpi_maxhistory'] = $DB->insert_id();
       }
       return false;
    }
@@ -258,8 +249,10 @@ class Log extends CommonDBTM {
     * Show History of an item
     *
     * @param $item CommonDBTM object
+    * @param $withtemplate integer : withtemplate param
+
    **/
-   static function showForItem(CommonDBTM $item) {
+   static function showForItem(CommonDBTM $item, $withtemplate='') {
       global $DB,$LANG;
 
       $itemtype = $item->getType();
@@ -288,7 +281,7 @@ class Log extends CommonDBTM {
       }
 
       // Display the pager
-      printAjaxPager($LANG['title'][38],$start,$number);
+      Html::printAjaxPager($LANG['title'][38],$start,$number);
 
       // Output events
       echo "<div class='center'><table class='tab_cadre_fixe'>";
@@ -345,7 +338,7 @@ class Log extends CommonDBTM {
          $tmp = array();
          $tmp['display_history'] = true;
          $tmp['id']              = $data["id"];
-         $tmp['date_mod']        = convDateTime($data["date_mod"]);
+         $tmp['date_mod']        = Html::convDateTime($data["date_mod"]);
          $tmp['user_name']       = $data["user_name"];
          $tmp['field']           = "";
          $tmp['change']          = "";
@@ -355,32 +348,30 @@ class Log extends CommonDBTM {
          if ($data["linked_action"]) {
             // Yes it is an internal device
             switch ($data["linked_action"]) {
-               case HISTORY_CREATE_ITEM :
+               case self::HISTORY_CREATE_ITEM :
                   $tmp['change'] = $LANG['log'][20];
                   break;
 
-               case HISTORY_DELETE_ITEM :
+               case self::HISTORY_DELETE_ITEM :
                   $tmp['change'] = $LANG['log'][22];
                   break;
 
-               case HISTORY_RESTORE_ITEM :
+               case self::HISTORY_RESTORE_ITEM :
                   $tmp['change'] = $LANG['log'][23];
                   break;
 
-               case HISTORY_ADD_DEVICE :
+               case self::HISTORY_ADD_DEVICE :
                   $tmp['field'] = NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['devices'][25]." : "."\"". $data["new_value"]."\"";
                   break;
 
-               case HISTORY_UPDATE_DEVICE :
+               case self::HISTORY_UPDATE_DEVICE :
                   $tmp['field'] = NOT_AVAILABLE;
                   $change = '';
-                  if (class_exists($data["itemtype_link"])) {
-                     $item          = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field']  = $item->getTypeName();
                      $specif_fields = $item->getSpecifityLabel();
                      $tmp['change'] = $specif_fields['specificity']." : ";
@@ -388,45 +379,42 @@ class Log extends CommonDBTM {
                   $tmp['change'] .= $data[ "old_value"]." --> "."\"". $data[ "new_value"]."\"";
                   break;
 
-               case HISTORY_DELETE_DEVICE :
+               case self::HISTORY_DELETE_DEVICE :
                   $tmp['field']=NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['devices'][26]." : "."\"". $data["old_value"]."\"";
                   break;
 
-               case HISTORY_INSTALL_SOFTWARE :
+               case self::HISTORY_INSTALL_SOFTWARE :
                   $tmp['field']  = $LANG['help'][31];
                   $tmp['change'] = $LANG['software'][44]." : "."\"".$data["new_value"]."\"";
                   break;
 
-               case HISTORY_UNINSTALL_SOFTWARE :
+               case self::HISTORY_UNINSTALL_SOFTWARE :
                   $tmp['field']  = $LANG['help'][31];
                   $tmp['change'] = $LANG['software'][45]." : "."\"". $data["old_value"]."\"";
                   break;
 
-               case HISTORY_DISCONNECT_DEVICE :
+               case self::HISTORY_DISCONNECT_DEVICE :
                   $tmp['field'] = NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][26]." : "."\"". $data["old_value"]."\"";
                   break;
 
-               case HISTORY_CONNECT_DEVICE :
+               case self::HISTORY_CONNECT_DEVICE :
                   $tmp['field'] = NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][27]." : "."\"". $data["new_value"]."\"";
                   break;
 
-               case HISTORY_OCS_IMPORT :
-                  if (haveRight("view_ocsng","r")) {
+               case self::HISTORY_OCS_IMPORT :
+                  if (Session::haveRight("view_ocsng","r")) {
                      $tmp['field']  = "";
                      $tmp['change'] = $LANG['ocsng'][7]." ".$LANG['ocsng'][45]." :";
                      $tmp['change'].= " "."\"".$data["new_value"]."\"";
@@ -435,8 +423,8 @@ class Log extends CommonDBTM {
                   }
                   break;
 
-               case HISTORY_OCS_DELETE :
-                  if (haveRight("view_ocsng","r")) {
+               case self::HISTORY_OCS_DELETE :
+                  if (Session::haveRight("view_ocsng","r")) {
                      $tmp['field']  ="";
                      $tmp['change'] = $LANG['ocsng'][46]." ".$LANG['ocsng'][45]." :";
                      $tmp['change'].= " "."\"".$data["old_value"]."\"";
@@ -445,11 +433,10 @@ class Log extends CommonDBTM {
                   }
                   break;
 
-               case HISTORY_OCS_LINK :
-                  if (haveRight("view_ocsng","r")) {
+               case self::HISTORY_OCS_LINK :
+                  if (Session::haveRight("view_ocsng","r")) {
                      $tmp['field'] = NOT_AVAILABLE;
-                     if (class_exists($data["itemtype_link"])) {
-                        $item         = new $data["itemtype_link"]();
+                     if ($item = getItemForItemtype($data["itemtype_link"])) {
                         $tmp['field'] = $item->getTypeName();
                      }
                      $tmp['change'] = $LANG['ocsng'][47]." ".$LANG['ocsng'][45]." :";
@@ -460,8 +447,8 @@ class Log extends CommonDBTM {
                   }
                   break;
 
-               case HISTORY_OCS_IDCHANGED :
-                  if (haveRight("view_ocsng","r")) {
+               case self::HISTORY_OCS_IDCHANGED :
+                  if (Session::haveRight("view_ocsng","r")) {
                      $tmp['field']  = "";
                      $tmp['change'] = $LANG['ocsng'][48]." "." : "."\"".
                                       $data["old_value"]."\" -->  : "."\"".
@@ -471,51 +458,46 @@ class Log extends CommonDBTM {
                   }
                   break;
 
-               case HISTORY_LOG_SIMPLE_MESSAGE :
+               case self::HISTORY_LOG_SIMPLE_MESSAGE :
                   $tmp['field']  = "";
                   $tmp['change'] = $data["new_value"];
                   break;
 
-               case HISTORY_ADD_RELATION :
+               case self::HISTORY_ADD_RELATION :
                   $tmp['field'] = NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][32]." : "."\"". $data["new_value"]."\"";
                   break;
 
-               case HISTORY_DEL_RELATION :
+               case self::HISTORY_DEL_RELATION :
                   $tmp['field'] = NOT_AVAILABLE;
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][33]." : "."\"". $data["old_value"]."\"";
                   break;
 
-               case HISTORY_ADD_SUBITEM :
+               case self::HISTORY_ADD_SUBITEM :
                   $tmp['field'] = '';
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][98]." : ".$tmp['field']." (".$data["new_value"].")";
                   break;
 
-               case HISTORY_UPDATE_SUBITEM :
+               case self::HISTORY_UPDATE_SUBITEM :
                   $tmp['field'] = '';
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][99]." : ".$tmp['field']." (".$data["new_value"].")";
                   break;
 
-               case HISTORY_DELETE_SUBITEM :
+               case self::HISTORY_DELETE_SUBITEM :
                   $tmp['field'] = '';
-                  if (class_exists($data["itemtype_link"])) {
-                     $item         = new $data["itemtype_link"]();
+                  if ($item = getItemForItemtype($data["itemtype_link"])) {
                      $tmp['field'] = $item->getTypeName();
                   }
                   $tmp['change'] = $LANG['log'][100]." : ".$tmp['field']." (".$data["old_value"].")";
@@ -544,33 +526,33 @@ class Log extends CommonDBTM {
                   break;
 
                case "datetime" :
-                  $data["old_value"] = convDateTime($data["old_value"]);
-                  $data["new_value"] = convDateTime($data["new_value"]);
+                  $data["old_value"] = Html::convDateTime($data["old_value"]);
+                  $data["new_value"] = Html::convDateTime($data["new_value"]);
                   break;
 
                case "date" :
-                  $data["old_value"] = convDate($data["old_value"]);
-                  $data["new_value"] = convDate($data["new_value"]);
+                  $data["old_value"] = Html::convDate($data["old_value"]);
+                  $data["new_value"] = Html::convDate($data["new_value"]);
                   break;
 
                case "timestamp" :
-                  $data["old_value"] = timestampToString($data["old_value"]);
-                  $data["new_value"] = timestampToString($data["new_value"]);
+                  $data["old_value"] = Html::timestampToString($data["old_value"]);
+                  $data["new_value"] = Html::timestampToString($data["new_value"]);
                   break;
 
                case "actiontime" :
-                  $data["old_value"] = Ticket::getActionTime($data["old_value"]);
-                  $data["new_value"] = Ticket::getActionTime($data["new_value"]);
+                  $data["old_value"] = CommonITILObject::getActionTime($data["old_value"]);
+                  $data["new_value"] = CommonITILObject::getActionTime($data["new_value"]);
                   break;
 
                case "number" :
-                  $data["old_value"] = formatNumber($data["old_value"],false,0);
-                  $data["new_value"] = formatNumber($data["new_value"],false,0);
+                  $data["old_value"] = Html::formatNumber($data["old_value"],false,0);
+                  $data["new_value"] = Html::formatNumber($data["new_value"],false,0);
                   break;
 
                case "decimal" :
-                  $data["old_value"] = formatNumber($data["old_value"]);
-                  $data["new_value"] = formatNumber($data["new_value"]);
+                  $data["old_value"] = Html::formatNumber($data["old_value"]);
+                  $data["new_value"] = Html::formatNumber($data["new_value"]);
                   break;
 
                case "right" :
@@ -591,5 +573,16 @@ class Log extends CommonDBTM {
       return $changes;
    }
 
+
+   /**
+    * Actions done after the ADD of the item in the database
+    *
+    * @since version 0.83
+    *
+    * @see inc/CommonDBTM::post_addItem()
+   **/
+   function post_addItem() {
+      $_SESSION['glpi_maxhistory'] = $this->fields['id'];
+   }
 }
 ?>
\ No newline at end of file
