@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: mailcollector.class.php 18022 2012-03-27 07:57:42Z moyo $
+ * @version $Id: mailcollector.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -263,7 +263,9 @@ class MailCollector  extends CommonDBTM {
       echo "<input type='submit' name='get_mails' value=\"".$LANG['mailgate'][2]."\" class='submit'>";
       echo "<input type='hidden' name='id' value='$ID'>";
       echo "</td></tr>";
-      echo "</table></form></div>";
+      echo "</table>";
+      Html::closeForm();
+      echo "</div>";
    }
 
 
@@ -422,6 +424,15 @@ class MailCollector  extends CommonDBTM {
                                   ||(isset($tkt['_users_id_requester'])
                                      && $tkt['_users_id_requester'] > 0));
 
+               $rejinput = array();
+               $rejinput['mailcollectors_id'] = $mailgateID;
+               $rejinput['from']              = $tkt['_head']['from'];
+               $rejinput['to']                = $tkt['_head']['to'];
+               $rejinput['users_id']          = $tkt['_users_id_requester'];
+               $rejinput['subject']           = $this->textCleaner($tkt['_head']['subject']);
+               $rejinput['messageid']         = $tkt['_head']['message_id'];
+               $rejinput['date']              = $_SESSION["glpi_currenttime"];
+
                // Manage blacklisted emails
                if (isset($tkt['_blacklisted']) && $tkt['_blacklisted']) {
                   $this->deleteMails($i);
@@ -449,6 +460,10 @@ class MailCollector  extends CommonDBTM {
                            $fup = new TicketFollowup();
                            if ($fup->add($tkt)) {
                               $delete_mail = true;
+                           } else {
+                              $error++;
+                              $rejinput['reason'] = NotImportedEmail::FAILED_INSERT;
+                              $rejected->add($rejinput);
                            }
                         } else {
                            $error++;
@@ -460,6 +475,10 @@ class MailCollector  extends CommonDBTM {
                            $track = new Ticket();
                            if ($track->add($tkt)) {
                               $delete_mail = true;
+                           } else {
+                              $error++;
+                              $rejinput['reason'] = NotImportedEmail::FAILED_INSERT;
+                              $rejected->add($rejinput);
                            }
                         } else {
                            $error++;
@@ -477,23 +496,13 @@ class MailCollector  extends CommonDBTM {
                   }
 
                } else {
-                  $input = array();
-                  $input['mailcollectors_id'] = $mailgateID;
-                  $input['from']              = $tkt['_head']['from'];
-                  $input['to']                = $tkt['_head']['to'];
-
                   if (!$tkt['_users_id_requester']) {
-                     $input['reason'] = NotImportedEmail::USER_UNKNOWN;
+                     $rejinput['reason'] = NotImportedEmail::USER_UNKNOWN;
 
                   } else {
-                     $input['reason'] = NotImportedEmail::MATCH_NO_RULE;
+                     $rejinput['reason'] = NotImportedEmail::MATCH_NO_RULE;
                   }
-
-                  $input['users_id']  = $tkt['_users_id_requester'];
-                  $input['subject']   = $this->textCleaner($tkt['_head']['subject']);
-                  $input['messageid'] = $tkt['_head']['message_id'];
-                  $input['date']      = $_SESSION["glpi_currenttime"];
-                  $rejected->add($input);
+                  $rejected->add($rejinput);
                }
                $this->fetch_emails++;
             }
@@ -673,9 +682,10 @@ class MailCollector  extends CommonDBTM {
                   // Delete line at the top of the first comment
                   if ($first_comment) {
                      $first_comment = false;
-                     if (isset($to_keep[$ID-1])) {
-                        unset($to_keep[$ID-1]);
-                     }
+                     // Do not drop line before comment because may be real text
+//                      if (isset($to_keep[$ID-1])) {
+//                         unset($to_keep[$ID-1]);
+//                      }
                   }
                } else {
                   $to_keep[$ID] = $ID;
@@ -911,9 +921,9 @@ class MailCollector  extends CommonDBTM {
 
          // secu on subject setting
          if (!isset($mail_header->subject)) {
-            $mail_header->subject = '';         
+            $mail_header->subject = '';
          }
-         
+
          $mail_details = array('from'       => Toolbox::strtolower($sender->mailbox).'@'.$sender->host,
                                'subject'    => $mail_header->subject,
                                'to'         => Toolbox::strtolower($to->mailbox).'@'.$to->host,
