@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: netpoint.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: netpoint.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -349,7 +349,7 @@ class Netpoint extends CommonDropdown {
             echo "<input type='hidden' name='action' value='delete'>";
             Html::closeArrowMassives(array('massiveaction' => $LANG['buttons'][6]));
 
-            echo "</form>\n";
+            Html::closeForm();
          }
       }
 
@@ -364,7 +364,8 @@ class Netpoint extends CommonDropdown {
          echo "<input type='hidden' name='locations_id' value='$ID'></td>";
          echo "<td><input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
 
          // Minimal form for massive input.
          echo "<form action='".$netpoint->getFormURL()."' method='post'>";
@@ -382,7 +383,8 @@ class Netpoint extends CommonDropdown {
          echo "<td><input type='submit' name='execute' value=\"".$LANG['buttons'][8]."\"
                     class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       }
       echo "</div>\n";
    }
