@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport.class.php 18087 2012-03-29 10:52:38Z walid $
+ * @version $Id: networkport.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -67,7 +67,7 @@ class NetworkPort extends CommonDBChild {
 
    function canView() {
 
-      if (isset($this->fields['itemtype'])) {
+      if (isset($this->fields['itemtype']) && $item=getItemForItemtype($this->fields['itemtype'])) {
          $item = new $this->fields['itemtype']();
          return $item->canView();
       }
@@ -403,7 +403,7 @@ class NetworkPort extends CommonDBChild {
                Dropdown::showForMassiveAction('NetworkPort');
                $actions = array();
                Html::closeArrowMassives($actions);
-               echo "</form>";
+               Html::closeForm();
             }
 
          } else {
