@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport_networkport.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: networkport_networkport.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -83,11 +83,11 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
       $sport = $this->fields['networkports_id_1'];
       $dport = $this->fields['networkports_id_2'];
 
-      $ps = new NetworkPort;
+      $ps = new NetworkPort();
       if (!$ps->getFromDB($sport)) {
          return false;
       }
-      $pd = new NetworkPort;
+      $pd = new NetworkPort();
       if (!$pd->getFromDB($dport)) {
          return false;
       }
@@ -106,18 +106,21 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
       // Update Item
       $updates[0] = 'netpoints_id';
 
-      if (empty ($source) && !empty ($destination)) {
+      if (empty($source) && !empty($destination)) {
          $ps->fields['netpoints_id'] = $destination;
          $ps->updateInDB($updates);
-         addMessageAfterRedirect($LANG['connect'][15] . "&nbsp;:&nbsp;" . $LANG['networking'][51]);
+         Session::addMessageAfterRedirect($LANG['connect'][15] . "&nbsp;:&nbsp;" .
+                                          $LANG['networking'][51]);
 
-      } else if (!empty ($source) && empty ($destination)) {
+      } else if (!empty($source) && empty($destination)) {
          $pd->fields['netpoints_id'] = $source;
          $pd->updateInDB($updates);
-         addMessageAfterRedirect($LANG['connect'][15] . "&nbsp;:&nbsp;" . $LANG['networking'][51]);
+         Session::addMessageAfterRedirect($LANG['connect'][15] . "&nbsp;:&nbsp;" .
+                                          $LANG['networking'][51]);
 
       } else if ($source != $destination) {
-         addMessageAfterRedirect($LANG['connect'][16] . "&nbsp;:&nbsp;" . $LANG['networking'][51]);
+         Session::addMessageAfterRedirect($LANG['connect'][16] . "&nbsp;:&nbsp;" .
+                                          $LANG['networking'][51]);
       }
 
       // Manage VLAN : use networkings one as defaults
@@ -168,16 +171,14 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
       $sourcehistory = false;
       $desthistory   = false;
 
-      if (class_exists($ps->fields['itemtype'])) {
-         $sourceitem = new $ps->fields['itemtype']();
+      if ($sourceitem = getItemForItemtype($ps->fields['itemtype'])) {
          if ($sourceitem->getFromDB($ps->fields['items_id'])) {
             $sourcename    = $sourceitem->getName();
             $sourcehistory = $sourceitem->dohistory;
          }
       }
 
-      if (class_exists($pd->fields['itemtype'])) {
-         $destitem = new $pd->fields['itemtype']();
+      if ($destitem = getItemForItemtype($pd->fields['itemtype'])) {
          if ($destitem->getFromDB($pd->fields['items_id'])) {
             $destname    = $destitem->getName();
             $desthistory = $destitem->dohistory;
@@ -199,7 +200,7 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
          }
 
          Log::history($ps->fields["items_id"], $ps->fields["itemtype"], $changes,
-                      $pd->fields["itemtype"], HISTORY_CONNECT_DEVICE);
+                      $pd->fields["itemtype"], Log::HISTORY_CONNECT_DEVICE);
       }
 
       if ($desthistory) {
@@ -214,7 +215,7 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
          }
 
          Log::history($pd->fields["items_id"], $pd->fields["itemtype"], $changes,
-                      $ps->fields["itemtype"], HISTORY_CONNECT_DEVICE);
+                      $ps->fields["itemtype"], Log::HISTORY_CONNECT_DEVICE);
       }
    }
 
@@ -223,8 +224,8 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
 
       // Update to blank networking item
       // clean datas of linked ports if network one
-      $np1 = new NetworkPort;
-      $np2 = new NetworkPort;
+      $np1 = new NetworkPort();
+      $np2 = new NetworkPort();
       if ($np1->getFromDB($this->fields['networkports_id_1'])
           && $np2->getFromDB($this->fields['networkports_id_2'])) {
          $npnet = NULL;
@@ -266,8 +267,7 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
          $name      = NOT_AVAILABLE;
          $dohistory = false;
 
-         if (class_exists($np2->fields["itemtype"])) {
-            $item = new $np2->fields["itemtype"];
+         if ($item = getItemForItemtype($np2->fields["itemtype"])) {
             if ($item->getFromDB($np2->fields["items_id"])) {
                $name      = $item->getName();
                $dohistory = $item->dohistory;
@@ -287,13 +287,12 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
                $changes[1] = $changes[1] . " > #" . $np2->fields["name"];
             }
             Log::history($np1->fields["items_id"], $np1->fields["itemtype"], $changes,
-                         $np2->fields["itemtype"], HISTORY_DISCONNECT_DEVICE);
+                         $np2->fields["itemtype"], Log::HISTORY_DISCONNECT_DEVICE);
          }
 
          $name      = NOT_AVAILABLE;
          $dohistory = false;
-         if (class_exists($np1->fields["itemtype"])) {
-            $item = new $np1->fields["itemtype"];
+         if ($item = getItemForItemtype($np1->fields["itemtype"])) {
             if ($item->getFromDB($np1->fields["items_id"])) {
                $name      = $item->getName();
                $dohistory = $item->dohistory;
@@ -313,7 +312,7 @@ class NetworkPort_NetworkPort extends CommonDBRelation {
                $changes[1] = $changes[1] . " > #" . $np1->fields["name"];
             }
             Log::history($np2->fields["items_id"], $np2->fields["itemtype"], $changes,
-                         $np1->fields["itemtype"], HISTORY_DISCONNECT_DEVICE);
+                         $np1->fields["itemtype"], Log::HISTORY_DISCONNECT_DEVICE);
          }
       }
 
