@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: networkport_vlan.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: networkport_vlan.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -191,7 +191,8 @@ class NetworkPort_Vlan extends CommonDBRelation {
                      "' class='submit'>";
          echo "</td></tr>\n";
 
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
       }
    }
 
