@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notification.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notification.class.php 17657 2012-02-28 09:12:39Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,80 +49,80 @@ class Notification extends CommonDBTM {
    // MAILING USERS TYPE
 
    //Notification to the GLPI global administrator
-   const GLOBAL_ADMINISTRATOR              = 1;
+   const GLOBAL_ADMINISTRATOR       = 1;
    //Notification to the technicial who's assign to a ticket
-   const TICKET_ASSIGN_TECH                = 2;
+   const ASSIGN_TECH                = 2;
    //Notification to the owner of the item
-   const AUTHOR                            = 3;
+   const AUTHOR                     = 3;
    //Notification to the technician previously in charge of the ticket
-   const TICKET_OLD_TECH_IN_CHARGE = 4;
+   const OLD_TECH_IN_CHARGE         = 4;
    //Notification to the technician in charge of the item
-   const ITEM_TECH_IN_CHARGE               = 5;
+   const ITEM_TECH_IN_CHARGE        = 5;
    //Notification to the item's user
-   const ITEM_USER                         = 6;
+   const ITEM_USER                  = 6;
    //Notification to the ticket's recipient
-   const TICKET_RECIPIENT                  = 7;
+   const RECIPIENT                  = 7;
    //Notificartion to the ticket's assigned supplier
-   const TICKET_SUPPLIER                   = 8;
+   const SUPPLIER                   = 8;
    //Notification to a group of people
-   const TICKET_ASSIGN_GROUP               = 9;
+   const ASSIGN_GROUP               = 9;
    //Notification to the supervisor of the ticket's assigned group
-   const TICKET_SUPERVISOR_ASSIGN_GROUP    = 10;
+   const SUPERVISOR_ASSIGN_GROUP    = 10;
    //Notification to the entity administrator
-   const ENTITY_ADMINISTRATOR              = 11;
+   const ENTITY_ADMINISTRATOR       = 11;
    //Notification to the supervisor of the ticket's requester group
-   const TICKET_SUPERVISOR_REQUESTER_GROUP = 12;
+   const SUPERVISOR_REQUESTER_GROUP = 12;
    //Notification to the ticket's requester group
-   const TICKET_REQUESTER_GROUP            = 13;
+   const REQUESTER_GROUP            = 13;
    //Notification to the ticket validation approver
-   const TICKET_VALIDATION_APPROVER        = 14;
+   const VALIDATION_APPROVER        = 14;
    //Notification to the ticket validation requester
-   const TICKET_VALIDATION_REQUESTER       = 15;
+   const VALIDATION_REQUESTER       = 15;
    //Notification to the task assign user
-   const TICKET_TASK_ASSIGN_TECH           = 16;
+   const TASK_ASSIGN_TECH           = 16;
    //Notification to the task author
-   const TICKET_TASK_AUTHOR                = 17;
+   const TASK_AUTHOR                = 17;
    //Notification to the followup author
-   const TICKET_FOLLOWUP_AUTHOR            = 18;
+   const FOLLOWUP_AUTHOR            = 18;
    //Notification to the user
-   const USER                              = 19;
+   const USER                       = 19;
    //Notification to the ticket's observer group
-   const TICKET_OBSERVER_GROUP             = 20;
+   const OBSERVER_GROUP             = 20;
    //Notification to the ticket's observer user
-   const TICKET_OBSERVER                   = 21;
+   const OBSERVER                   = 21;
    //Notification to the supervisor of the ticket's observer group
-   const TICKET_SUPERVISOR_OBSERVER_GROUP  = 22;
+   const SUPERVISOR_OBSERVER_GROUP  = 22;
+   //Notification to the group of technician in charge of the item
+   const ITEM_TECH_GROUP_IN_CHARGE  = 23;
 
 
    // From CommonDBTM
    public $dohistory = true;
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
-      return $LANG['setup'][704];
+      if ($nb>1) {
+         return $LANG['setup'][704];
+      }
+      return $LANG['setup'][705];
    }
 
 
    function defineTabs($options=array()) {
       global $LANG;
 
-      $tabs[1]  = $LANG['common'][12];
-      if ($this->fields['id'] > 0) {
-         $tabs[12] = $LANG['title'][38];
-      }
+      $ong = array();
+      $this->addStandardTab('NotificationTarget', $ong, $options);
+      $this->addStandardTab('Log', $ong, $options);
 
-      return $tabs;
+      return $ong;
    }
 
 
    function showForm($ID, $options=array()) {
       global $LANG,$CFG_GLPI;
 
-      if (!haveRight("notification", "r")) {
-         return false;
-      }
-
       if ($ID > 0) {
          $this->check($ID,'r');
       } else {
@@ -135,7 +135,7 @@ class Notification extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['common'][16] . "&nbsp;:</td>";
       echo "<td>";
-      autocompletionTextField($this, "name");
+      Html::autocompletionTextField($this, "name");
       echo "</td>";
 
       echo "<td rowspan='6' class='middle right'>".$LANG['common'][25]."&nbsp;:</td>";
@@ -149,7 +149,7 @@ class Notification extends CommonDBTM {
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['common'][17] . "&nbsp;:</td>";
       echo "<td>";
-      if (haveRight('config', 'w') && $this->getEntityID() == 0) {
+      if (Session::haveRight('config', 'w') && $this->getEntityID() == 0) {
          $rand = Dropdown::dropdownTypes("itemtype", $this->fields['itemtype'],
                                          $CFG_GLPI["notificationtemplates_types"]);
       } else {
@@ -160,12 +160,12 @@ class Notification extends CommonDBTM {
       }
 
       $params = array('itemtype' => '__VALUE__');
-      ajaxUpdateItemOnSelectEvent("dropdown_itemtype$rand", "show_events",
-                                  $CFG_GLPI["root_doc"]."/ajax/dropdownNotificationEvent.php",
-                                  $params);
-      ajaxUpdateItemOnSelectEvent("dropdown_itemtype$rand", "show_templates",
-                                  $CFG_GLPI["root_doc"]."/ajax/dropdownNotificationTemplate.php",
-                                  $params);
+      Ajax::updateItemOnSelectEvent("dropdown_itemtype$rand", "show_events",
+                                    $CFG_GLPI["root_doc"]."/ajax/dropdownNotificationEvent.php",
+                                    $params);
+      Ajax::updateItemOnSelectEvent("dropdown_itemtype$rand", "show_templates",
+                                    $CFG_GLPI["root_doc"]."/ajax/dropdownNotificationTemplate.php",
+                                    $params);
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'><td>" . $LANG['mailing'][120] . "&nbsp;:</td>";
@@ -178,7 +178,7 @@ class Notification extends CommonDBTM {
       NotificationEvent::dropdownEvents($this->fields['itemtype'],$this->fields['event']);
       echo "</span></td></tr>";
 
-      echo "<tr class='tab_bg_1'><td>" . $LANG['mailing'][113] . "&nbsp;:</td>";
+      echo "<tr class='tab_bg_1'><td>" . $LANG['mailing'][112] . "&nbsp;:</td>";
       echo "<td><span id='show_templates'>";
       NotificationTemplate::dropdownTemplates('notificationtemplates_id', $this->fields['itemtype'],
                                               $this->fields['notificationtemplates_id']);
@@ -250,22 +250,22 @@ class Notification extends CommonDBTM {
 
 
    function canCreate() {
-      return haveRight('notification', 'w');
+      return Session::haveRight('notification', 'w');
    }
 
 
    function canView() {
-      return haveRight('notification', 'r');
+      return Session::haveRight('notification', 'r');
    }
 
 
    function canViewItem() {
 
       if (($this->fields['itemtype'] == 'Crontask' || $this->fields['itemtype'] == 'DBConnection')
-          && !haveRight('config', 'w')) {
+          && !Session::haveRight('config', 'w')) {
           return false;
       }
-      return haveAccessToEntity($this->getEntityID(), $this->isRecursive());
+      return Session::haveAccessToEntity($this->getEntityID(), $this->isRecursive());
    }
 
 
@@ -277,10 +277,10 @@ class Notification extends CommonDBTM {
    function canCreateItem() {
 
       if (($this->fields['itemtype'] == 'Crontask' || $this->fields['itemtype'] == 'DBConnection')
-          && !haveRight('config', 'w')) {
+          && !Session::haveRight('config', 'w')) {
           return false;
       }
-      return haveAccessToEntity($this->getEntityID());
+      return Session::haveAccessToEntity($this->getEntityID());
    }
 
 
@@ -319,9 +319,9 @@ class Notification extends CommonDBTM {
    }
 
 
-   static function send ($mailing_options) {
+   static function send($mailing_options) {
 
-      $mail = new NotificationMail;
+      $mail = new NotificationMail();
       $mail->sendNotification($mailing_options);
       $mail->ClearAddresses();
    }
@@ -334,7 +334,9 @@ class Notification extends CommonDBTM {
       global $DB, $CFG_GLPI;
 
       foreach ($DB->request('glpi_entitydatas', array('entities_id' => $entity)) as $data) {
-         return $data['mailing_signature'];
+         if (!empty($data['mailing_signature'])) {
+            return $data['mailing_signature'];
+         }
       }
       return $CFG_GLPI['mailing_signature'];
 
@@ -354,7 +356,7 @@ class Notification extends CommonDBTM {
                                                  $entity, true) ."
                       AND `glpi_notifications`.`is_active`='1'
                 ORDER BY `glpi_entities`.`level` DESC";
-// logDebug($query);
+// Toolbox::logDebug($query);
       return $DB->request($query);
    }
 
