@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationevent.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationevent.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -41,6 +41,16 @@ if (!defined('GLPI_ROOT')) {
 **/
 class NotificationEvent extends CommonDBTM {
 
+   static function getTypeName($nb=0) {
+      global $LANG;
+
+      if ($nb>1) {
+         return $LANG['mailing'][108];
+      }
+      return $LANG['mailing'][119];
+   }
+
+
    static function dropdownEvents($itemtype,$value='') {
 
       $events = array();
@@ -48,11 +58,35 @@ class NotificationEvent extends CommonDBTM {
       if ($target) {
          $events = $target->getAllEvents();
       }
-      $events[''] = DROPDOWN_EMPTY_VALUE;
+      $events[''] = Dropdown::EMPTY_VALUE;
       Dropdown::showFromArray('event', $events, array('value' => $value));
    }
 
 
+   /**
+    * retrieve the label for an event
+    *
+    * @since version 0.83
+    *
+    * @param itemtype string name of the type
+    * @param $event   string name of the event
+    *
+    * @return string
+   **/
+   static function getEventName($itemtype, $event) {
+
+      $events = array();
+      $target = NotificationTarget::getInstanceByType($itemtype);
+      if ($target) {
+         $events = $target->getAllEvents();
+         if (isset($events[$event])) {
+            return $events[$event];
+         }
+      }
+      return NOT_AVAILABLE;
+   }
+
+
    /**
     * Raise a notification event event
     *
@@ -69,7 +103,7 @@ class NotificationEvent extends CommonDBTM {
          $email_processed    = array();
          $email_notprocessed = array();
          //Get template's informations
-         $template = new NotificationTemplate;
+         $template = new NotificationTemplate();
 
          $notificationtarget = NotificationTarget::getInstance($item,$event,$options);
          $entity             = $notificationtarget->getEntity();
@@ -112,8 +146,8 @@ class NotificationEvent extends CommonDBTM {
 
                            //Send notification to the user
                            if ($label=='') {
-                              Notification::send ($template->getDataToSend($notificationtarget,
-                                                                           $users_infos, $options));
+                              Notification::send($template->getDataToSend($notificationtarget,
+                                                                          $users_infos, $options));
                            } else {
                               $notificationtarget->getFromDB($target['id']);
                               echo "<tr class='tab_bg_2'><td>".$label."</td>";
