@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationmail.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationmail.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -78,7 +78,7 @@ class NotificationMail extends phpmailer implements NotificationInterface {
          if ($CFG_GLPI['smtp_username'] != '') {
             $this->SMTPAuth = true;
             $this->Username = $CFG_GLPI['smtp_username'];
-            $this->Password = decrypt($CFG_GLPI['smtp_passwd'], GLPIKEY);
+            $this->Password = Toolbox::decrypt($CFG_GLPI['smtp_passwd'], GLPIKEY);
          }
 
          if ($CFG_GLPI['smtp_mode'] == MAIL_SMTPSSL) {
@@ -90,7 +90,7 @@ class NotificationMail extends phpmailer implements NotificationInterface {
          }
       }
 
-      if ($_SESSION['glpi_use_mode'] == DEBUG_MODE) {
+      if ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE) {
          $this->do_debug = 3;
       }
    }
@@ -167,7 +167,7 @@ class NotificationMail extends phpmailer implements NotificationInterface {
    static function testNotification() {
       global $CFG_GLPI,$LANG;
 
-      $mmail = new NotificationMail;
+      $mmail = new NotificationMail();
       $mmail->AddCustomHeader("Auto-Submitted: auto-generated");
       // For exchange
       $mmail->AddCustomHeader("X-Auto-Response-Suppress: OOF, DR, NDR, RN, NRN");
@@ -177,9 +177,9 @@ class NotificationMail extends phpmailer implements NotificationInterface {
       $mmail->Body    = $LANG['mailing'][31]."\n-- \n".$CFG_GLPI["mailing_signature"];
 
       if (!$mmail->Send()) {
-         addMessageAfterRedirect($LANG['setup'][206], false, ERROR);
+         Session::addMessageAfterRedirect($LANG['setup'][206], false, ERROR);
       } else {
-         addMessageAfterRedirect($LANG['setup'][205]);
+         Session::addMessageAfterRedirect($LANG['setup'][205]);
       }
    }
 
@@ -240,9 +240,10 @@ class NotificationMail extends phpmailer implements NotificationInterface {
 
       if (!$mmail->Send()) {
          $senderror = true;
-         addMessageAfterRedirect($messageerror."<br>".$mmail->ErrorInfo, true);
+         Session::addMessageAfterRedirect($messageerror."<br>".$mmail->ErrorInfo, true);
       } else {
-         logInFile("mail", $LANG['tracking'][38]." ".$options['to']." : ".$options['subject']."\n");
+         Toolbox::logInFile("mail",
+                            $LANG['tracking'][38]." ".$options['to']." : ".$options['subject']."\n");
       }
 
       $mmail->ClearAddresses();
