@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationmailsetting.class.php 17841 2012-03-13 21:08:37Z tsmr $
+ * @version $Id: notificationmailsetting.class.php 18871 2012-07-10 09:46:18Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -214,12 +214,6 @@ class NotificationMailSetting extends CommonDBTM {
       $options['candel'] = false;
       $options['addbuttons'] = array('test_smtp_send' => $LANG['setup'][229]);
       $this->showFormButtons($options);
-
-      /*
-      echo "<tr class='tab_bg_2'><td class='center' colspan='4'>";
-      echo "<input class='submit' type='submit' name='update' value='".$LANG['buttons'][2]."'>";
-      echo "</td></tr>";
-      echo "</table></form>";*/
    }
 
 
