@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtarget.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: notificationtarget.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -210,7 +210,8 @@ class NotificationTarget extends CommonDBChild {
       echo "<input type='hidden' name='itemtype' value='".$notification->getField('itemtype')."'>";
       $this->showNotificationTargets($notification);
       echo "</tr>";
-      echo "</table></form>";
+      echo "</table>";
+      Html::closeForm();
    }
 
 
@@ -505,7 +506,7 @@ class NotificationTarget extends CommonDBChild {
    /**
     * Get targets for all the users of a group
     *
-    * @param $manager : 0 user, 1 supervisor
+    * @param $manager : 0 all users, 1 only supervisors
     * @param $group_id id of the group
    **/
    function getAddressesByGroup($manager, $group_id) {
@@ -519,9 +520,12 @@ class NotificationTarget extends CommonDBChild {
                $this->getProfileJoinSql()."
                INNER JOIN `glpi_groups` ON (`glpi_groups_users`.`groups_id` = `glpi_groups`.`id`)
                WHERE `glpi_groups_users`.`groups_id` = '$group_id'
-                     AND `glpi_groups_users`.`is_manager` = '$manager'
                      AND `glpi_groups`.`is_notify`";
 
+      if ($manager) {
+         $query .= " AND `glpi_groups_users`.`is_manager` ";
+      }
+
       foreach ($DB->request($query) as $data) {
          $this->addToAddressesList($data);
       }
