@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetcartridge.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: notificationtargetcartridge.class.php 18475 2012-05-15 11:43:31Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -76,7 +76,7 @@ class NotificationTargetCartridge extends NotificationTarget {
 
       $tags = array('cartridge.action'    => $LANG['mailing'][119],
                     'cartridge.reference' => $LANG['consumables'][2],
-                    'cartridge.item'      => $LANG['financial'][104],
+                    'cartridge.item'      => $LANG['cartridges'][1],
                     'cartridge.remaining' => $LANG['software'][20],
                     'cartridge.url'       => $LANG['common'][94],
                     'cartridge.entity'    => $LANG['entity'][0]);
