@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetconsumable.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: notificationtargetconsumable.class.php 18475 2012-05-15 11:43:31Z yllen $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -78,7 +78,7 @@ class NotificationTargetConsumable extends NotificationTarget {
 
       $tags = array('consumable.action'    => $LANG['mailing'][119],
                     'consumable.reference' => $LANG['consumables'][2],
-                    'consumable.item'      => $LANG['financial'][104],
+                    'consumable.item'      => $LANG['consumables'][3],
                     'consumable.remaining' => $LANG['software'][20],
                     'consumable.entity'    => $LANG['entity'][0]);
 
