@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetreservation.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: notificationtargetreservation.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,6 +49,7 @@ class NotificationTargetReservation extends NotificationTarget {
 
       if ($event != 'alert') {
          $this->addTarget(Notification::ITEM_TECH_IN_CHARGE, $LANG['common'][10]);
+         $this->addTarget(Notification::ITEM_TECH_GROUP_IN_CHARGE, $LANG['common'][109]);
          $this->addTarget(Notification::ITEM_USER, $LANG['mailing'][137]);
          $this->addTarget(Notification::AUTHOR, $LANG['job'][4]);
       }
@@ -65,20 +66,19 @@ class NotificationTargetReservation extends NotificationTarget {
 
       if ($event != 'alert') {
          $this->datas['##reservation.user##'] = "";
-         $user_tmp = new User;
+         $user_tmp = new User();
          if ($user_tmp->getFromDB($this->obj->getField('users_id'))) {
             $this->datas['##reservation.user##'] = $user_tmp->getName();
          }
-         $this->datas['##reservation.begin##']   = convDateTime($this->obj->getField('begin'));
-         $this->datas['##reservation.end##']     = convDateTime($this->obj->getField('end'));
+         $this->datas['##reservation.begin##']   = Html::convDateTime($this->obj->getField('begin'));
+         $this->datas['##reservation.end##']     = Html::convDateTime($this->obj->getField('end'));
          $this->datas['##reservation.comment##'] = $this->obj->getField('comment');
 
-         $reservationitem = new ReservationItem;
+         $reservationitem = new ReservationItem();
          $reservationitem->getFromDB($this->obj->getField('reservationitems_id'));
          $itemtype = $reservationitem->getField('itemtype');
 
-         if (class_exists($itemtype)) {
-            $item = new $itemtype();
+         if ($item = getItemForItemtype($itemtype)) {
             $item->getFromDB($reservationitem->getField('items_id'));
             $this->datas['##reservation.itemtype##']    = $item->getTypeName();
             $this->datas['##reservation.item.name##']   = $item->getField('name');
@@ -101,10 +101,10 @@ class NotificationTargetReservation extends NotificationTarget {
 
          foreach ($options['items'] as $id => $item) {
             $tmp = array();
-            $obj = new $item['itemtype'] ();
+            $obj = new $item['itemtype']();
             $tmp['##reservation.itemtype##']       = $obj->getTypeName();
             $tmp['##reservation.item##']           = $item['item_name'];
-            $tmp['##reservation.expirationdate##'] = convDateTime($item['end']);
+            $tmp['##reservation.expirationdate##'] = Html::convDateTime($item['end']);
             $tmp['##reservation.url##']            = urldecode($CFG_GLPI["url_base"].
                                                                "/index.php?redirect=reservation_".
                                                                $id);
@@ -182,8 +182,9 @@ class NotificationTargetReservation extends NotificationTarget {
          if ($ri->getFromDB($this->obj->getField('reservationitems_id'))) {
             $itemtype = $ri->getField('itemtype');
 
-            if ($itemtype != NOT_AVAILABLE && $itemtype != '' && class_exists($itemtype)) {
-               $item = new $itemtype();
+            if ($itemtype != NOT_AVAILABLE
+                && $itemtype != ''
+                && ($item = getItemForItemtype($itemtype))) {
                $item->getFromDB($ri->getField('items_id'));
                $this->target_object = $item;
             }
