@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: notificationtargetticket.class.php 18161 2012-04-04 17:57:33Z moyo $
+ * @version $Id: notificationtargetticket.class.php 18719 2012-06-26 06:57:34Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -162,7 +162,7 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
                       'update_task'     => $LANG['job'][52],
                       'delete_task'     => $LANG['job'][53],
                       'closed'          => $LANG['mailing'][127],
-                      'deleted'         => $LANG['mailing'][129],
+                      'delete'          => $LANG['mailing'][129],
                       'alertnotclosed'  => $LANG['crontask'][15],
                       'recall'          => $LANG['sla'][9],
                       'satisfaction'    => $LANG['satisfaction'][3]);
@@ -214,7 +214,8 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
 
       $datas['##ticket.urlvalidation##']   = urldecode($CFG_GLPI["url_base"].
                                                                "/index.php?redirect=ticket_".
-                                                               $item->getField("id")."_TicketValidation");
+                                                               $item->getField("id").
+                                                               "_TicketValidation$1");
 
       $datas['##ticket.globalvalidation##']
                   = TicketValidation::getStatus($item->getField('global_validation'));
@@ -228,13 +229,11 @@ class NotificationTargetTicket extends NotificationTargetCommonITILObject {
 
       $datas['##ticket.autoclose##']             = $LANG['setup'][307];
       $datas['##lang.ticket.autoclosewarning##'] = "";
-      if ($autoclose_value >= 0) {
-               $datas['##ticket.autoclose##'] = $autoclose_value;
-      } 
       if ($autoclose_value > 0) {
-               $datas['##lang.ticket.autoclosewarning##']
-                           = $LANG['job'][54]." ".$autoclose_value." ".Toolbox::ucfirst($LANG['calendar'][12]);
-      } 
+         $datas['##ticket.autoclose##'] = $autoclose_value;
+         $datas['##lang.ticket.autoclosewarning##']
+                     = $LANG['job'][54]." ".$autoclose_value." ".Toolbox::ucfirst($LANG['calendar'][12]);
+      }
 
       $datas['##ticket.sla##'] = '';
       if ($item->getField('slas_id')) {
