@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: notimportedemail.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: notimportedemail.class.php 18751 2012-06-28 06:27:44Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -41,6 +41,7 @@ class NotImportedEmail extends CommonDBTM {
 
    const MATCH_NO_RULE = 0;
    const USER_UNKNOWN  = 1;
+   const FAILED_INSERT = 2;
 
    function canCreate() {
       return Session::haveRight('config', 'w');
@@ -130,6 +131,9 @@ class NotImportedEmail extends CommonDBTM {
          case self::USER_UNKNOWN :
             return $LANG['login'][14];
 
+         case self::FAILED_INSERT :
+            return $LANG['common'][118];
+
          default :
             return '';
       }
