@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: planning.class.php 17244 2012-01-27 10:38:40Z moyo $
+ * @version $Id: planning.class.php 18847 2012-07-05 11:02:04Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -98,6 +98,13 @@ class Planning {
                                       'who_group' => 0,
                                       'begin'     => $begin,
                                       'end'       => $end));
+         if (isPluginItemType($itemtype)) {
+            if (isset($data['items'])) {
+               $data = $data['items'];
+            } else {
+               $data = array();
+            }
+         }
          if (count($data) && method_exists($itemtype,'getAlreadyPlannedInformation')) {
             foreach ($data as $key => $val) {
                if (!isset($except[$itemtype])
@@ -263,7 +270,9 @@ class Planning {
              title=\"".$LANG['buttons'][11]."\"></a>";
       echo "</td>";
       echo "</tr>";
-      echo "</table></form></div>\n";
+      echo "</table>";
+      Html::closeForm();
+      echo "</div>\n";
    }
 
 
@@ -317,7 +326,9 @@ class Planning {
       echo "</td>\n";
 
       echo "</tr>";
-      echo "</table></form></div>\n";
+      echo "</table>";
+      Html::closeForm();
+      echo "</div>\n";
 
 
             // ---------------Tracking
@@ -972,8 +983,8 @@ class Planning {
 
             if (isset($val["tickets_id"])) {
                $vevent->setProperty("summary",
-                                    $LANG['planning'][8]." # ".$val["tickets_id"]." ".
-                                       $LANG['document'][14]." # ".$val["device"]);
+                                    $LANG['planning'][8]." #".$val["tickets_id"]." ".
+                                    $val["name"]);
             } else if (isset($val["name"])) {
                $vevent->setProperty( "summary", $val["name"] );
             }
