@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: printer.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: printer.class.php 18803 2012-07-03 08:50:05Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -83,6 +83,7 @@ class Printer  extends CommonDBTM {
       $this->addStandardTab('Contract_Item', $ong, $options);
       $this->addStandardTab('Document', $ong, $options);
       $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Item_Problem', $ong, $options);
       $this->addStandardTab('Link', $ong, $options);
       $this->addStandardTab('Note', $ong, $options);
       $this->addStandardTab('Reservation', $ong, $options);
@@ -267,6 +268,21 @@ class Printer  extends CommonDBTM {
                                    'items_id'     => $this->fields['id']));
             }
          }
+         // Add connected devices
+         $query = "SELECT *
+                   FROM `glpi_computers_items`
+                   WHERE `itemtype` = '".$this->getType()."'
+                     AND `items_id` = '".$this->input["_oldID"]."';";
+         $result = $DB->query($query);
+
+         if ($DB->numrows($result)>0) {
+            $conn = new Computer_Item();
+            while ($data=$DB->fetch_array($result)) {
+               $conn->add(array('computers_id' => $data["computers_id"],
+                                'itemtype'     => $data["itemtype"],
+                                'items_id'     => $this->fields['id']));
+            }
+         }          
       }
    }
 
