@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: profile.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -184,6 +184,12 @@ class Profile extends CommonDBTM {
       // PROFILES and UNIQUE_PROFILE in RuleMailcollector
       Rule::cleanForItemCriteria($this, 'PROFILES');
       Rule::cleanForItemCriteria($this, 'UNIQUE_PROFILE');
+
+      $gki = new KnowbaseItem_Profile();
+      $gki->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+
+      $gr = new Profile_Reminder();
+      $gr->cleanDBonItemDelete($this->getType(), $this->fields['id']);
    }
 
 
@@ -604,7 +610,8 @@ class Profile extends CommonDBTM {
          echo "<input type='hidden' name='id' value=$ID>";
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       } else {
          echo "</table>\n";
       }
@@ -720,6 +727,9 @@ class Profile extends CommonDBTM {
       echo "<td>".$LANG['title'][5]."&nbsp;:</td><td>";
       self::dropdownNoneReadWrite("knowbase", $this->fields["knowbase"], 1, 1, 1);
       echo "</td>";
+      echo "<td>".$LANG['setup'][237]." - ".$LANG['title'][5]."&nbsp;:</td><td>";
+      Dropdown::showYesNo("knowbase_admin", $this->fields["knowbase_admin"]);
+      echo "</td>";
       echo "<td>".$LANG['profiles'][23]."&nbsp;:</td><td colspan='3'>";
       self::dropdownNoneReadWrite("reservation_central", $this->fields["reservation_central"],
                                   1, 1, 1);
@@ -748,7 +758,8 @@ class Profile extends CommonDBTM {
          echo "<input type='hidden' name='id' value=$ID>";
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       } else {
          echo "</table>\n";
       }
@@ -984,7 +995,8 @@ class Profile extends CommonDBTM {
          echo "<input type='hidden' name='id' value=$ID>";
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       } else {
          echo "</table>\n";
       }
@@ -1103,7 +1115,8 @@ class Profile extends CommonDBTM {
          echo "<input type='hidden' name='id' value=$ID>";
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       } else {
          echo "</table>\n";
       }
@@ -1281,7 +1294,8 @@ class Profile extends CommonDBTM {
          echo "<input type='hidden' name='id' value=$ID>";
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][7]."\" class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>\n";
+         echo "</table>\n";
+         Html::closeForm();
       } else {
          echo "</table>\n";
       }
