@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: profile_user.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: profile_user.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -198,7 +198,8 @@ class Profile_User extends CommonDBTM {
          Html::openArrowMassives("entityuser_form$rand",true);
          Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
       }
-      echo "</form></div>";
+      Html::closeForm();
+      echo "</div>";
    }
 
 
@@ -341,7 +342,7 @@ class Profile_User extends CommonDBTM {
       if ($canedit) {
          Html::openArrowMassives("entityuser_form$rand", true);
          Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
-         echo "</form>";
+         Html::closeForm();
       }
       echo "</div>";
 
@@ -420,7 +421,9 @@ class Profile_User extends CommonDBTM {
                               $LANG['buttons'][20]."' class='submit'>&nbsp;";
                         Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
                      }
-                     echo "</div></form></td></tr>\n";
+                     echo "</div>";
+                     Html::closeForm();
+                     echo "</td></tr>\n";
                   }
 
                   // New entity
@@ -502,7 +505,9 @@ class Profile_User extends CommonDBTM {
                                $LANG['buttons'][20]."' class='submit'>&nbsp;";
                   Html::closeArrowMassives(array('delete' => $LANG['buttons'][6]));
                }
-               echo "</div></form></td></tr>\n";
+               echo "</div>";
+               Html::closeForm();
+               echo "</td></tr>\n";
             }
 
          } else {
@@ -516,12 +521,13 @@ class Profile_User extends CommonDBTM {
    /**
     * Get entities for which a user have a right
     *
-    * @param $user_ID user ID
-    * @param $is_recursive check also using recursive rights
+    * @param $user_ID         user ID
+    * @param $is_recursive    check also using recursive rights
+    * @param $default_first   user default entity first
     *
     * @return array of entities ID
    **/
-   static function getUserEntities($user_ID, $is_recursive=true) {
+   static function getUserEntities($user_ID, $is_recursive=true, $default_first=false) {
       global $DB;
 
       $query = "SELECT DISTINCT `entities_id`, `is_recursive`
@@ -541,6 +547,17 @@ class Profile_User extends CommonDBTM {
             }
          }
 
+         // Set default user entity at the begin
+         if ($default_first) {
+            $user = new User();
+            if ($user->getFromDB($user_ID)) {
+               $ent = $user->getField('entities_id');
+               if (in_array($ent, $entities)) {
+                  array_unshift($entities, $ent);
+               }
+            }
+         }
+
          return array_unique($entities);
       }
 
