@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: relation.constant.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: relation.constant.php 17303 2012-01-31 12:32:34Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -62,30 +62,40 @@ $RELATION = array("glpi_authldaps"
                   "glpi_cartridgeitemtypes"
                         => array('glpi_cartridgeitems' => 'cartridgeitemtypes_id'),
 
+//                   "glpi_changes"
+//                         => array('glpi_changes_groups'   => 'changes_id',
+//                                  'glpi_changes_items'    => 'changes_id',
+//                                  'glpi_changes_problems' => 'changes_id',
+//                                  'glpi_changes_tickets'  => 'changes_id',
+//                                  'glpi_changes_users'    => 'changes_id',
+//                                  'glpi_changetasks'      => 'changes_id'),
+// 
+//                   "glpi_changetasks"
+//                         => array('glpi_changetasks'   => 'changetasks_id'),
+
                   "glpi_computermodels"
                         => array('glpi_computers' => 'computermodels_id'),
 
                   "glpi_computers"
-                        => array(
-                                 'glpi_computers_devicecases'         => 'computers_id',
-                                 'glpi_computers_devicecontrols'      => 'computers_id',
-                                 'glpi_computers_devicedrives'        => 'computers_id',
-                                 'glpi_computers_devicegraphiccards'  => 'computers_id',
-                                 'glpi_computers_deviceharddrives'    => 'computers_id',
-                                 'glpi_computers_devicememories'      => 'computers_id',
-                                 'glpi_computers_devicemotherboards'  => 'computers_id',
-                                 'glpi_computers_devicenetworkcards'  => 'computers_id',
-                                 'glpi_computers_devicepcis'          => 'computers_id',
-                                 'glpi_computers_devicepowersupplies' => 'computers_id',
-                                 'glpi_computers_deviceprocessors'    => 'computers_id',
-                                 'glpi_computers_devicesoundcards'    => 'computers_id',
-                                 'glpi_computers_items'               => 'computers_id',
-                                 'glpi_computers_softwarelicenses'    => 'computers_id',
-                                 'glpi_computers_softwareversions'    => 'computers_id',
-                                 'glpi_computerdisks'                 => 'computers_id',
-                                 'glpi_computervirtualmachines'       => 'computers_id',
-                                 'glpi_ocslinks'                      => 'computers_id',
-                                 'glpi_registrykeys'                  => 'computers_id'),
+                        => array('_glpi_computers_devicecases'         => 'computers_id',
+                                 '_glpi_computers_devicecontrols'      => 'computers_id',
+                                 '_glpi_computers_devicedrives'        => 'computers_id',
+                                 '_glpi_computers_devicegraphiccards'  => 'computers_id',
+                                 '_glpi_computers_deviceharddrives'    => 'computers_id',
+                                 '_glpi_computers_devicememories'      => 'computers_id',
+                                 '_glpi_computers_devicemotherboards'  => 'computers_id',
+                                 '_glpi_computers_devicenetworkcards'  => 'computers_id',
+                                 '_glpi_computers_devicepcis'          => 'computers_id',
+                                 '_glpi_computers_devicepowersupplies' => 'computers_id',
+                                 '_glpi_computers_deviceprocessors'    => 'computers_id',
+                                 '_glpi_computers_devicesoundcards'    => 'computers_id',
+                                 'glpi_computers_items'                => 'computers_id',
+                                 'glpi_computers_softwarelicenses'     => 'computers_id',
+                                 'glpi_computers_softwareversions'     => 'computers_id',
+                                 'glpi_computerdisks'                  => 'computers_id',
+                                 'glpi_computervirtualmachines'        => 'computers_id',
+                                 'glpi_ocslinks'                       => 'computers_id',
+                                 'glpi_registrykeys'                   => 'computers_id'),
 
                   "glpi_computertypes"
                         => array('glpi_computers' => 'computertypes_id'),
@@ -169,6 +179,7 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_calendars'               => 'entities_id',
                                  'glpi_calendarsegments'        => 'entities_id',
                                  'glpi_cartridgeitems'          => 'entities_id',
+//                                  'glpi_changes'                 => 'entities_id',
                                  'glpi_computers'               => 'entities_id',
                                  'glpi_computervirtualmachines' => 'entities_id',
                                  'glpi_consumableitems'         => 'entities_id',
@@ -176,12 +187,17 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_contracts'               => 'entities_id',
                                  'glpi_documents'               => 'entities_id',
                                  'glpi_entities'                => 'entities_id',
-                                 '_glpi_entitydatas'            => 'entities_id',
+                                 '_glpi_entitydatas'            => array('entities_id',
+                                                                     'entities_id_software'),
+                                 'glpi_entities_reminders'      => 'entities_id',
+                                 'glpi_entities_knowbaseitems'  => 'entities_id',
                                  'glpi_fieldblacklists'         => 'entities_id',
                                  'glpi_fieldunicities'          => 'entities_id',
                                  'glpi_groups'                  => 'entities_id',
+                                 'glpi_groups_knowbaseitems'    => 'entities_id',
                                  'glpi_holidays'                => 'entities_id',
-                                 'glpi_knowbaseitems'           => 'entities_id',
+                                 'glpi_knowbaseitemcategories'  => 'entities_id',
+                                 'glpi_knowbaseitems_profiles'  => 'entities_id',
                                  'glpi_links'                   => 'entities_id',
                                  'glpi_locations'               => 'entities_id',
                                  'glpi_monitors'                => 'entities_id',
@@ -192,32 +208,48 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_peripherals'             => 'entities_id',
                                  'glpi_phones'                  => 'entities_id',
                                  'glpi_printers'                => 'entities_id',
+                                 'glpi_problems'                => 'entities_id',
+                                 'glpi_profiles_reminders'      => 'entities_id',
                                  'glpi_profiles_users'          => 'entities_id',
-                                 'glpi_reminders'               => 'entities_id',
+                                 '_glpi_reservationitems'         => 'entities_id',
                                  'glpi_rules'                   => 'entities_id',
+                                 '_glpi_slalevels'               => 'entities_id',
                                  'glpi_slas'                    => 'entities_id',
                                  'glpi_softwarelicenses'        => 'entities_id',
                                  'glpi_softwares'               => 'entities_id',
+                                 'glpi_ticketrecurrents'         => 'entities_id',
+                                 'glpi_solutiontemplates'       => 'entities_id',
+                                 'glpi_solutiontypes'           => 'entities_id',
                                  'glpi_suppliers'               => 'entities_id',
                                  'glpi_taskcategories'          => 'entities_id',
-                                 'glpi_ticketcategories'        => 'entities_id',
+                                 'glpi_itilcategories'          => 'entities_id',
+                                 'glpi_tickettemplates'          => 'entities_id',
+                                 '_glpi_tickettemplatehiddenfields' => 'entities_id',
+                                 '_glpi_tickettemplatemandatoryfields' => 'entities_id',
+                                 '_glpi_tickettemplatepredefinedfields' => 'entities_id',
                                  'glpi_tickets'                 => 'entities_id',
-                                 'glpi_ticketsolutiontemplates' => 'entities_id',
+                                 '_glpi_ticketvalidations'      => 'entities_id',
                                  'glpi_users'                   => 'entities_id'),
 
                   "glpi_filesystems"
                         => array('glpi_computerdisks' => 'filesystems_id'),
 
                   "glpi_groups"
-                        => array('glpi_computers'         => 'groups_id',
+                        => array('glpi_computers'         => array('groups_id_tech', 'groups_id'),
+//                                  'glpi_changes_groups'    => 'groups_id',
+                                 'glpi_groups_knowbaseitems'  => 'groups_id',
+                                 'glpi_groups_problems'   => 'groups_id',
+                                 'glpi_groups_reminders'  => 'groups_id',
                                  'glpi_groups_tickets'    => 'groups_id',
                                  'glpi_groups_users'      => 'groups_id',
-                                 'glpi_monitors'          => 'groups_id',
-                                 'glpi_networkequipments' => 'groups_id',
-                                 'glpi_peripherals'       => 'groups_id',
-                                 'glpi_phones'            => 'groups_id',
-                                 'glpi_printers'          => 'groups_id',
-                                 'glpi_softwares'         => 'groups_id'),
+                                 'glpi_monitors'          => array('groups_id_tech', 'groups_id'),
+                                 'glpi_networkequipments' => array('groups_id_tech', 'groups_id'),
+                                 'glpi_peripherals'       => array('groups_id_tech', 'groups_id'),
+                                 'glpi_phones'            => array('groups_id_tech', 'groups_id'),
+                                 'glpi_printers'          => array('groups_id_tech', 'groups_id'),
+                                 'glpi_softwares'         => array('groups_id_tech', 'groups_id'),
+                                 'glpi_cartridgeitems'    => 'groups_id_tech',
+                                 'glpi_consumableitems'   => 'groups_id_tech'),
 
                   "glpi_holidays"
                         => array('glpi_calendars_holidays' => 'holidays_id',),
@@ -229,8 +261,13 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_devicecontrols'     => 'interfacetypes_id'),
 
                   "glpi_knowbaseitemcategories"
-                        => array('glpi_knowbaseitemcategories' =>'knowbaseitemcategories_id',
-                                 'glpi_knowbaseitems' =>'knowbaseitemcategories_id'),
+                        => array('glpi_itilcategories'         => 'knowbaseitemcategories_id',
+                                 'glpi_knowbaseitemcategories' => 'knowbaseitemcategories_id',
+                                 'glpi_knowbaseitems'          => 'knowbaseitemcategories_id'),
+
+                  "glpi_knowbaseitems"
+                        => array('glpi_entities_knowbaseitems' => 'knowbaseitems_id',
+                                 'glpi_knowbaseitems_profiles' => 'knowbaseitems_id',),
 
                   "glpi_links"
                         => array('glpi_links_itemtypes' => 'links_id'),
@@ -341,9 +378,25 @@ $RELATION = array("glpi_authldaps"
                   "glpi_printertypes"
                         => array('glpi_printers' => 'printertypes_id'),
 
+                  "glpi_problems"
+                        => array(/*'glpi_changes_problems' => 'problems_id',*/
+                                 'glpi_groups_problems'  => 'problems_id',
+                                 'glpi_items_problems'   => 'problems_id',
+                                 'glpi_problems_tickets' => 'problems_id',
+                                 'glpi_problems_users'   => 'problems_id',
+                                 'glpi_problemtasks'     => 'problems_id'),
+
                   "glpi_profiles"
-                        => array('glpi_users'          => 'profiles_id',
-                                 'glpi_profiles_users' => 'profiles_id'),
+                        => array('glpi_knowbaseitems_profiles'  => 'profiles_id',
+                                 'glpi_profiles_reminders' => 'profiles_id',
+                                 'glpi_profiles_users'     => 'profiles_id',
+                                 'glpi_users'              => 'profiles_id'),
+
+                  "glpi_reminders"
+                        => array('glpi_entities_reminders' => 'reminders_id',
+                                 'glpi_groups_reminders'   => 'reminders_id',
+                                 'glpi_profiles_reminders' => 'reminders_id',
+                                 'glpi_reminders_users'    => 'reminders_id',),
 
                   "glpi_requesttypes"
                         => array('glpi_tickets' => 'requesttypes_id'),
@@ -390,7 +443,8 @@ $RELATION = array("glpi_authldaps"
                         => array('glpi_softwarelicenses' =>'softwarelicensetypes_id'),
 
                   "glpi_softwareversions"
-                        => array('glpi_computers_softwareversions' => 'softwareversions_id',
+                        => array('glpi_computers_softwareversions'
+                                                         => 'softwareversions_id',
                                  'glpi_softwarelicenses' => array('softwareversions_id_buy',
                                                                   'softwareversions_id_use')),
 
@@ -401,6 +455,13 @@ $RELATION = array("glpi_authldaps"
                         => array('glpi_softwarelicenses' => 'softwares_id',
                                  'glpi_softwareversions' => 'softwares_id',
                                  'glpi_softwares'        => 'softwares_id'),
+
+                  "glpi_solutiontypes"
+                        => array(/*'glpi_changes'           => 'solutiontypes_id',*/
+                                 'glpi_problems'          => 'solutiontypes_id',
+                                 'glpi_tickets'           => 'solutiontypes_id',
+                                 'glpi_solutiontemplates' => 'solutiontypes_id'),
+
                   "glpi_states"
                         => array('glpi_computers'         => 'states_id',
                                  'glpi_monitors'          => 'states_id',
@@ -408,27 +469,48 @@ $RELATION = array("glpi_authldaps"
                                  'glpi_peripherals'       => 'states_id',
                                  'glpi_phones'            => 'states_id',
                                  'glpi_printers'          => 'states_id',
-                                 'glpi_softwareversions'  => 'states_id'),
+                                 'glpi_softwareversions'  => 'states_id',
+                                 'glpi_states'            => 'states_id'),
 
                   "glpi_suppliers"
-                        => array('glpi_contacts_suppliers'  => 'suppliers_id',
+                        => array(/*'glpi_changes'             => 'suppliers_id_assign',*/
+                                 'glpi_contacts_suppliers'  => 'suppliers_id',
                                  'glpi_contracts_suppliers' => 'suppliers_id',
                                  'glpi_infocoms'            => 'suppliers_id',
+                                 'glpi_problems'            => 'suppliers_id_assign',
                                  'glpi_tickets'             => 'suppliers_id_assign'),
 
                   "glpi_suppliertypes"
                         => array('glpi_suppliers' => 'suppliertypes_id'),
 
                   "glpi_taskcategories"
-                        => array("glpi_taskcategories" => "taskcategories_id",
-                                 "glpi_tickettasks"    => "taskcategories_id",),
+                        => array('glpi_changetasks'    => 'taskcategories_id',
+                                 'glpi_problemtasks'   => 'taskcategories_id',
+                                 'glpi_taskcategories' => 'taskcategories_id',
+                                 'glpi_tickettasks'    => 'taskcategories_id'),
 
-                  "glpi_ticketcategories"
-                        => array('glpi_tickets' => 'ticketcategories_id'),
+                  "glpi_itilcategories"
+                        => array(/*'glpi_changes'         => 'itilcategories_id',*/
+                                 'glpi_itilcategories'  => 'itilcategories_id',
+                                 'glpi_tickets'         => 'itilcategories_id',
+                                 'glpi_problems'        => 'itilcategories_id'),
+
+                  "glpi_tickettemplates"
+                        => array('glpi_itilcategories'      => array('tickettemplates_id_incident',
+                                                                     'tickettemplates_id_demand'),
+                                 'glpi_ticketrecurrents'    => 'tickettemplates_id',
+                                 'glpi_tickettemplatehiddenfields'
+                                                            => 'tickettemplates_id',
+                                 'glpi_tickettemplatepredefinedfields'
+                                                            => 'tickettemplates_id',
+                                 'glpi_tickettemplatemandatoryfields'
+                                                            => 'tickettemplates_id'),
 
                   "glpi_tickets"
                         => array('_glpi_documents'          => 'tickets_id',
+//                                  'glpi_changes_tickets'     => 'tickets_id',
                                  'glpi_groups_tickets'      => 'tickets_id',
+                                 'glpi_problems_tickets'    => 'tickets_id',
                                  'glpi_slalevels_tickets'   => 'tickets_id',
                                  'glpi_ticketfollowups'     => 'tickets_id',
                                  'glpi_ticketsatisfactions' => 'tickets_id',
@@ -438,12 +520,11 @@ $RELATION = array("glpi_authldaps"
                                                                      'tickets_id_2'),
                                  'glpi_tickets_users'       => 'tickets_id'),
 
-                  "glpi_ticketsolutiontypes"
-                        => array('glpi_tickets'                 => 'ticketsolutiontypes_id',
-                                 'glpi_ticketsolutiontemplates' => 'ticketsolutiontypes_id'),
-
-                  "glpi_tickettasks"
-                        => array('glpi_ticketplannings' => 'tickettasks_id'),
+                  "glpi_solutiontypes"
+                           => array(/*'glpi_changes'             => 'solutiontypes_id',*/
+                                    'glpi_tickets'             => 'solutiontypes_id',
+                                    'glpi_solutiontemplates'   => 'solutiontypes_id',
+                                    'glpi_problems'            => 'solutiontypes_id'),
 
                   "glpi_transfers"
                         => array('glpi_configs' => 'transfers_id_auto'),
@@ -453,30 +534,38 @@ $RELATION = array("glpi_authldaps"
 
                   "glpi_users"
                         => array('glpi_bookmarks'           => 'users_id',
+                                 'glpi_bookmarks_users'     => 'users_id',
                                  'glpi_cartridgeitems'      => 'users_id_tech',
+//                                  'glpi_changes'             => array('users_id_recipient',
+//                                                                      'users_id_lastupdater'),
+//                                  'glpi_changes_users'       => 'users_id',
+//                                  'glpi_changetasks'         => array('users_id', 'users_id_tech'),
                                  'glpi_computers'           => array('users_id_tech', 'users_id'),
-                                 'glpi_consumables'         => 'users_id',
                                  'glpi_consumableitems'     => 'users_id_tech',
                                  'glpi_displaypreferences'  => 'users_id',
-                                 'glpi_bookmarks_users'     => 'users_id',
                                  'glpi_documents'           => 'users_id',
-                                 'glpi_ticketfollowups'     => 'users_id',
-                                 'glpi_groups'              => 'users_id',
+                                 'glpi_groups_users'        => 'users_id',
                                  'glpi_knowbaseitems'       => 'users_id',
                                  'glpi_monitors'            => array('users_id_tech', 'users_id'),
                                  'glpi_networkequipments'   => array('users_id_tech', 'users_id'),
                                  'glpi_peripherals'         => array('users_id_tech', 'users_id'),
                                  'glpi_phones'              => array('users_id_tech', 'users_id'),
                                  'glpi_printers'            => array('users_id_tech', 'users_id'),
+                                 'glpi_problems'            => array('users_id_recipient',
+                                                                     'users_id_lastupdater'),
+                                 'glpi_problems_users'      => 'users_id',
+                                 'glpi_problemtasks'        => array('users_id', 'users_id_tech'),
+                                 'glpi_profiles_users'      => 'users_id',
                                  'glpi_reminders'           => 'users_id',
+                                 'glpi_reminders_users'     => 'users_id',
                                  'glpi_reservations'        => 'users_id',
                                  'glpi_softwares'           => array('users_id_tech', 'users_id'),
+                                 'glpi_ticketfollowups'     => 'users_id',
                                  'glpi_tickets'             => array('users_id_recipient',
                                                                      'users_id_lastupdater'),
                                  'glpi_tickets_users'       => 'users_id',
-                                 'glpi_ticketplannings'     => 'users_id',
-                                 'glpi_groups_users'        => 'users_id',
-                                 'glpi_profiles_users'      => 'users_id'),
+                                 'glpi_tickettasks'         => array('users_id', 'users_id_tech'),
+                                 'glpi_useremails'          => 'users_id'),
 
                   "glpi_usertitles"
                         => array('glpi_users' => 'usertitles_id'),
@@ -493,7 +582,7 @@ $RELATION = array("glpi_authldaps"
                   "glpi_virtualmachinetypes"
                         => array('glpi_computervirtualmachines' => 'virtualmachinetypes_id'),
 
-                // link from devices tables (computers, software, ...)
+                // link from devices tables (computers, software, ...) : only used for unrecurs check
                 "_virtual_device" => array('glpi_contracts_items' => array('items_id', 'itemtype'),
                                            'glpi_documents_items' => array('items_id', 'itemtype'),
                                            'glpi_infocoms'        => array('items_id', 'itemtype')),
