@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reminder.class.php 17719 2012-03-06 08:57:17Z moyo $
+ * @version $Id: reminder.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -107,6 +107,17 @@ class Reminder extends CommonDBTM {
       $this->profiles = Profile_Reminder::getProfiles($this->fields['id']);
    }
 
+   function cleanDBonPurge() {
+
+      $class = new Reminder_User();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new Entity_Reminder();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new Group_Reminder();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+      $class = new Profile_Reminder();
+      $class->cleanDBonItemDelete($this->getType(), $this->fields['id']);
+   }
 
    /**
     * @since version 0.83
@@ -215,10 +226,12 @@ class Reminder extends CommonDBTM {
    **/
    static function addVisibilityJoins($forceall=false) {
 
-      $join = '';
+      if (!Session::haveRight('reminder_public', 'r')) {
+         return '';
+      }
 
       // Users
-      $join .= " LEFT JOIN `glpi_reminders_users`
+      $join = " LEFT JOIN `glpi_reminders_users`
                      ON (`glpi_reminders_users`.`reminders_id` = `glpi_reminders`.`id`) ";
 
       // Groups
@@ -254,7 +267,11 @@ class Reminder extends CommonDBTM {
    **/
    static function addVisibilityRestrict() {
 
-      $restrict = "(`glpi_reminders`.`users_id` = '".Session::getLoginUserID()."' ";
+      $restrict = "`glpi_reminders`.`users_id` = '".Session::getLoginUserID()."' ";
+
+      if (!Session::haveRight('reminder_public', 'r')) {
+         return $restrict;
+      }
 
       // Users
       $restrict .= " OR `glpi_reminders_users`.`users_id` = '".Session::getLoginUserID()."' ";
@@ -283,8 +300,7 @@ class Reminder extends CommonDBTM {
          $restrict .= getEntitiesRestrictRequest("OR","glpi_entities_reminders", '', '', true, true);
       }
 
-      $restrict .= ") ";
-      return $restrict;
+      return '('.$restrict.')';
    }
 
 
@@ -667,7 +683,7 @@ class Reminder extends CommonDBTM {
          echo "<textarea cols='115' rows='15' name='text'>".$this->fields["text"]."</textarea>";
       } else {
          echo "<div  id='kbanswer'>";
-         echo Toolbox::unclean_cross_side_scripting_deep($this->fields["text"]);
+         echo Toolbox::unclean_html_cross_side_scripting_deep($this->fields["text"]);
          echo "</div>";
       }
 
@@ -866,11 +882,12 @@ class Reminder extends CommonDBTM {
 
       $users_id = Session::getLoginUserID();
       $today    = date('Y-m-d');
+      $now      = date('Y-m-d H:i:s');
 
       $restrict_visibility = " AND (`glpi_reminders`.`begin_view_date` IS NULL
-                                    OR `glpi_reminders`.`begin_view_date` < '$today')
+                                    OR `glpi_reminders`.`begin_view_date` < '$now')
                               AND (`glpi_reminders`.`end_view_date` IS NULL
-                                   OR `glpi_reminders`.`end_view_date` > '$today') ";
+                                   OR `glpi_reminders`.`end_view_date` > '$now') ";
 
       if ($personal) {
 
@@ -944,7 +961,7 @@ class Reminder extends CommonDBTM {
                   href='".$CFG_GLPI["root_doc"]."/front/reminder.form.php?id=".$data["id"]."'>".
                   $data["name"]."</a>&nbsp;";
 
-            Html::showToolTip(Toolbox::unclean_cross_side_scripting_deep($data["text"]),
+            Html::showToolTip(Toolbox::unclean_html_cross_side_scripting_deep($data["text"]),
                               array('applyto' => "content_reminder_".$data["id"].$rand));
 
             if ($data["is_planned"]) {
@@ -1137,10 +1154,7 @@ class Reminder extends CommonDBTM {
       echo "<tr class='tab_bg_1'><th colspan='4'>".$LANG['common'][116]."</tr>";
       echo "<tr><td class='tab_bg_2' width='100px'>";
 
-      $types = array( 'Group', 'Profile', 'User');
-      if (Session::isMultiEntitiesMode()) {
-         $types[] = 'Entity';
-      }
+      $types = array( 'Group', 'Profile', 'User', 'Entity');
 
       $addrand = Dropdown::dropdownTypes('_type', '', $types);
       $params  = array('type'  => '__VALUE__',
@@ -1288,9 +1302,9 @@ class Reminder extends CommonDBTM {
          $confirm= array();
          if ($this->fields['users_id'] != Session::getLoginUserID()) {
             $confirm = array('deletevisibility' => $LANG['common'][120]);
-         }         
+         }
          Html::closeArrowMassives(array('deletevisibility' => $LANG['buttons'][6]), $confirm);
-         echo "</form>";
+         Html::closeForm();
       }
 
       echo "</div>";
