@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: requesttype.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: requesttype.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -40,9 +40,12 @@ if (!defined('GLPI_ROOT')) {
 class RequestType extends CommonDropdown {
 
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['dropdown'][6];
+      }
       return $LANG['job'][44];
    }
 
@@ -111,7 +114,7 @@ class RequestType extends CommonDropdown {
             $DB->query($query);
 
          } else {
-            addMessageAfterRedirect($LANG['setup'][313], true);
+            Session::addMessageAfterRedirect($LANG['setup'][313], true);
          }
       }
 
@@ -124,7 +127,7 @@ class RequestType extends CommonDropdown {
             $DB->query($query);
 
          } else {
-            addMessageAfterRedirect($LANG['setup'][313], true);
+            Session::addMessageAfterRedirect($LANG['setup'][313], true);
          }
       }
    }
@@ -136,7 +139,7 @@ class RequestType extends CommonDropdown {
     * @param $source string
     *
     * @return requesttypes_id
-    */
+   **/
    static function getDefault($source) {
       global $DB;
 
@@ -152,7 +155,6 @@ class RequestType extends CommonDropdown {
 
 
    function cleanDBonPurge() {
-
       Rule::cleanForItemCriteria($this);
    }
 }
