@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: reservationitem.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: reservationitem.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -115,6 +115,7 @@ class ReservationItem extends CommonDBTM {
       $tab[1]['name']          = $LANG['common'][16];
       $tab[1]['datatype']      = 'itemlink';
       $tab[1]['massiveaction'] = false;
+      $tab[1]['addobjetparams'] = array('forcetab' => 'Reservation$1');
 
       $tab[2]['table']         = 'reservation_types';
       $tab[2]['field']         = 'id';
@@ -212,7 +213,9 @@ class ReservationItem extends CommonDBTM {
          echo "<input type='submit' name='add' value=\"".$LANG['reservation'][7]."\" class='submit'>";
          echo "</td>";
       }
-      echo "</tr></table></form></div>";
+      echo "</tr></table>";
+      Html::closeForm();
+      echo "</div>";
    }
 
 
@@ -252,7 +255,9 @@ class ReservationItem extends CommonDBTM {
          echo "<input type='submit' name='update' value=\"".$LANG['buttons'][14]."\" class='submit'>";
          echo "</td></tr>\n";
 
-         echo "</table></form></div>";
+         echo "</table>";
+         Html::closeForm();
+         echo "</div>";
          return true;
 
       } else {
@@ -333,7 +338,8 @@ class ReservationItem extends CommonDBTM {
       }
       echo "</table>\n";
       echo "<input type='hidden' name='id' value=''>";
-      echo "</form></div>\n";
+      Html::closeForm();
+      echo "</div>\n";
    }
 
 
