@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rule.class.php 17964 2012-03-21 09:46:22Z yllen $
+ * @version $Id: rule.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -86,6 +86,8 @@ class Rule extends CommonDBTM {
    const PATTERN_DOES_NOT_EXISTS = 9;
    const PATTERN_FIND            = 10;
    const PATTERN_UNDER           = 11;
+   const PATTERN_NOT_UNDER       = 12;
+   const PATTERN_IS_EMPTY        = 30;
 
    const AND_MATCHING = "AND";
    const OR_MATCHING  = "OR";
@@ -418,7 +420,7 @@ class Rule extends CommonDBTM {
          echo "<form name='actionsaddform' method='post' action='".
                 Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
          $this->addActionForm($rules_id);
-         echo "</form>";
+         Html::closeForm();
       }
 
       if ($canedit) {
@@ -452,7 +454,7 @@ class Rule extends CommonDBTM {
          Html::closeArrowMassives(array('delete_action' => $LANG['buttons'][6]));
       }
       if ($canedit) {
-         echo "</form>";
+         Html::closeForm();
       }
       echo "</div>";
    }
@@ -549,7 +551,7 @@ class Rule extends CommonDBTM {
          echo "<form name='criteriasaddform' method='post' action='".
                 Toolbox::getItemTypeFormURL(get_class($this))."'>\n";
          $this->addCriteriaForm($rules_id);
-         echo "</form>";
+         Html::closeForm();
       }
 
       echo "<div class='spaced'>";
@@ -580,7 +582,8 @@ class Rule extends CommonDBTM {
          echo "<input type='hidden' name='".$this->rules_id_field."' value='$rules_id'>";
          Html::closeArrowMassives(array('delete_criteria' => $LANG['buttons'][6]));
       }
-      echo "</form></div>\n";
+      Html::closeForm();
+      echo "</div>\n";
    }
 
 
@@ -1313,7 +1316,8 @@ class Rule extends CommonDBTM {
 
       } else if (in_array($condition, array(self::PATTERN_IS,
                                             self::PATTERN_IS_NOT,
-                                            self::PATTERN_UNDER))) {
+                                            self::PATTERN_UNDER,
+                                            self::PATTERN_NOT_UNDER))) {
          $crit = $this->getCriteria($ID);
 
          if (isset($crit['type'])) {
@@ -1402,7 +1406,8 @@ class Rule extends CommonDBTM {
       if (isset($crit['type'])
           && ($test || in_array($condition, array(self::PATTERN_IS,
                                                   self::PATTERN_IS_NOT,
-                                                  self::PATTERN_UNDER)))) {
+                                                  self::PATTERN_UNDER,
+                                                  self::PATTERN_NOT_UNDER)))) {
 
          switch ($crit['type']) {
             case "yesonly" :
@@ -1416,8 +1421,13 @@ class Rule extends CommonDBTM {
                break;
 
             case "dropdown" :
-               Dropdown::show(getItemTypeForTable($crit['table']), array('name'  => $name,
-                                                                         'value' => $value));
+               $param = array('name'  => $name,
+                              'value' => $value);
+               if (isset($crit['condition'])) {
+                  $param['condition'] = $crit['condition'];
+               }
+
+               Dropdown::show(getItemTypeForTable($crit['table']), $param);
                $display = true;
                break;
 
@@ -1543,7 +1553,8 @@ class Rule extends CommonDBTM {
 
       if (!in_array($condition, array(self::PATTERN_IS,
                                       self::PATTERN_IS_NOT,
-                                      self::PATTERN_UNDER,))) {
+                                      self::PATTERN_UNDER,
+                                      self::PATTERN_NOT_UNDER))) {
          $crit = $this->getCriteria($ID);
          if (isset($crit['type'])) {
 
@@ -1659,7 +1670,8 @@ class Rule extends CommonDBTM {
          echo "<input type='hidden' name='".$this->rules_id_field."' value='$rules_id'>";
          echo "<input type='hidden' name='sub_type' value='" . $this->getType() . "'>";
          echo "</td></tr>\n";
-         echo "</table></div></form>\n";
+         echo "</table></div>\n";
+         Html::closeForm();
       }
    }
 
@@ -1797,7 +1809,8 @@ class Rule extends CommonDBTM {
       echo "<input type=hidden name='_method' value='AddRule'>";
       echo "<input type='submit' name='execute' value=\"".$LANG['buttons'][8]."\" class='submit'>";
       echo "</td></tr>\n";
-      echo "</table></form>";
+      echo "</table>";
+      Html::closeForm();
    }
 
 
@@ -1866,7 +1879,7 @@ class Rule extends CommonDBTM {
             Html::openArrowMassives($formname, true);
             echo "<input type='hidden' name='action' value='delete'>";
             Html::closeArrowMassives(array('massiveaction' => $LANG['buttons'][6]));
-            echo "</form>";
+            Html::closeForm();
          }
       }
       echo "</div>";
