@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleaction.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: ruleaction.class.php 18528 2012-05-25 08:24:25Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -242,7 +242,12 @@ class RuleAction extends CommonDBChild {
                switch($actions[$options["field"]]['type']) {
                   case "dropdown" :
                      $table = $actions[$options["field"]]['table'];
-                     Dropdown::show(getItemTypeForTable($table), array('name' => "value"));
+                     $param = array('name' => "value");
+                     if (isset($actions[$options["field"]]['condition'])) {
+                        $param['condition'] = $actions[$options["field"]]['condition'];
+                     }
+                     
+                     Dropdown::show(getItemTypeForTable($table), $param);
                      $display = true;
                      break;
 
