@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecached.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: rulecached.class.php 18701 2012-06-23 16:37:01Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -91,16 +91,13 @@ class RuleCached extends Rule {
       $rulecollection = RuleCollection::getClassByType($this->getType());
 
       $query = "SELECT *
-                FROM `".$rulecollection->cache_table."`,
-                     `glpi_rules`
-                WHERE `".$rulecollection->cache_table."`.`rules_id` = `glpi_rules`.`id`
-                      AND `".$rulecollection->cache_table."`.`rules_id` = '".$this->fields["id"]."'
-                ORDER BY `name`";
+                FROM `".$rulecollection->cache_table."`
+                WHERE `".$rulecollection->cache_table."`.`rules_id` = '".$this->fields["id"]."'";
 
       $res_count = $DB->query($query);
       $this->showCacheRuleHeader();
 
-      while ($datas = $DB->fetch_array($res_count)) {
+      while ($datas = $DB->fetch_assoc($res_count)) {
          echo "<tr>";
          $this->showCacheRuleDetail($datas);
          echo "</tr>\n";
