@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulecriteria.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: rulecriteria.class.php 18726 2012-06-26 10:50:02Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -163,10 +163,10 @@ class RuleCriteria extends CommonDBChild {
 
       switch ($condition) {
          case Rule::PATTERN_EXISTS :
-            return ($field != '');
+            return (!empty($field));
 
          case Rule::PATTERN_DOES_NOT_EXISTS :
-            return ($field == '');
+            return (empty($field));
 
          case Rule::PATTERN_IS :
             if (is_array($field)) {
@@ -196,6 +196,14 @@ class RuleCriteria extends CommonDBChild {
             }
             return false;
 
+         case Rule::PATTERN_NOT_UNDER :
+            $table  = getTableNameForForeignKeyField($criteria);
+            $values = getSonsOf($table, $pattern);
+            if (isset($values[$field])) {
+               return false;
+            }
+            return true;
+
          case Rule::PATTERN_END :
             $value = "/".$pattern."$/";
             if (preg_match($value, $field) > 0) {
@@ -260,7 +268,9 @@ class RuleCriteria extends CommonDBChild {
             }
             return false;
 
-          case Rule::PATTERN_FIND :
+         case Rule::PATTERN_IS_EMPTY :
+         case Rule::PATTERN_FIND :
+            // Global criteria will be evaluated later
             return true;
       }
       return false;
@@ -317,9 +327,10 @@ class RuleCriteria extends CommonDBChild {
 
       if (isset($crit['type']) && $crit['type'] == 'dropdown') {
          $crititemtype = getItemtypeForTable($crit['table']);
-         $item         = new $crititemtype();
-         if ($item instanceof CommonTreeDropdown) {
-            $criteria[Rule::PATTERN_UNDER] = $LANG['search'][3];
+         if (($item = getItemForItemtype($crititemtype))
+             && $item instanceof CommonTreeDropdown) {
+            $criteria[Rule::PATTERN_UNDER]     = $LANG['search'][3];
+            $criteria[Rule::PATTERN_NOT_UNDER] = $LANG['search'][7];
          }
       }
 
