@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulemailcollector.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: rulemailcollector.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -54,12 +54,12 @@ class RuleMailCollector extends Rule {
 
 
    function canCreate() {
-      return haveRight('rule_mailcollector', 'w');
+      return Session::haveRight('rule_mailcollector', 'w');
    }
 
 
    function canView() {
-      return haveRight('rule_mailcollector', 'r');
+      return Session::haveRight('rule_mailcollector', 'r');
    }
 
 
@@ -141,7 +141,7 @@ class RuleMailCollector extends Rule {
       $criterias['received']['type']  = 'text';
 
       $criterias['GROUPS']['table']     = 'glpi_groups';
-      $criterias['GROUPS']['field']     = 'name';
+      $criterias['GROUPS']['field']     = 'completename';
       $criterias['GROUPS']['name']      = $LANG['common'][34].' : '.$LANG['common'][35];
       $criterias['GROUPS']['linkfield'] = '';
       $criterias['GROUPS']['type']      = 'dropdown';
@@ -164,7 +164,7 @@ class RuleMailCollector extends Rule {
       $criterias['PROFILES']['id']              = 'profiles';
       $criterias['PROFILES']['allow_condition'] = array(Rule::PATTERN_IS);
 
-      if (isMultiEntitiesMode()) {
+      if (Session::isMultiEntitiesMode()) {
          $criterias['UNIQUE_PROFILE']['field']           = 'name';
          $criterias['UNIQUE_PROFILE']['name']            = $LANG['rulesengine'][147];
          $criterias['UNIQUE_PROFILE']['table']           = 'glpi_profiles';
@@ -257,7 +257,6 @@ class RuleMailCollector extends Rule {
                         if ($profile) {
                            $entities = array();
                            if (isset($params['_users_id_requester'])) { // Not set when testing
-                              // Retrieve only the "top" entities
                               $entities = Profile_User::getEntitiesForProfileByUser($params['_users_id_requester'],
                                                                                     $profile);
                            }
@@ -276,7 +275,7 @@ class RuleMailCollector extends Rule {
 
                                  //Rights on more than one entity : get the user's prefered entity
                                  if (isset($params['_users_id_requester'])) { // Not set when testing
-                                    $user = new User;
+                                    $user = new User();
                                     $user->getFromDB($params['_users_id_requester']);
 
                                     $tmpid = $user->getField('entities_id');
