@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: rulerightcollection.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: rulerightcollection.class.php 18489 2012-05-22 17:47:17Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -104,7 +104,13 @@ class RuleRightCollection extends RuleCollection {
          echo "<tr class='tab_bg_2'>";
          echo "<td colspan='4' class='center'>".$LANG['rulesengine'][112]."</td>";
          foreach ($output["_ldap_rules"]["rules_entities_rights"] as $val) {
-            $this->displayActionByName("entity", $val[0]);
+            if (is_array($val[0])) {
+               foreach($val[0] as $tmp) {
+                  $this->displayActionByName("entity", $tmp[0]);
+               }
+            } else {
+               $this->displayActionByName("entity", $val[0]);
+            }
             if (isset($val[1])) {
                $this->displayActionByName("profile", $val[1]);
             }
