@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ruleticket.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: ruleticket.class.php 18528 2012-05-25 08:24:25Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -240,7 +240,8 @@ class RuleTicket extends Rule {
       $criterias['_groups_id_assign']['field']     = 'completename';
       $criterias['_groups_id_assign']['name']      = $LANG['job'][5]." - ".$LANG['common'][35];
       $criterias['_groups_id_assign']['linkfield'] = '_groups_id_assign';
-      $criterias['_groups_id_assign']['type']      = 'dropdown';
+      $criterias['_groups_id_assign']['type']         = 'dropdown';
+      $criterias['_groups_id_assign']['condition']    = '`is_assign`';
 
       $criterias['suppliers_id_assign']['table']     = 'glpi_suppliers';
       $criterias['suppliers_id_assign']['field']     = 'name';
@@ -327,6 +328,7 @@ class RuleTicket extends Rule {
       $actions['_groups_id_assign']['table'] = 'glpi_groups';
       $actions['_groups_id_assign']['name']  = $LANG['job'][5]." - ".$LANG['common'][35];
       $actions['_groups_id_assign']['type']  = 'dropdown';
+      $actions['_groups_id_assign']['condition']  = '`is_assign`';
 
       $actions['suppliers_id_assign']['table'] = 'glpi_suppliers';
       $actions['suppliers_id_assign']['name']  = $LANG['job'][5]." - ".$LANG['financial'][26];
