@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: session.class.php 17985 2012-03-23 08:50:03Z remi $
+ * @version $Id: session.class.php 18843 2012-07-04 18:52:24Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,7 +39,6 @@ class Session {
    const TRANSLATION_MODE  = 1;
    const DEBUG_MODE        = 2;
 
-
    /**
     * Destroy the current session
     *
@@ -68,7 +67,7 @@ class Session {
 
       if ($auth->auth_succeded) {
          // Restart GLPi session : complete destroy to prevent lost datas
-         $tosave = array('glpi_plugins', 'glpicookietest', 'phpCAS');
+         $tosave = array('glpi_plugins', 'glpicookietest', 'phpCAS', 'glpicsrftokens');
          $save   = array();
          foreach ($tosave as $t) {
             if (isset($_SESSION[$t])) {
@@ -950,5 +949,68 @@ class Session {
       }
       return true;
    }
+
+   /**
+   * Get new CSRF token
+   * @since version 0.83.3
+   * @return      string  new generated token
+   */
+   static public function getNewCSRFToken() {
+      global $CURRENTCSRFTOKEN;
+
+      if (empty($CURRENTCSRFTOKEN)) {
+         $CURRENTCSRFTOKEN = md5(uniqid(rand(), TRUE));
+      }
+
+      if (!isset($_SESSION['glpicsrftokens'])) {
+         $_SESSION['glpicsrftokens'] = array();
+      }
+      $_SESSION['glpicsrftokens'][$CURRENTCSRFTOKEN] = time() + GLPI_CSRF_EXPIRES;
+      return $CURRENTCSRFTOKEN;
+   }
+
+   /**
+   * Clean expires CSRF tokens
+   * @since version 0.83.3
+   * @return      nothing
+   */
+   static public function cleanCSRFTokens() {
+      $now = time();
+      if (isset($_SESSION['glpicsrftokens']) && is_array($_SESSION['glpicsrftokens'])) {
+         if (count($_SESSION['glpicsrftokens'])) {
+            foreach ($_SESSION['glpicsrftokens'] as $token => $expires) {
+               if ($expires < $now) {
+                  unset($_SESSION['glpicsrftokens'][$token]);
+               }
+            }
+            $overflow = count($_SESSION['glpicsrftokens']) - GLPI_CSRF_MAX_TOKENS;
+            if ($overflow > 0) {
+               $_SESSION['glpicsrftokens'] = array_slice($_SESSION['glpicsrftokens'], $overflow + 1, null, true);
+            }
+         }
+      }
+   }
+   /**
+   * Validate that the page has a CSRF token in the POST data
+   * and that the token is legit/not expired.  If the token is valid
+   * it will be removed from the list of valid tokens.
+   *
+   * @param $data array $_POST datas
+   * @return boolean Valid csrf token.
+   */
+   static public function validateCSRF($data) {
+      if (!isset($data['_glpi_csrf_token'])) {
+         Session::cleanCSRFTokens();
+         return false;
+      }
+      $requestToken = $data['_glpi_csrf_token'];
+      if (isset($_SESSION['glpicsrftokens'][$requestToken]) && $_SESSION['glpicsrftokens'][$requestToken] >= time()) {
+         unset($_SESSION['glpicsrftokens'][$requestToken]);
+         Session::cleanCSRFTokens();
+         return true;
+      }
+      Session::cleanCSRFTokens();
+      return false;
+   }
 }
 ?>
\ No newline at end of file
