@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: software.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: software.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -103,6 +103,7 @@ class Software extends CommonDBTM {
       $this->addStandardTab('Contract_Item', $ong, $options);
       $this->addStandardTab('Document', $ong, $options);
       $this->addStandardTab('Ticket', $ong, $options);
+      $this->addStandardTab('Item_Problem', $ong, $options);
       $this->addStandardTab('Link', $ong, $options);
       $this->addStandardTab('Note', $ong, $options);
       $this->addStandardTab('Reservation', $ong, $options);
@@ -620,10 +621,12 @@ class Software extends CommonDBTM {
     * @param entity the entity in which the software must be added
     * @param comment
     * @param is_recursive must the software be recursive (boolean)
+    * @param is_helpdesk_visible show in helpdesk, default : from config
     *
     * @return the software's ID
    **/
-   function addSoftware($name, $manufacturer, $entity, $comment='', $is_recursive=false) {
+   function addSoftware($name, $manufacturer, $entity, $comment='',
+                        $is_recursive=false, $is_helpdesk_visible=NULL) {
       global $DB, $CFG_GLPI;
 
       $manufacturer_id = 0;
@@ -647,7 +650,11 @@ class Software extends CommonDBTM {
          $input["entities_id"]         = $entity;
          $input["is_recursive"]        = ($is_recursive ? 1 : 0);
          // No comment
-         $input["is_helpdesk_visible"] = $CFG_GLPI["default_software_helpdesk_visible"];
+         if (is_null($is_helpdesk_visible)) {
+            $input["is_helpdesk_visible"] = $CFG_GLPI["default_software_helpdesk_visible"];
+         } else {
+            $input["is_helpdesk_visible"] = $is_helpdesk_visible;
+         }
 
          //Process software's category rules
          $softcatrule = new RuleSoftwareCategoryCollection();
@@ -673,8 +680,10 @@ class Software extends CommonDBTM {
     * @param entity the entity in which the software must be added
     * @param comment comment
     * @param is_recursive must the software be recursive (boolean)
+    * @param is_helpdesk_visible    show in helpdesk, default = config value
    */
-   function addOrRestoreFromTrash($name, $manufacturer, $entity, $comment='', $is_recursive=false) {
+   function addOrRestoreFromTrash($name, $manufacturer, $entity, $comment='',
+                                  $is_recursive=false, $is_helpdesk_visible=NULL) {
       global $DB;
 
       //Look for the software by his name in GLPI for a specific entity
@@ -700,7 +709,8 @@ class Software extends CommonDBTM {
       }
 
       if (!$ID) {
-         $ID = $this->addSoftware($name, $manufacturer, $entity, $comment, $is_recursive);
+         $ID = $this->addSoftware($name, $manufacturer, $entity, $comment,
+                                  $is_recursive, $is_helpdesk_visible);
       }
       return $ID;
    }
@@ -802,7 +812,7 @@ class Software extends CommonDBTM {
          foreach ($req as $data) {
             echo "<tr class='tab_bg_2'>";
             echo "<td><input type='checkbox' name='item[".$data["id"]."]' value='1'></td>";
-            echo "<td<a href='".$link."?id=".$data["id"]."'>".$data["name"]."</a></td>";
+            echo "<td><a href='".$link."?id=".$data["id"]."'>".$data["name"]."</a></td>";
             echo "<td>".$data["entity"]."</td>";
             echo "<td class='right'>".Computer_SoftwareVersion::countForSoftware($data["id"])."</td>";
             echo "<td class='right'>".SoftwareLicense::countForSoftware($data["id"])."</td></tr>\n";
@@ -813,7 +823,7 @@ class Software extends CommonDBTM {
          echo "<input type='hidden' name='id' value='$ID'>";
          Html::closeArrowMassives(array('mergesoftware' => $LANG['software'][48]));
 
-         echo "</form>";
+         Html::closeForm();
 
       } else {
          echo $LANG['search'][15];
