@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: softwarecategory.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: softwarecategory.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,15 +39,17 @@ if (!defined('GLPI_ROOT')) {
 /// Class SoftwareCategory
 class SoftwareCategory extends CommonDropdown {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['softwarecategories'][6];
+      }
       return $LANG['softwarecategories'][5];
    }
 
 
    function cleanDBonPurge() {
-
       Rule::cleanForItemAction($this);
    }
 }
