@@ -2,7 +2,7 @@
 
 
 /*
- * @version $Id: softwarelicense.class.php 18025 2012-03-27 09:00:32Z moyo $
+ * @version $Id: softwarelicense.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -663,7 +663,7 @@ class SoftwareLicense extends CommonDBTM {
                $options = array();
                Html::closeArrowMassives($options);
 
-               echo "</form>";
+               Html::closeForm();
             }
 
          } else {
