@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: state.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: state.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -37,11 +37,14 @@ if (!defined('GLPI_ROOT')) {
 }
 
 /// Class State
-class State extends CommonDropdown {
+class State extends CommonTreeDropdown {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['title'][9];
+      }
       return $LANG['setup'][83];
    }
 
@@ -53,7 +56,7 @@ class State extends CommonDropdown {
     * @param $lib string to add for -1 value
     * @param $value default value
    **/
-   static function dropdownBehaviour ($name, $lib="", $value=0) {
+   static function dropdownBehaviour($name, $lib="", $value=0) {
       global $DB, $LANG;
 
       $elements = array("0" => $LANG['setup'][195]);
@@ -83,9 +86,7 @@ class State extends CommonDropdown {
       $states     = array();
 
       foreach ($state_type as $key=>$itemtype) {
-         if (class_exists($itemtype)) {
-            $item = new $itemtype();
-
+         if ($item = getItemForItemtype($itemtype)) {
             if (!$item->canView()) {
                unset($state_type[$key]);
 
@@ -117,10 +118,9 @@ class State extends CommonDropdown {
          echo "<th>".$LANG['state'][0]."</th>";
 
          foreach ($state_type as $key => $itemtype) {
-            if (class_exists($itemtype)) {
-               $item = new $itemtype();
+            if ($item = getItemForItemtype($itemtype)) {
                echo "<th>".$item->getTypeName()."</th>";
-               $total[$itemtype]=0;
+               $total[$itemtype] = 0;
             } else {
                unset($state_type[$key]);
             }
@@ -130,7 +130,7 @@ class State extends CommonDropdown {
          echo "</tr>";
          $query = "SELECT *
                    FROM `glpi_states`
-                   ORDER BY `name`";
+                   ORDER BY `completename`";
          $result = $DB->query($query);
 
          // No state
@@ -142,7 +142,7 @@ class State extends CommonDropdown {
             if (isset($states[0][$itemtype])) {
                echo $states[0][$itemtype];
                $total[$itemtype] += $states[0][$itemtype];
-               $tot += $states[0][$itemtype];
+               $tot              += $states[0][$itemtype];
             } else {
                echo "&nbsp;";
             }
@@ -156,7 +156,7 @@ class State extends CommonDropdown {
             echo "<tr class='tab_bg_2'><td class='b'>";
             echo "<a href='".$CFG_GLPI['root_doc']."/front/states.php?reset=reset&amp;contains[0]=".
                    "$$$$".$data["id"]."&amp;searchtype[0]=contains&amp;field[0]=31&amp;sort=".
-                   "1&amp;start=0'>".$data["name"]."</a></td>";
+                   "1&amp;start=0'>".$data["completename"]."</a></td>";
 
             foreach ($state_type as $itemtype) {
                echo "<td class='center tab_bg_1'>";
@@ -192,9 +192,7 @@ class State extends CommonDropdown {
 
 
    function cleanDBonPurge() {
-
       Rule::cleanForItemCriteria($this);
    }
 }
-
-?>
\ No newline at end of file
+?>
