@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: supplier.class.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: supplier.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -291,6 +291,16 @@ class Supplier extends CommonDBTM {
       $tab[86]['name']     = $LANG['entity'][9];
       $tab[86]['datatype'] = 'bool';
 
+      $tab[29]['table']         = 'glpi_contracts';
+      $tab[29]['field']         = 'name';
+      $tab[29]['name']          = $LANG['financial'][66];
+      $tab[29]['forcegroupby']  = true;
+      $tab[29]['datatype']      = 'itemlink';
+      $tab[29]['itemlink_type'] = 'Contract';
+      $tab[29]['massiveaction'] = false;
+      $tab[29]['joinparams']    = array('beforejoin'
+                                       => array('table'      => 'glpi_contracts_suppliers',
+                                                'joinparams' => array('jointype' => 'child')));
       return $tab;
    }
 
@@ -442,7 +452,9 @@ class Supplier extends CommonDBTM {
                    class='submit'>";
             echo "</td></tr>";
          }
-         echo "</table></form></div>";
+         echo "</table>";
+         Html::closeForm();
+         echo "</div>";
       }
    }
 
@@ -698,7 +710,8 @@ class Supplier extends CommonDBTM {
             echo "<td>&nbsp;</td></tr>";
          }
       }
-      echo "</table></div></form>";
+      echo "</table></div>";
+      Html::closeForm();
    }
 
 }
