@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticket_ticket.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: ticket_ticket.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -55,8 +55,8 @@ class Ticket_Ticket extends CommonDBRelation {
 
    function canCreate() {
 
-      return haveRight('create_ticket', 1) // Add on creation
-             || haveRight('update_ticket', 1);
+      return (Session::haveRight('create_ticket', 1) // Add on creation
+             || Session::haveRight('update_ticket', 1));
    }
 
 
@@ -116,7 +116,7 @@ class Ticket_Ticket extends CommonDBRelation {
       global $DB, $LANG, $CFG_GLPI;
 
       $tickets   = self::getLinkedTicketsTo($ID);
-      $canupdate = haveRight('update_ticket','1');
+      $canupdate = Session::haveRight('update_ticket', '1');
 
       $ticket = new Ticket();
       if (is_array($tickets) && count($tickets)) {
@@ -239,13 +239,13 @@ class Ticket_Ticket extends CommonDBRelation {
     *
     * @return nothing do the change
    **/
-   static function manageLinkedTicketsOnSolved ($ID) {
+   static function manageLinkedTicketsOnSolved($ID) {
 
       $ticket = new Ticket();
 
       if ($ticket->getfromDB($ID)) {
-         $input['solution']               = addslashes($ticket->fields['solution']);
-         $input['ticketsolutiontypes_id'] = addslashes($ticket->fields['ticketsolutiontypes_id']);
+         $input['solution']         = addslashes($ticket->fields['solution']);
+         $input['solutiontypes_id'] = addslashes($ticket->fields['solutiontypes_id']);
 
          $tickets = self::getLinkedTicketsTo($ID);
          if (count($tickets)) {
@@ -264,5 +264,4 @@ class Ticket_Ticket extends CommonDBRelation {
 
 
 }
-
 ?>
