@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ticketfollowup.class.php 17472 2012-02-14 07:57:31Z moyo $
+ * @version $Id: ticketfollowup.class.php 18771 2012-06-29 08:49:19Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -222,7 +222,7 @@ class TicketFollowup  extends CommonDBTM {
       Log::history($this->getField('tickets_id'), 'Ticket', $changes, $this->getType(),
                    Log::HISTORY_DELETE_SUBITEM);
 
-      $options = array('followup_id' => $this->fields["id"], 
+      $options = array('followup_id' => $this->fields["id"],
                         // Force is_private with data / not available
                         'is_private' => $this->fields['is_private']);
       NotificationEvent::raiseEvent('delete_followup', $job, $options);
@@ -244,8 +244,8 @@ class TicketFollowup  extends CommonDBTM {
       $job = new Ticket();
       $mailsend = false;
 
-      if ($job->getFromDB($this->input["tickets_id"])) {
-         $job->updateDateMod($this->input["tickets_id"]);
+      if ($job->getFromDB($this->fields["tickets_id"])) {
+         $job->updateDateMod($this->fields["tickets_id"]);
 
          if (count($this->updates)) {
             if ($CFG_GLPI["use_mailing"]
@@ -713,7 +713,8 @@ class TicketFollowup  extends CommonDBTM {
          echo "<input type='submit' name='add_reopen' value=\"".$LANG['jobresolution'][4]."\"
                 class='submit'>";
          echo "</td></tr>\n";
-         echo "</table></form>";
+         echo "</table>";
+         Html::closeForm();
       }
       return true;
    }
