@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: toolbox.class.php 17672 2012-02-28 14:33:56Z moyo $
+ * @version $Id: toolbox.class.php 18773 2012-06-29 09:31:34Z remi $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -331,6 +331,32 @@ class Toolbox {
       return $value;
    }
 
+   /**
+    *  Invert fonction from clean_cross_side_scripting_deep to display HTML striping XSS code
+    *
+    * @since version 0.83.3
+    * @param $value array or string: item to unclean from clean_cross_side_scripting_deep
+    *
+    * @return unclean item
+    *
+    * @see clean_cross_side_scripting_deep
+   **/
+   static function unclean_html_cross_side_scripting_deep($value) {
+
+      $in  = array('<', '>');
+      $out = array('&lt;', '&gt;');
+
+      $value = is_array($value) ? array_map(array(__CLASS__, 'unclean_html_cross_side_scripting_deep'),
+                                            $value)
+                                : (is_null($value) ? NULL : str_replace($out,$in,$value));
+
+      include_once(GLPI_HTMLAWED);
+
+      $value = htmLawed($value, array('safe'=>1));
+
+      return $value;
+   }
+
 
    /**
     * Log in 'php-errors' all args
@@ -380,6 +406,12 @@ class Toolbox {
          error_log(Html::convDateTime(date("Y-m-d H:i:s"))."$user\n".$text,
                    3, GLPI_LOG_DIR."/".$name.".log");
       }
+
+      if (isset($_SESSION['glpi_use_mode'])
+          && ($_SESSION['glpi_use_mode'] == Session::DEBUG_MODE)
+          && isCommandLine()) {
+         fwrite(STDERR, $text);
+      }
    }
 
 
@@ -1500,6 +1532,16 @@ class Toolbox {
                      // Use for compatibility with old name
                      case "tracking" :
                      case "ticket" :
+                        // Check entity
+                        if (($item = getItemForItemtype($data[0]))
+                              && $item->isEntityAssign()) {
+                           if ($item->getFromDB($data[1])) {
+                              if (!Session::haveAccessToEntity($item->getEntityID())) {
+                                 Session::changeActiveEntities($item->getEntityID(),1);
+                              }
+                           }
+                        }
+
                         Html::redirect($CFG_GLPI["root_doc"]."/front/ticket.form.php?id=".$data[1].
                                      "&$forcetab");
                         break;
@@ -1566,6 +1608,15 @@ class Toolbox {
 
                      default :
                         if (!empty($data[0] )&& $data[1]>0) {
+                           // Check entity
+                           if (($item = getItemForItemtype($data[0]))
+                                 && $item->isEntityAssign()) {
+                              if ($item->getFromDB($data[1])) {
+                                 if (!Session::haveAccessToEntity($item->getEntityID())) {
+                                    Session::changeActiveEntities($item->getEntityID(),1);
+                                 }
+                              }
+                           }
                            Html::redirect($CFG_GLPI["root_doc"]."/front/".$data[0].".form.php?id=".
                                         $data[1]."&$forcetab");
                         } else {
