@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: virtualmachinestate.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: virtualmachinestate.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,9 +39,12 @@ if (!defined('GLPI_ROOT')) {
 /// Class Filesystem
 class VirtualMachineState extends CommonDropdown {
 
-   static function getTypeName() {
+   static function getTypeName($nb=0) {
       global $LANG;
 
+      if ($nb>1) {
+         return $LANG['computers'][69];
+      }
       return $LANG['computers'][63];
    }
 
