@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: xml.class.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: xml.class.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -175,7 +175,7 @@ class XML {
                      $Attributes = " fieldname=\"".$FieldsVector[$j]."\"";
                }
                fputs($fp, "         <".$FieldName.$Attributes.">".
-                     encodeInUtf8(htmlspecialchars($row[$j]))."</".$FieldName.">\n");
+                     Toolbox::encodeInUtf8(htmlspecialchars($row[$j]))."</".$FieldName.">\n");
             }
             fputs($fp, "      </row>\n");
          }
