@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: update_content.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: update_content.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -39,24 +39,21 @@ define('GLPI_ROOT', '..');
 $CFG_GLPI['root_doc'] = '..';
 
 include_once (GLPI_ROOT . "/config/define.php");
-
-include_once (GLPI_ROOT . "/inc/dbmysql.class.php");
-include_once (GLPI_ROOT . "/inc/common.function.php");
-include_once (GLPI_ROOT . "/inc/display.function.php");
+include_once (GLPI_ROOT . "/inc/autoload.function.php");
 include_once (GLPI_ROOT . "/inc/db.function.php");
 include_once (GLPI_ROOT . "/config/based_config.php");
 include_once (GLPI_CONFIG_DIR . "/config_db.php");
 
-setGlpiSessionPath();
-startGlpiSession();
+Session::setPath();
+Session::start();
 
 // Init debug variable
-$_SESSION['glpi_use_mode'] = DEBUG_MODE;
+$_SESSION['glpi_use_mode'] = Session::DEBUG_MODE;
 $CFG_GLPI["debug_sql"]     = $CFG_GLPI["debug_vars"]=0;
 $CFG_GLPI["use_errorlog"]  = 1;
 ini_set('display_errors','On');
 error_reporting(E_ALL | E_STRICT);
-set_error_handler("userErrorHandlerDebug");
+set_error_handler(array('Toolbox', 'userErrorHandlerDebug'));
 
 //################################ Functions ################################
 
@@ -92,7 +89,7 @@ if ($max_time>5) {
    $defaultrowlimit = 1;
 }
 
-$DB = new DB;
+$DB = new DB();
 
 
 function init_time() {
@@ -140,8 +137,8 @@ function get_update_content($DB, $table, $from, $limit, $conv_utf8) {
                } else if ($val != "") {
                   if ($conv_utf8) {
                      // Gestion users AD qui sont deja en UTF8
-                     if ($table!="glpi_users" || !seems_utf8($val)) {
-                        $val = encodeInUtf8($val);
+                     if ($table!="glpi_users" || !Toolbox::seems_utf8($val)) {
+                        $val = Toolbox::encodeInUtf8($val);
                      }
                   }
                   $insert .= "'".addslashes($val)."',";
@@ -363,7 +360,7 @@ if (TableExists("glpi_configs")) {
    $config_table = "glpi_configs";
 }
 
-if (!FieldExists($config_table,"utf8_conv")) {
+if (!FieldExists($config_table,"utf8_conv", false)) {
    $conv_utf8 = true;
 } else {
    $query = "SELECT `utf8_conv`
@@ -380,9 +377,9 @@ if (!FieldExists($config_table,"utf8_conv")) {
 
 if ($offsettable>=0 && $complete_utf8) {
    if ($percent >= 0) {
-      displayProgressBar(400,$percent);
+      Html::displayProgressBar(400, $percent);
       echo "<div class='bas'></div></div></div></body></html>";
-      glpi_flush();
+      Html::glpi_flush();
    }
 
    if (UpdateContent($DB,$duree,$rowlimit,$conv_utf8,$complete_utf8)) {
@@ -392,7 +389,7 @@ if ($offsettable>=0 && $complete_utf8) {
       echo "<script language='javascript' type='text/javascript'>
              window.location=\"update_content.php?dump=1&duree=$duree&rowlimit=$rowlimit&offsetrow=".
              "$offsetrow&offsettable=$offsettable&cpt=$cpt\";</script>";
-      glpi_flush();
+      Html::glpi_flush();
       exit;
    }
 
