@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: update_to_031.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: update_to_031.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -49,7 +49,7 @@ function updateDbTo031(){
 	//Version 0.21 ajout du champ ramSize a la table printers si non existant.
 
 
-	if(!FieldExists("printers", "ramSize")) {
+	if(!FieldExists("printers", "ramSize", false)) {
 		$query = "alter table printers add ramSize varchar(6) NOT NULL default ''";
 		$DB->query($query) or die($LANG['update'][90].$DB->error());
 	}
