@@ -1,10 +1,10 @@
 /*!
- * Ext JS Library 3.3.0
- * Copyright(c) 2006-2010 Ext JS, Inc.
- * licensing@extjs.com
- * http://www.extjs.com/license
+ * Ext JS Library 3.4.0
+ * Copyright(c) 2006-2011 Sencha Inc.
+ * licensing@sencha.com
+ * http://www.sencha.com/license
  */
-﻿/**
+/**
  * List compiled by mystix on the extjs.com forums.
  * Thank you Mystix!
  *
@@ -164,7 +164,8 @@ if(Ext.form.DateField){
     maxText           : "A dátum nem lehet későbbi, mint {0}",
     invalidText       : "{0} nem megfelelő dátum - a helyes formátum: {1}",
     format            : "Y m d",
-    altFormats        : "Y-m-d|y-m-d|y/m/d|m/d|m-d|md|ymd|Ymd|d"
+    altFormats        : "Y-m-d|y-m-d|y/m/d|m/d|m-d|md|ymd|Ymd|d",
+    startDay          : 0
   });
 }
 
