@@ -1,6 +1,6 @@
 <?php 
 /*
- * @version $Id: zh_TW.php 18108 2012-04-03 06:21:56Z moyo $ 
+ * @version $Id: zh_TW.php 18513 2012-05-25 06:31:03Z moyo $ 
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -1820,6 +1820,7 @@ $LANG['search'][3]="在";
 $LANG['search'][4]="排序"; 
 $LANG['search'][5]="選擇過大，已停用此大量動作。"; 
 $LANG['search'][6]="為了增加上限：請在PHP配置更改max_input_vars或suhosin.post.max_vars。"; 
+$LANG['search'][7]="不在"; 
 $LANG['search'][8]="開始日期"; 
 $LANG['search'][9]="結束日期"; 
 $LANG['search'][11]="檢視的項目"; 
@@ -1855,6 +1856,10 @@ $LANG['setup'][18]="登入名稱";
 $LANG['setup'][19]="密碼"; 
 $LANG['setup'][20]="密碼確認"; 
 $LANG['setup'][21]="錯誤：這兩個密碼不相同"; 
+$LANG['setup'][22]="搜尋影引擎"; 
+$LANG['setup'][23]="上次標準"; 
+$LANG['setup'][24]="預設標準"; 
+$LANG['setup'][25]="全部查尋"; 
 $LANG['setup'][35]="兆赫"; 
 $LANG['setup'][39]="根據個人的預設"; 
 $LANG['setup'][40]="優先顯示新問題單？"; 
@@ -1932,6 +1937,7 @@ $LANG['setup'][129]="顯示GLPI ID";
 $LANG['setup'][130]="用於下一個/上一個項目"; 
 $LANG['setup'][131]="每頁顯示數量"; 
 $LANG['setup'][132]="下拉清單顯示完整的名稱"; 
+$LANG['setup'][133]="在首頁上的結果數量"; 
 $LANG['setup'][135]="正常"; 
 $LANG['setup'][136]="翻譯"; 
 $LANG['setup'][137]="除錯"; 
