@@ -1,7 +1,7 @@
 <?php
 
 /*
- * @version $Id: logout.php 17154 2012-01-24 11:27:36Z moyo $
+ * @version $Id: logout.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -52,10 +52,10 @@ if (!isset($_SESSION["noAUTO"])
 $toADD = "";
 
 // Redirect management
-if (isset ($_POST['redirect']) && strlen($_POST['redirect'])>0) {
+if (isset($_POST['redirect']) && strlen($_POST['redirect'])>0) {
    $toADD = "?redirect=" .$_POST['redirect'];
 
-} else if (isset ($_GET['redirect']) && strlen($_GET['redirect'])>0) {
+} else if (isset($_GET['redirect']) && strlen($_GET['redirect'])>0) {
    $toADD = "?redirect=" .$_GET['redirect'];
 }
 
@@ -68,11 +68,10 @@ if (isset($_SESSION["noAUTO"]) || isset($_GET['noAUTO'])) {
    $toADD .= "noAUTO=1";
 }
 
-$auth = new Auth();
-$auth->destroySession();
+Session::destroy();
 
 // Redirect to the login-page
 
-glpi_header($CFG_GLPI["root_doc"]."/index.php".$toADD);
+Html::redirect($CFG_GLPI["root_doc"]."/index.php".$toADD);
 
 ?>
