@@ -1,6 +1,6 @@
 <?php
 /*
- * @version $Id: ldap_mass_sync.php 17152 2012-01-24 11:22:16Z moyo $
+ * @version $Id: ldap_mass_sync.php 18207 2012-04-10 07:54:41Z walid $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
  Copyright (C) 2003-2012 by the INDEPNET Development Team.
@@ -97,11 +97,12 @@ if (!Toolbox::canUseLdap() || !countElementsInTable('glpi_authldaps')) {
 }
 
 $sql = "SELECT `id`, `name`
-        FROM `glpi_authldaps`";
+        FROM `glpi_authldaps`
+        WHERE `is_active`='1'";
 
 //Get the ldap server's id by his name
 if ($options['ldapservers_id'] != NOT_AVAILABLE) {
-   $sql .= " WHERE `id` = '" . $options['ldapservers_id']."'";
+   $sql .= " AND `id` = '" . $options['ldapservers_id']."'";
 }
 
 $result = $DB->query($sql);
